# Appendix A: Computer Software Help

setwd("~/Teaching/arm3e/")

# cars1

# A.1

cars1 <- read.csv("data/cars1.csv")
attach(cars1)

Class1 <- factor(Class, levels = c("MC", "SC", "CO", "MI", "LA", "SW", "SU"), ordered=T)
Drive1 <- factor(Drive, levels = c("F", "R", "A", "4"), ordered=T)

postscript("insman/cars1hist.eps",
           width=3.5, height=3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
hist(Hmpg, main="", xlab="Hmpg (highway miles per gallon)",
     freq = TRUE,
     breaks=seq(14, 40, by=2))
par(oldpar)
dev.off()

range(Hmpg) # 15 40

mean(Hmpg) # 26.62678

Hgphm <- 100/Hmpg

mean(Hgphm) # 3.870027
100/mean(Hgphm) # 25.83962

# A.2

postscript("insman/cars1histvol.eps",
           width=3.5, height=3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
hist(Vol, main="", xlab="Vol (interior passenger and cargo volume)",
     freq = TRUE, #right=F,
     breaks=seq(.5, 1.8, by=.1))
par(oldpar)
dev.off()

mean(Vol) # 1.096439
median(Vol) # 1.11

quantile(Vol, probs=c(.25,.5,.75), type=6)
#  25%  50%  75% 
# 1.00 1.11 1.20

# A.3

table(Class1, Drive1)
#      Drive1
#Class1  F  R  A  4
#    MC  6 16  0  6
#    SC 16 30 13  0
#    CO 36 16 13  2
#    MI 36 19 25  3
#    LA 14 30 14  2
#    SW 17  5 11  1
#    SU  2  4  8  6

ag <- aggregate(Cmpg ~ Class1 + Drive1, FUN=mean)
round(xtabs(Cmpg ~ ., data=ag),1)
#      Drive1
#Class1    F    R    A    4
#    MC 23.8 17.1  0.0 18.0
#    SC 24.1 17.0 17.4  0.0
#    CO 23.3 15.4 19.1 17.5
#    MI 20.9 16.8 17.2 16.3
#    LA 18.9 15.3 15.6 16.0
#    SW 23.1 16.6 19.5 16.0
#    SU 18.0 15.5 18.4 12.7

postscript("insman/cars1bar.eps",
           width=3.5, height=3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,3,1,1)+0.1, mgp=c(2,1,0))
barplot(tapply(ag$Cmpg, list(ag$Drive1, ag$Class1), sum),
        beside=TRUE, col=c(gray(.2), gray(.4), gray(.6), gray(.8)),
        ylab="Mean city miles per gallon", ylim=c(0,30))
legend("top", inset=c(0,0), legend=c("FWD", "RWD", "AWD", "4WD"),
       horiz=T, fill=c(gray(.2), gray(.4), gray(.6), gray(.8)))
par(oldpar)
dev.off()

# A.4

table(Class1)
#Class1
#MC SC CO MI LA SW SU 
#28 59 67 83 60 34 20 

table(Drive1)
#Drive1
#  F   R   A   4 
#127 120  84  20 

mytab <- table(Class1, Drive1)
mytab
#      Drive1
#Class1  F  R  A  4
#    MC  6 16  0  6
#    SC 16 30 13  0
#    CO 36 16 13  2
#    MI 36 19 25  3
#    LA 14 30 14  2
#    SW 17  5 11  1
#    SU  2  4  8  6

rowsum <- apply(mytab, 1, sum)
round(100*mytab/rowsum,0)
#      Drive1
#Class1  F  R  A  4
#    MC 21 57  0 21
#    SC 27 51 22  0
#    CO 54 24 19  3
#    MI 43 23 30  4
#    LA 23 50 23  3
#    SW 50 15 32  3
#    SU 10 20 40 30

colsum <- apply(mytab, 2, sum)
round(100*t(t(mytab)/colsum),0)
#      Drive1
#Class1  F  R  A  4
#    MC  5 13  0 30
#    SC 13 25 15  0
#    CO 28 13 15 10
#    MI 28 16 30 15
#    LA 11 25 17 10
#    SW 13  4 13  5
#    SU  2  3 10 30

# A.5

postscript("insman/cars1box.eps",
           width=3.5, height=3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,3,1,1)+0.1, mgp=c(2,1,0))
boxplot(Cmpg ~ Class1, boxwex=.5, cex.axis=1,
        xlab = "Class (vehicle class)",
        ylab = "Cmpg (city miles per gallon)")
par(oldpar)
dev.off()

# A.6

postscript("insman/cars1splom.eps",
           width = 4.0, height = 4.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Cmpg, Eng, Cyl, Vol), cex.labels=1.3, #panel=panel.smooth,
      labels=c("City MPG", "Engine size", "Cylinders", "Volume"))
dev.off()

# A.7

postscript("insman/cars1sp1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Cmpg,Hmpg,
	xlab="Cmpg (city miles per gallon)",
    ylab="Hmpg (highway miles per gallon)")
par(oldpar)
dev.off()

postscript("insman/cars1sp2.eps",
           width = 3.5, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Cmpg,Hmpg,xlim=c(10,40), ylim=c(10,40),
	xlab="Cmpg (city miles per gallon)",
    ylab="Hmpg (highway miles per gallon)")
abline(0,1)
par(oldpar)
dev.off()

range(Hmpg-Cmpg) #  4 13

detach(cars1)
