# Appendix E: Matrices

A <- matrix(1:6, 3, 2, byrow=T)
B <- matrix(7:14, 2, 4, byrow=T)
A%*%B
#      [,1] [,2] [,3] [,4]
# [1,]   29   32   35   38
# [2,]   65   72   79   86
# [3,]  101  112  123  134

b <- matrix(c(7, 8), 2, 1)
A%*%b
#      [,1]
# [1,]   23
# [2,]   53
# [3,]   83

7*A
#      [,1] [,2]
# [1,]    7   14
# [2,]   21   28
# [3,]   35   42

A %*% t(A)
t(A) %*% A
b %*% t(b)
t(b) %*% b

A <- matrix(1:4, 2, 2, byrow=T)
solve(A)
#      [,1] [,2]
# [1,] -2.0  1.0
# [2,]  1.5 -0.5

X1 <- c(4, 3, 1, 5, 2)
X2 <- c(2, 2, 1, 3, 2)
Y  <- c(15, 12, 6, 16, 11)
model1 <- lm(Y ~ X1 + X2, x=T, y=T)
summary(model1)
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)
# (Intercept)    4.000      2.324   1.721    0.227
# X1             2.000      1.000   2.000    0.184
# X2             1.000      2.236   0.447    0.698
# 
# Residual standard error: 1.414 on 2 degrees of freedom
# Multiple R-squared:  0.9355,	Adjusted R-squared:  0.871 
# F-statistic:  14.5 on 2 and 2 DF,  p-value: 0.06452

pairs(cbind(Y, X1, X2))

t(model1$x) %*% model1$x
#             (Intercept) X1 X2
# (Intercept)           5 15 10
# X1                   15 55 34
# X2                   10 34 22

xtxinv <- solve(t(model1$x) %*% model1$x)
xtxinv
#             (Intercept)   X1   X2
# (Intercept)         2.7  0.5 -2.0
# X1                  0.5  0.5 -1.0
# X2                 -2.0 -1.0  2.5

xty <- t(model1$x) %*% model1$y
xty
#             [,1]
# (Intercept)   60
# X1           204
# X2           130

bhat <- xtxinv %*% xty
bhat
#             [,1]
# (Intercept)    4
# X1             2
# X2             1

yhat <- model1$x %*% bhat
yhat
#   [,1]
# 1   14
# 2   12
# 3    7
# 4   17
# 5   10

fitted(model1)
#  1  2  3  4  5 
# 14 12  7 17 10 

h <- model1$x %*% xtxinv %*% t(model1$x)
h
#      1   2    3    4    5
# 1  0.7 0.2  0.2  0.2 -0.3
# 2  0.2 0.2  0.2  0.2  0.2
# 3  0.2 0.2  0.7 -0.3  0.2
# 4  0.2 0.2 -0.3  0.7  0.2
# 5 -0.3 0.2  0.2  0.2  0.7

h %*% model1$y
#   [,1]
# 1   14
# 2   12
# 3    7
# 4   17
# 5   10

ehat <- model1$y - yhat
round(ehat, 1)
#   [,1]
# 1    1
# 2    0
# 3   -1
# 4   -1
# 5    1

round(resid(model1), 1)
# 1  2  3  4  5 
# 1  0 -1 -1  1 

rss <- c(t(ehat) %*% ehat)
rss # 4

sum((Y-fitted(model1))^2) # 4

dfe <- summary(model1)$df[2]
dfe # 2

s <- c(sqrt(rss/dfe))
s # 1.414214

ycent <- model1$y-mean(model1$y)
ycent
# 1  2  3  4  5 
# 3  0 -6  4 -1 

tss <- c(t(ycent) %*% ycent)
tss # 62

sum((Y-mean(Y))^2) # 62

1 - rss/tss # 0.9354839

summary(model1)$r.squared # 0.9354839

s^2 * xtxinv
#             (Intercept) X1 X2
# (Intercept)         5.4  1 -4
# X1                  1.0  1 -2
# X2                 -4.0 -2  5

bse <- sqrt(diag(s^2 * xtxinv))
bse
# (Intercept)          X1          X2 
#    2.323790    1.000000    2.236068 

bhat/bse
#                  [,1]
# (Intercept) 1.7213259
# X1          2.0000000
# X2          0.4472136

newx <- c(1, 4, 3)
newfit <- c(t(newx) %*% bhat)
newfit # 15

newx %*% xtxinv %*% newx # 1.2

see <- c(s * sqrt(newx %*% xtxinv %*% newx))
see # 1.549193

predict(model1, newdata=data.frame(X1=4, X2=3), interval="confidence",
        se.fit=T)$se.fit
# 1.549193

qt(.975,dfe) # 4.302653

qt(.975,dfe)*see # 6.665641

newfit + c(-1, 1) * qt(.975,dfe) * see # 8.334359 21.665641

round(predict(model1, newdata=data.frame(X1=4, X2=3), interval="confidence"), 3)
#   fit    lwr    upr
# 1  15 8.334 21.666

1 + newx %*% xtxinv %*% newx # 2.2

sep <- c(s * sqrt(1 + newx %*% xtxinv %*% newx))
sep # 2.097618

sqrt(s^2 + see^2) # 2.097618

qt(.975,dfe) * sep # 9.025321

newfit + c(-1, 1) * qt(.975,dfe) * sep # 5.974679 24.025321

round(predict(model1, newdata=data.frame(X1=4, X2=3), interval="prediction"), 3)
#   fit     lwr    upr
# 1  15 5.975 24.025

leverages <- diag(h)
leverages
#   1   2   3   4   5 
# 0.7 0.2 0.7 0.7 0.7 

hatvalues(model1)
#   1   2   3   4   5 
# 0.7 0.2 0.7 0.7 0.7 

rhat <- ehat / (s * sqrt(1-leverages))
round(rhat, 3)
#     [,1]
# 1  1.291
# 2  0.000
# 3 -1.291
# 4 -1.291
# 5  1.291

rstandard(model1)
#        1         2         3         4         5 
# 1.290994  0.000000 -1.290994 -1.290994  1.290994 

that <- rhat * sqrt((dfe-1)/(dfe-rhat^2))
round(that, 3)
#     [,1]
# 1  2.236
# 2  0.000
# 3 -2.236
# 4 -2.236
# 5  2.236

rstudent(model1)
#        1         2         3         4         5 
# 2.236068  0.000000 -2.236068 -2.236068  2.236068 

dfr <- summary(model1)$df[1]
dfr # 3

cooksd <- (rhat^2*leverages)/(dfr*(1-leverages))
round(cooksd, 3)
#    [,1]
# 1 1.296
# 2 0.000
# 3 1.296
# 4 1.296
# 5 1.296

round(cooks.distance(model1), 3)
#     1     2     3     4     5 
# 1.296 0.000 1.296 1.296 1.296 
