# Chapter 1: Foundations

setwd("~/Teaching/arm3e/")

# 1.1: Identifying and summarizing data

homes1 <- read.csv("data/homes1.csv")
attach(homes1)

# stem-and-leaf plot

stem(Price, scale=.8)
#  The decimal point is 2 digit(s) to the right of the |
#  1 | 6
#  2 | 0011344
#  2 | 5666777899
#  3 | 002223444
#  3 | 666

# histogram

postscript("manuscript/figures/histogram.eps",
           width=4.0, height=3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
hist(Price, main="", xlab="Price (sale price in $ thousands)",
     freq = TRUE,
     breaks=c(150,175,200,225,250,275,300,325,350,375,400))
par(oldpar)
dev.off()

# summary statistics

c(mean(Price), median(Price), sd(Price), min(Price), max(Price), 
	quantile(Price, probs=c(.25,.5,.75), type=6))
#                                                  25%      50%      75% 
#278.6033 278.9500  53.8656 155.5000 359.9000 241.3750 278.9500 325.8750 

# 1.2: Population distributions

# normalhist

check <- 0
while(check<4) {
Y1 <- rnorm(1000, mean(Price), sd(Price))
check <- (min(Y1)<125)+(min(Y1)>120)+(max(Y1)<450)+(max(Y1)>445)
}
c(min(Y1), max(Y1), mean(Y1), sd(Y1))
#121.90837 449.98542 279.24537  52.94608

hist(Y1, main="", xlab="Price (sale price in $ thousands)",
     freq = FALSE,
     breaks=seq(from=120,to=450,by=10))
lines(sort(Y1), dnorm(sort(Y1), mean(Price), sd(Price)))

postscript("manuscript/figures/normalhist.eps",
           width=4.0, height=3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
hist(Y1, main="", xlab="Price (sale price in $ thousands)",
     freq = FALSE,
     breaks=seq(from=120,to=450,by=10))
lines(sort(Y1), dnorm(sort(Y1), mean(Price), sd(Price)))
par(oldpar)
dev.off()

# normalcurve

postscript("manuscript/figures/normalcurve.eps",
           width=4.0, height=3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,1,1,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dnorm(x),type="l",xlab="",ylab="",
     ylim=c(.015,.4),yaxt="n",bty="n")
x <- seq(0,1.96,len=40)
y <- dnorm(x)
x <- c(x,1.96,0,0)
y <- c(y,0,0,dnorm(0))
polygon(x,y,col="gray")
text(-0.27,-0.012,xpd=NA,"a = 0")
text(1.58,-0.012,xpd=NA,"b = 1.96")
text(2.3,0.2,"area = 0.475")
lines(c(2.3,1.4),c(0.19,0.1))
par(oldpar)
dev.off()

# normal percentiles

round(qnorm(c(.1,.05,.025,.01,.005,.001),lower.tail=F),3)
# 1.282 1.645 1.960 2.326 2.576 3.090

# qqplot

postscript("manuscript/figures/qqplot.eps",
           width=3.5, height=3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
qqnorm(Price, main="")
qqline(Price)
par(oldpar)
dev.off()

# 1.3: Selecting individuals at random - probability

(380-280)/50 # 2
pnorm(2, lower.tail=F) # 0.02275013

(215-280)/50 # -1.3
pnorm(-1.3, lower.tail=T) # 0.09680048

qnorm(0.025,lower.tail=F) # 1.959964
1.96*50 + 280 # 378

# 1.4: Random sampling

# 1.4.1: Central limit theorem - normal version

qnorm(0.1,lower.tail=F)*50/sqrt(30) + 280 # 291.6989
qnorm(0.1,lower.tail=F)*50 + 280 # 344.0776

qnorm(0.1,lower.tail=F) # 1.281552
50/sqrt(30) # 9.128709

round(1.282*9.129 + 280, 3) # 291.703
round(1.282*50 + 280, 3) # 344.1

(291.703-280)/9.129 # 1.281959
pnorm(1.282, lower.tail=F) # 0.09992132

# clt

postscript("manuscript/figures/clt.eps",
           width = 5.0, height = 4.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,1,1,1)+0.1)
layout(matrix(c(1,1,1,0,2,0,0,2,0),3,3,byrow=T))
x <- seq(180,380,len=100)
plot(x,dnorm(x,280,50),type="l",xlab="",ylab="",yaxt="n",xaxt="n",
     bty="n",ylim=c(0,.008),mgp=c(1,1,0))
lines(c(280,280),c(0,.008))
x <- seq(344.1,380,len=20)
y <- dnorm(x,280,50)
x <- c(x,380,344.1,344.1)
y <- c(y,0,0,dnorm(344.1,280,50))
polygon(x,y,col="gray")
lines(c(380,380),c(0,dnorm(380,280,50)),col="gray")
lines(c(180,380),c(0,0))
text(384,0,"Y",xpd=NA,cex=1.5)
text(280,-0.0008,"280",xpd=NA,cex=1.5)
text(344.1,-0.0008,"344.100",xpd=NA,cex=1.5)
x <- seq(250,310,len=100)
plot(x,dnorm(x,280,9.129),type="l",xlab="",ylab="",yaxt="n",xaxt="n",
     bty="n",ylim=c(0,.044),mgp=c(1,1,0))
lines(c(280,280),c(0,.044))
x <- seq(291.703,310,len=20)
y <- dnorm(x,280,9.129)
x <- c(x,310,291.703,291.703)
y <- c(y,0,0,dnorm(291.703,280,9.129))
polygon(x,y,col="gray")
lines(c(310,310),c(0,dnorm(310,280,9.129)),col="gray")
lines(c(250,310),c(0,0))
text(314,0,expression(M[Y]),xpd=NA,cex=1.5)
text(277,-0.002,"280",xpd=NA,cex=1.5)
text(294.7,-0.002,"291.703",xpd=NA,cex=1.5)
par(oldpar)
dev.off()

# 1.4.2: Central limit theorem - t version

# t percentiles

round(qt(c(.1,.05,.025,.01,.005,.001),29,lower.tail=F),3)
# 1.311 1.699 2.045 2.462 2.756 3.396

qt(0.1, 29, lower.tail=F)*sd(Price)/sqrt(30) + 280 # 292.8973

qt(0.1, 29, lower.tail=F) # 1.311434
sd(Price) # 53.8656

round(1.311*53.8656/sqrt(30) + 280, 3) # 292.893

(292.893-280)/(53.8656/sqrt(30)) # 1.311001
pt(1.311, 29, lower.tail=F) # 0.1000723

# 1.5: Interval estimation

mean(Price) # 278.6033
qt(0.975, 29, lower.tail=T) # 2.04523

2.045*53.8656/sqrt(30) # 20.11149
round(278.6033-20.1115, 3) # 258.492
round(278.6033+20.1115, 3) # 298.715

t.test(Price, conf.level=.95)
#95 percent confidence interval:
# 258.4896 298.7171 

qt(0.95, 29, lower.tail=T) # 1.699127

round(278.6033-1.699*(53.8656/sqrt(30)), 3) # 261.895
round(278.6033+1.699*(53.8656/sqrt(30)), 3) # 295.312

t.test(Price, conf.level=.9)
# 90 percent confidence interval:
#   261.8933 295.3133

# 1.6: Hypothesis testing

round((278.6033-255)/(53.8656/sqrt(30)),2) # 2.4

qt(0.95, 29, lower.tail=T) # 1.699127
pt(2.4, 29, lower.tail=F) # 0.0115196

t.test(Price, mu=255, alternative="greater")
#t = 2.4001, df = 29, p-value = 0.01152
#alternative hypothesis: true mean is greater than 255 

qt(0.975, 29, lower.tail=T) # 2.04523
2*pt(2.4, 29, lower.tail=F) # 0.0230392

t.test(Price, mu=255, alternative="two.sided")
#t = 2.4001, df = 29, p-value = 0.02304
#alternative hypothesis: true mean is not equal to 255 

# tcurverents

x <- seq(-3,3,len=100)
postscript("manuscript/figures/tcurverents.eps",
           width = 4.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,1,1,1)+0.1)
plot(x,dt(x,df=28),type="l",xlab="",ylab="",
ylim=c(.015,.4),yaxt="n",xaxt="n",bty="n")
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.015,"0",xpd=NA)
x <- seq(1.699,3,len=20)
y <- dt(x,df=28)
x <- c(x,3,1.699,1.699)
y <- c(y,0,0,dt(1.699,df=28))
polygon(x,y,density=15)
x <- seq(2.40,3,len=20)
y <- dt(x,df=28)
x <- c(x,3,2.40,2.40)
y <- c(y,0,0,dt(2.40,df=28))
polygon(x,y,density=15,angle=-45)
lines(c(3,3),c(0,dt(3,df=28)),col="white")
text(2.45,0.085,"significance")
text(2.4,0.07,"level")
arrows(2.1,0.075,2.0,0.03,0,lwd=.5)
text(2.75,0.04,"p-value")
arrows(2.7,0.035,2.75,0.005,0,lwd=.5)
text(1.699,-0.015,"1.699",xpd=NA)
text(2.40,-0.015,"2.40",xpd=NA)
text(1.4,-0.035,"critical value",xpd=NA)
text(2.7,-0.035,"test statistic",xpd=NA)
par(oldpar)
dev.off()

# tcurveupperreject

postscript("manuscript/figures/tcurveupperreject.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2.2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Upper-tail test: reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(1.7,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,1.7,1.7)
y <- c(y,0,0,dt(1.7,df=60))
polygon(x,y,density=25)
x <- seq(2.2,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,2.2,2.2)
y <- c(y,0,0,dt(2.2,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(3,3),c(0,dt(3,df=60)),col="white")
text(2.48,0.14,"significance",xpd=NA)
text(2.48,0.11,"level")
arrows(2.05,0.12,1.95,0.03,0,lwd=.5)
text(2.78,0.065,"p-value",xpd=NA)
arrows(2.8,0.06,2.7,0.005,0,lwd=.5)
text(1.3,-0.02,"critical",xpd=NA)
text(1.3,-0.05,"value",xpd=NA)
text(2.5,-0.02,"test",xpd=NA)
text(2.5,-0.05,"statistic",xpd=NA)
par(oldpar)
dev.off()

# tcurveupperaccept

postscript("manuscript/figures/tcurveupperaccept.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Upper-tail test: do not reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(1.7,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,1.7,1.7)
y <- c(y,0,0,dt(1.7,df=60))
polygon(x,y,density=25)
x <- seq(1.3,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,1.3,1.3)
y <- c(y,0,0,dt(1.3,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(3,3),c(0,dt(3,df=60)),col="white")
text(2.65,0.115,"significance",xpd=NA)
text(2.65,0.085,"level")
arrows(2.15,0.095,1.9,0.035,0,lwd=.5)
text(2.15,0.165,"p-value",xpd=NA)
arrows(1.7,0.15,1.45,0.09,0,lwd=.5)
text(0.9,-0.02,"test",xpd=NA)
text(0.9,-0.05,"statistic",xpd=NA)
text(2.1,-0.02,"critical",xpd=NA)
text(2.1,-0.05,"value",xpd=NA)
par(oldpar)
dev.off()

# tcurvelowerreject

postscript("manuscript/figures/tcurvelowerreject.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2.2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Lower-tail test: reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(-1.7,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-1.7,-1.7)
y <- c(y,0,0,dt(-1.7,df=60))
polygon(x,y,density=25)
x <- seq(-2.2,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-2.2,-2.2)
y <- c(y,0,0,dt(-2.2,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(-3,-3),c(0,dt(-3,df=60)),col="white")
text(-2.48,0.14,"significance",xpd=NA)
text(-2.48,0.11,"level")
arrows(-2.05,0.12,-1.95,0.03,0,lwd=.5)
text(-2.78,0.065,"p-value",xpd=NA)
arrows(-2.8,0.06,-2.7,0.005,0,lwd=.5)
text(-1.3,-0.02,"critical",xpd=NA)
text(-1.3,-0.05,"value",xpd=NA)
text(-2.5,-0.02,"test",xpd=NA)
text(-2.5,-0.05,"statistic",xpd=NA)
par(oldpar)
dev.off()

# tcurveloweraccept

postscript("manuscript/figures/tcurveloweraccept.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Lower-tail test: do not reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(-1.7,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-1.7,-1.7)
y <- c(y,0,0,dt(-1.7,df=60))
polygon(x,y,density=25)
x <- seq(-1.3,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-1.3,-1.3)
y <- c(y,0,0,dt(-1.3,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(-3,-3),c(0,dt(-3,df=60)),col="white")
text(-2.65,0.115,"significance",xpd=NA)
text(-2.65,0.085,"level")
arrows(-2.15,0.095,-1.9,0.035,0,lwd=.5)
text(-2.15,0.165,"p-value",xpd=NA)
arrows(-1.7,0.15,-1.45,0.09,0,lwd=.5)
text(-0.9,-0.02,"test",xpd=NA)
text(-0.9,-0.05,"statistic",xpd=NA)
text(-2.1,-0.02,"critical",xpd=NA)
text(-2.1,-0.05,"value",xpd=NA)
par(oldpar)
dev.off()

# tcurvetworeject

postscript("manuscript/figures/tcurvetworeject.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2.2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Two-tail test: reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(2.0,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,2.0,2.0)
y <- c(y,0,0,dt(2.0,df=60))
polygon(x,y,density=25)
x <- seq(2.4,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,2.4,2.4)
y <- c(y,0,0,dt(2.4,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(3,3),c(0,dt(3,df=60)),col="white")
x <- seq(-2.0,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-2.0,-2.0)
y <- c(y,0,0,dt(-2.0,df=60))
polygon(x,y,density=25)
x <- seq(-2.4,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-2.4,-2.4)
y <- c(y,0,0,dt(-2.4,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(-3,-3),c(0,dt(-3,df=60)),col="white")
text(2.48,0.14,"significance",xpd=NA)
text(2.48,0.11,"level")
arrows(2.0,0.11,2.1,0.02,0,lwd=.5)
arrows(2.0,0.11,-2.1,0.02,0,lwd=.5)
text(2.85,0.065,"p-value",xpd=NA)
arrows(2.8,0.05,2.7,0.005,0,lwd=.5)
arrows(2.8,0.05,-2.7,0.005,0,lwd=.5)
text(1.5,-0.02,"critical",xpd=NA)
text(1.5,-0.05,"value",xpd=NA)
text(2.7,-0.02,"test",xpd=NA)
text(2.7,-0.05,"statistic",xpd=NA)
text(-1.5,-0.02,"-critical",xpd=NA)
text(-1.5,-0.05,"value",xpd=NA)
text(-2.7,-0.02,"-test",xpd=NA)
text(-2.7,-0.05,"statistic",xpd=NA)
par(oldpar)
dev.off()

# tcurvetwoaccept

postscript("manuscript/figures/tcurvetwoaccept.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2.2,1,2,1)+0.1)
x <- seq(-3,3,len=100)
plot(x,dt(x,df=60),type="l",xlab="",ylab="",
ylim=c(.015,.39),yaxt="n",xaxt="n",bty="n",
main="Two-tail test: do not reject null", cex.main=1)
lines(c(-3,3),c(0,0))
lines(c(0,0),c(0,.4))
text(0,-0.02,"0",xpd=NA)
x <- seq(2.0,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,2.0,2.0)
y <- c(y,0,0,dt(2.0,df=60))
polygon(x,y,density=25)
x <- seq(2,3,len=20)
y <- dt(x,df=60)
x <- c(x,3,1.6,1.6)
y <- c(y,0,0,dt(1.6,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(3,3),c(0,dt(3,df=60)),col="white")
x <- seq(-2.0,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-2.0,-2.0)
y <- c(y,0,0,dt(-2.0,df=60))
polygon(x,y,density=25)
x <- seq(-1.6,-3,len=20)
y <- dt(x,df=60)
x <- c(x,-3,-1.6,-1.6)
y <- c(y,0,0,dt(-1.6,df=60))
polygon(x,y,density=25,angle=-45)
lines(c(-3,-3),c(0,dt(-3,df=60)),col="white")
text(2.15,0.165,"p-value",xpd=NA)
arrows(1.6,0.145,1.7,0.06,0,lwd=.5)
arrows(1.6,0.145,-1.7,0.06,0,lwd=.5)
text(2.65,0.115,"significance",xpd=NA)
text(2.65,0.085,"level")
arrows(2.15,0.09,2.25,0.02,0,lwd=.5)
arrows(2.15,0.09,-2.25,0.02,0,lwd=.5)
text(2.4,-0.02,"critical",xpd=NA)
text(2.4,-0.05,"value",xpd=NA)
text(1.2,-0.02,"test",xpd=NA)
text(1.2,-0.05,"statistic",xpd=NA)
text(-2.4,-0.02,"-critical",xpd=NA)
text(-2.4,-0.05,"value",xpd=NA)
text(-1.2,-0.02,"-test",xpd=NA)
text(-1.2,-0.05,"statistic",xpd=NA)
par(oldpar)
dev.off()

# 1.7: Random errors and prediction

2.045*53.8656*sqrt(1+1/30) # 111.976
278.6033-111.976 # 166.6273 
278.6033+111.976 # 390.5793

model <- lm(Price ~ 1)
predict(model, interval="prediction")[1,]
#        fit      lwr      upr
#1  278.6033 166.6147 390.5919

278.6033-1.699*53.8656*sqrt(1+1/30) # 185.5729
278.6033+1.699*53.8656*sqrt(1+1/30) # 371.6337

predict(model, interval="prediction", level=0.9)[1,]
#        fit      lwr      upr
#1  278.6033 185.5659 371.6407

detach(homes1)