# Chapter 2: Simple Linear Regression

setwd("~/Teaching/arm3e/")

# 2.1: Probability model for X and Y

# plotsales4

postscript("manuscript/figures/plotsales4.eps",
           width=5.0, height=3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,2,2)+0.1)
x <- c(1,2,3,4,5,6,7)
y <- x
layout(matrix(c(1,2,3,4),2,2,byrow=T))
plot(x,y,type="b",xlab="floor size",ylab="sale price",
     xaxt="n",yaxt="n", mgp=c(1,1,0))
y <- -x
plot(x,y,type="b",xlab="floor size",ylab="sale price",
     xaxt="n",yaxt="n", mgp=c(1,1,0))
y <- -1/(x^1.3)
plot(x,y,type="b",xlab="floor size",ylab="sale price",
     xaxt="n",yaxt="n", mgp=c(1,1,0))
y <- 1/(1+exp(2*(4-x)))
plot(x,y,type="b",xlab="floor size",ylab="sale price",
     xaxt="n",yaxt="n", mgp=c(1,1,0))
par(oldpar)
dev.off()

# plotsales

homes2 <- read.csv("data/homes2.csv")
attach(homes2)

model1 <- lm(Price ~ Floor)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  190.318     11.023  17.266 0.000423 ***
#Floor         40.800      5.684   7.179 0.005569 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 2.786 on 3 degrees of freedom
#Multiple R-squared: 0.945,	Adjusted R-squared: 0.9266 
#F-statistic: 51.53 on 1 and 3 DF,  p-value: 0.005569 

postscript("manuscript/figures/plotsales.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Floor,Price,xlab="Floor = floor size (in thousands of square feet)",
     ylab="Price = sale price (in thousands of dollars)",
     xlim=c(1.65,2.3),ylim=c(259,286))
lines(Floor,fitted(model1))
text(1.95,277,expression(paste("E(Price|Floor) = ", 190.3+40.8*Floor)))
arrows(1.95,276,2.053,274.0808,0,lwd=0.5)
text(2.07,272.0404,"e")
arrows(2.053,270,2.053,274.0808,0.1,code=3,lwd=0.5)
par(oldpar)
dev.off()

# linearequation

postscript("manuscript/figures/linearequation.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,2,2)+0.1, mgp=c(2,1,0))
x <- c(0,2,4,6)
y <- c(1,2,3,4)
plot(x,y,xlab="X = predictor",ylab="Y = response",
xlim=c(-1,7),ylim=c(0,5),type="l")
text(4.7,4,expression(paste("E(Y|X) = ", b[0]+b[1]*X)))
text(3.1,3,expression(paste(b[1], " = slope")))
text(5.3,3,"change in Y")
text(4,2.5,"change in X")
arrows(4.5,3.25,4.5,2.75,0.1,code=3,lwd=0.5)
arrows(3.5,2.75,4.5,2.75,0.1,code=3,lwd=0.5)
text(1.0,.5,expression(paste(b[0], " = Y-intercept")))
arrows(0,0,0,1,0.1,code=3,lwd=0.5)
par(oldpar)
dev.off()

# 2.2: Least squares criterion

# leastsquares

postscript("manuscript/figures/leastsquares.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,2,2)+0.1, mgp=c(2,1,0))
plot(Floor,Price,xlab="Floor = floor size (in thousands of square feet)",
	ylab="Price = sale price (in thousands of dollars)",pch=19,
    xlim=c(1.65,2.3),ylim=c(259,286))
lines(Floor,fitted(model1))
lines(Floor,rep(268.94,5),lty=2)
lines(Floor,268.94+13.6*(Floor-1.927),lty=2)
lines(Floor,268.94+27.2*(Floor-1.927),lty=2)
lines(Floor,268.94+54.4*(Floor-1.927),lty=2)
lines(Floor,268.94+68*(Floor-1.927),lty=2)
par(oldpar)
dev.off()

# slrmodel

postscript("manuscript/figures/slrmodel.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Floor,Price,xlab="Floor = floor size (in thousands of square feet)",
     ylab="Price = sale price (in thousands of dollars)",
     xlim=c(1.65,2.3),ylim=c(259,286))
lines(Floor,fitted(model1))
text(1.95,279,expression(widehat(Price)==hat(b)[0]+hat(b)[1]*Floor))
arrows(1.95,276,2.053,274.0808,0,lwd=0.5)
text(2.053,268,expression(Price==hat(b)[0]+hat(b)[1]*Floor+hat(e)))
text(2.13,273.6,expression(hat(e)))
arrows(2.053,270,2.053,274.0808,0.1,code=3,lwd=0.5)
text(1.95,277,"(fitted value)")
text(2.053,266,"(observed value)")
text(2.13,272.2,"(estimated error")
text(2.13,270.8,"or residual)")
par(oldpar)
dev.off()

# 2.3: Model evaluation

# rsquared4

postscript("manuscript/figures/rsquared4.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
x <- sort(runif(30))
layout(matrix(c(1,2,3,4),2,2,byrow=T))
y <- rnorm(30)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(x,rep(0,30))
y <- x+rnorm(30,sd=.2)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(x,fitted(lm(y~x)))
y <- x+rnorm(30,sd=.05)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(x,fitted(lm(y~x)))
y <- x
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(x,fitted(lm(y~x)))
par(oldpar)
dev.off()

# 2.3.1: Regression standard error

# sinterpretation

postscript("manuscript/figures/sinterpretation.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
x <- runif(50)
y <- x+rnorm(50,sd=.1)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",mgp=c(1,1,0))
lines(sort(x),(fitted(lm(y~x)))[order(x)])
lines(sort(x),(fitted(lm(y~x)))[order(x)]+2*summary(lm(y~x))$sigma,
      lty=2) 
lines(sort(x),(fitted(lm(y~x)))[order(x)]-2*summary(lm(y~x))$sigma,
      lty=2) 
arrows(.45,predict(lm(y~x),data.frame(x=.45)),.45,
predict(lm(y~x),data.frame(x=.45))+2*summary(lm(y~x))$sigma,.1,code=3,
       lwd=.5) 
text(.48,.55,expression(+2*s))
arrows(.45,predict(lm(y~x),data.frame(x=.45)),.45,
predict(lm(y~x),data.frame(x=.45))-2*summary(lm(y~x))$sigma,.1,code=3,
       lwd=.5)
text(.42,.34,expression(-2*s))
par(oldpar)
dev.off()

# 2.3.2: Coefficient of determination

# rsquared

postscript("manuscript/figures/rsquared.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Floor,Price,xlab="Floor = floor size (in thousands of square feet)",
     ylab="Price = sale price (in thousands of dollars)",
     xlim=c(1.65,2.3),ylim=c(259,286))
lines(Floor,fitted(model1))
lines(Floor,rep(mean(Price),5))
arrows(2.269,285,2.269,282.8936,0.1,code=3,lwd=0.5)
text(2.15,284,expression(RSS==sum((Price[i]-widehat(Price)[i])^2,i==1,n)))
arrows(2.29,285,2.29,268.94,0.1,code=3,lwd=0.5)
text(2.18,273,expression(TSS==sum((Price[i]-m[Price])^2,i==1,n)))
#arrows(4.1,29.5,4.4,34.0,0,lwd=0.5)
par(oldpar)
dev.off()

# rsquared9

x <- sort(runif(50))
postscript("manuscript/figures/rsquared9.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,3,1)+0.1)
layout(matrix(1:9,3,3,byrow=T))
y <- x+rnorm(50,sd=1)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.6)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.4)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.25)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.2)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.12)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.08)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.05)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
y <- x
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(R^2==.(round(summary(lm(y~x))$r.squared,2))),line=1)
lines(x,fitted(lm(y~x)))
par(oldpar)
dev.off()

# correlation9

x <- sort(runif(50))
postscript("manuscript/figures/correlation9.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,3,1)+0.1)
layout(matrix(1:9,3,3,byrow=T))
y <- -x
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",           ")),line=0.9)
mtext(bquote(paste("            ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- -x+rnorm(50,sd=.08)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",               ")),line=0.9)
mtext(bquote(paste("                ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- -x+rnorm(50,sd=.2)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",               ")),line=0.9)
mtext(bquote(paste("                ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- -x+rnorm(50,sd=.4)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",               ")),line=0.9)
mtext(bquote(paste("                ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=1)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",              ")),line=0.9)
mtext(bquote(paste("               ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.4)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",              ")),line=0.9)
mtext(bquote(paste("               ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.2)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",              ")),line=0.9)
mtext(bquote(paste("               ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- x+rnorm(50,sd=.08)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",              ")),line=0.9)
mtext(bquote(paste("               ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
y <- x
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
mgp=c(1,1,0))
mtext(bquote(paste(r==.(round(cor(x,y),2)),",          ")),line=0.9)
mtext(bquote(paste("           ",
  R^2==.(round(summary(lm(y~x))$r.squared,2)))),line=1)
lines(x,fitted(lm(y~x)))
par(oldpar)
dev.off()

# 2.3.3: Slope parameter

# slrpopulation

postscript("manuscript/figures/slrpopulation.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,2,2)+0.1)
x <- runif(50,min(Floor),max(Floor))
y <- 190.3+40.8*x+rnorm(50,sd=3)
x <- c(Floor,x)
y <- c(Price,y)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
     xlim=c(1.65,2.3),ylim=c(259,286),mgp=c(1,1,0))
lines(sort(x),(fitted(lm(y~x)))[order(x)],lty=2)
lines(sort(x),190.3+40.8*sort(x))
points(Floor,Price,pch=19)
text(1.95,278.5,expression(E(Y)==b[0]+b[1]*X))
arrows(1.95,276,2.053,273.5,0,lwd=0.5)
text(2.1,269,expression(Y==b[0]+b[1]*X+e))
#text(2.13,272.7,expression(e),bg="white")
arrows(2.053,270,2.053,273.5,0.1,code=3,lwd=0.5)
text(1.95,277,"(expected value)")
text(2.1,267.5,"(population value)")
text(2.14,271.5,"e (random error)")
par(oldpar)
dev.off()

qt(0.95,3) # 2.353363
qt(0.995,3) # 5.840909
qt(0.999,3) # 10.21453
qt(0.975,3) # 3.182446

# slopetest

postscript("manuscript/figures/slopetest.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
plot(Floor,Price,xlab="X",ylab="Y",xaxt="n",yaxt="n",
     xlim=c(1.65,2.3),ylim=c(259,286),mgp=c(1,1,0))
for(i in 1:100)
lines(Floor,268.94+rt(1,3)*summary(lm(Price~Floor))$coefficients[2,2]*(Floor-1.927),
      col="gray",lwd=.5)
lines(Floor,fitted(model1))
points(Floor,Price)
par(oldpar)
dev.off()

Age <- seq(15,24,b=1)
#Length <- 64+Age + round(rnorm(10,0,.5),1)
Length <- c(79.2,79.9,80.8,82.1,82.8,83.5,84.2,86.3,87.1,88.5)

plot(Age,Length)

summary(lm(Length~Age))
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 63.51455    0.87636   72.47 1.46e-12 ***
#Age          1.02182    0.04446   22.98 1.36e-08 ***

lines(Age,fitted(lm(Length~Age)))

summary(lm(Length~Age-1))
#Coefficients:
#    Estimate Std. Error t value Pr(>|t|)    
#Age   4.2098     0.1566   26.88 6.62e-10 ***

lines(Age,fitted(lm(Length~Age-1)))

# slope confidence interval

qt(0.975,3) # 3.182446
3.182*5.684 # 18.08649
40.8+c(-1,1)*18.086 # 22.714 58.886

confint(model1)
#                2.5 %    97.5 %
#(Intercept) 155.23828 225.39804
#Floor        22.71243  58.88782

qt(.95,3) # 2.353363
2.353*5.684 # 13.37445
40.8+c(-1,1)*13.374 # 27.426 54.174

confint(model1, level=.9)
#                  5 %      95 %
#(Intercept) 164.37720 216.25911
#Floor        27.42459  54.17566

# 2.4: Model Assumptions

# errordistribution

x <- c(0,2,4,6)
y <- c(1,2,3,4)
postscript("manuscript/figures/errordistribution.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
  mgp=c(1,1,0),xlim=c(0,7),ylim=c(0.5,4.5),type="l")
text(6,4.2,expression(E(Y)==b[0]+b[1]*X))
for(i in 1:5){
lines(i+1.5*dnorm(seq(-3,3,length=30)),
      seq(.5*i+.2,.5*i+1.8,length=30),lwd=.5)
lines(c(i,i),c(.5*i+.2,.5*i+1.8),lwd=.5)}
points(c(1,2,3,4,5),c(1.3,2.1,2.8,2.9,3.4),pch=19)
par(oldpar)
dev.off()

# residualspass12

x <- sort(runif(50))
postscript("manuscript/figures/residualspass12.eps",
           width = 5.0, height = 5.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:12,4,3,byrow=T))
for(i in 1:12){
y <- x+rnorm(50,sd=.05)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))}
par(oldpar)
dev.off()

# residualsfail12

postscript("manuscript/figures/residualsfail12.eps",
           width = 5.0, height = 5.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:12,4,3,byrow=T))
y <- x^2+rnorm(50,sd=.05)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y <- -x^2+rnorm(50,sd=.05)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y <- (x-.5)^3+rnorm(50,sd=.01)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y <- x+x*rnorm(50,sd=.03)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y <- x+(1-x)*rnorm(50,sd=.03)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y <- x+c(rnorm(15,sd=.1),rnorm(20,sd=.01),rnorm(15,sd=.1))
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y7 <- x+.05*rt(50,df=2)
plot(x,residuals(lm(y7~x)),xlab="X",ylab="residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y8 <- x+.03*(rchisq(50,1)-.5)
plot(x,residuals(lm(y8~x)),xlab="X",ylab="residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y9 <- x-.03*(rchisq(50,1)-.5)
plot(x,residuals(lm(y9~x)),xlab="X",ylab="residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(c(0,1),c(0,0))
y[1] <- x[1]+rnorm(1,sd=.03)
for(j in 2:50)
y[j] <- .7*y[j-1]+x[j]+rnorm(1,sd=.03)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
lines(x,residuals(lm(y~x)),lwd=.5)
y[1] <- rnorm(1,sd=.04)
for(j in 2:50)
y[j] <- -.9*y[j-1]+x[j]-.5+rnorm(1,sd=.04)
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
lines(x,residuals(lm(y~x)),lwd=.5)
y <- .5-sin(x)+rnorm(50,sd=.005)
y[15:17]<-y[15:17]+.09
y[32:34]<-y[32:34]+.1
plot(x,residuals(lm(y~x)),xlab="X",ylab="residuals",xaxt="n",yaxt="n",
mgp=c(1,1,0))
lines(c(0,1),c(0,0))
par(oldpar)
dev.off()

# residualshist6

postscript("manuscript/figures/residualshist6.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:6,2,3,byrow=T))
y1 <- x+rnorm(50,sd=.05)
hist(residuals(lm(y1~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y1~x))),max(residuals(lm(y1~x))),
  length=10),
mgp=c(1,1,0),ylab="")
y2 <- x+rnorm(50,sd=.05)
hist(residuals(lm(y2~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y2~x))),max(residuals(lm(y2~x))),
  length=10),
mgp=c(1,1,0),ylab="")
y3 <- x+rnorm(50,sd=.05)
hist(residuals(lm(y3~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y3~x))),max(residuals(lm(y3~x))),
  length=10),
mgp=c(1,1,0),ylab="")
hist(residuals(lm(y7~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y7~x))),max(residuals(lm(y7~x))),
  length=10),
mgp=c(1,1,0),ylab="")
hist(residuals(lm(y8~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y8~x))),max(residuals(lm(y8~x))),
  length=10),
mgp=c(1,1,0),ylab="")
hist(residuals(lm(y9~x)),main="",xaxt="n",yaxt="n",xlab="residuals",
breaks=seq(min(residuals(lm(y9~x))),max(residuals(lm(y9~x))),
  length=10),
mgp=c(1,1,0),ylab="")
par(oldpar)
dev.off()

# residualsqq6

postscript("manuscript/figures/residualsqq6.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:6,2,3,byrow=T))
qqnorm(residuals(lm(y1~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y1~x)))
qqnorm(residuals(lm(y2~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y2~x)))
qqnorm(residuals(lm(y3~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y3~x)))
qqnorm(residuals(lm(y7~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y7~x)))
qqnorm(residuals(lm(y8~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y8~x)))
qqnorm(residuals(lm(y9~x)),main="",xaxt="n",yaxt="n",xlab="normal quantiles",
ylab="residual quantiles",mgp=c(1,1,0))
qqline(residuals(lm(y9~x)))
par(oldpar)
dev.off()

# 2.5: Model interpretation

# salesinterpret

postscript("manuscript/figures/salesinterpret.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special") 
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Floor,Price,xlab="Floor = floor size (in thousands of square feet)",
     ylab="Price = sale price (in thousands of dollars)",
     xlim=c(1.65,2.3),ylim=c(259,286))
lines(Floor,fitted(model1))
text(2.08,280,expression(widehat(Price)==190.3+40.8*Floor))
par(oldpar)
dev.off()

# 2.6: Estimation and prediction

round(predict(model1, newdata=data.frame(Floor=2), interval="confidence"), 3)
#      fit     lwr     upr
#1 271.918 267.739 276.098

round(predict(model1, newdata=data.frame(Floor=2), interval="confidence", se.fit=T)$se.fit, 3)
# 1.313

190.3+40.8*2 # 271.9
qt(.975,3) # 3.182446
3.182*1.313 # 4.177966
271.9+c(-1,1)*4.178 # 267.722 276.078

round(predict(model1, interval="confidence"), 3)
#      fit     lwr     upr
#1 258.985 253.051 264.918
#2 260.005 254.400 265.610
#3 268.736 264.769 272.703
#4 274.081 269.507 278.655
#5 282.894 275.546 290.242

round(predict(model1, interval="confidence", se.fit=T)$se.fit, 3)
# 1.864 1.761 1.246 1.437 2.309

qt(.95,3) # 2.353363
2.353*1.313 # 3.089489
271.9+c(-1,1)*3.089 # 268.811 274.989

round(predict(model1, newdata=data.frame(Floor=2), interval="prediction"), 3)
#      fit     lwr     upr
#1 271.918 262.115 281.722

round(sqrt(summary(model1)$sigma^2 + predict(model1, newdata=data.frame(Floor=2), interval="prediction", se.fit=T)$se.fit^2), 3)
# 3.08

190.3+40.8*2 # 271.9
qt(.975,3) # 3.182446
3.182*3.08 # 9.80056
271.9+c(-1,1)*9.801 # 262.099 281.701

round(predict(model1, interval="prediction"), 3)
#      fit     lwr     upr
#1 258.985 248.315 269.655
#2 260.005 249.514 270.496
#3 268.736 259.021 278.451
#4 274.081 264.103 284.059
#5 282.894 271.377 294.410

qt(.95,3) # 2.353363
2.353*3.08 # 7.24724
271.9+c(-1,1)*7.247 # 264.653 279.147

detach(homes2)

# slrpredict

postscript("manuscript/figures/slrpredict.eps",
           width = 5.0, height = 3.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
x <- sort(runif(50))
y <- x+rnorm(50,sd=.1)
plot(x,y,xlab="X",ylab="Y",xaxt="n",yaxt="n",
xlim=c(0,1.35),ylim=c(-0.2,1.2),mgp=c(1,1,0))
lines(x,(fitted(lm(y~x)))[order(x)])
ci<-predict(lm(y~x),data.frame(x=seq(min(x),max(x),length=50)),
  interval="confidence")
pi<-predict(lm(y~x),data.frame(x=seq(min(x),max(x),length=50)),
  interval="prediction")
lines(seq(min(x),max(x),length=50),ci[,2],lty=2)
lines(seq(min(x),max(x),length=50),ci[,3],lty=2)
lines(seq(min(x),max(x),length=50),pi[,2],lty=3)
lines(seq(min(x),max(x),length=50),pi[,3],lty=3)
text(1.18,1.18,"upper prediction limit")
text(1.19,1.05,"upper confidence limit")
text(1.13,0.98,expression(E(Y)==b[0]+b[1]*X))
text(1.19,0.91,"lower confidence limit")
text(1.18,0.78,"lower prediction limit")
par(oldpar)
dev.off()

# 2.7: Chapter summary

# body

body <- read.csv("data/body.csv")
attach(body)

postscript("manuscript/figures/body.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Arm, Height, xlab="Arm = Upper Arm Length (in cm)",
     ylab="Height = Standing Height (in cm)")
par(oldpar)
dev.off()

model1 <- lm(Height ~ Arm)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  53.8404     9.7003    5.55 4.35e-07 ***
#Arm           3.0428     0.2568   11.85  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 6.249 on 73 degrees of freedom
#Multiple R-squared: 0.6579,	Adjusted R-squared: 0.6532 
#F-statistic: 140.4 on 1 and 73 DF,  p-value: < 2.2e-16 

round(confint(model1), 4)
#              2.5 %  97.5 %
#(Intercept) 34.5078 73.1731
#Arm          2.5310  3.5546

postscript("manuscript/figures/bodyresid.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Arm,residuals(model1),xlab="Arm = Upper Arm Length (in cm)",
     ylab="Unstandardized residual")
#scatter.smooth(Arm, residuals(model1), span=0.75)
par(oldpar)
dev.off()

postscript("manuscript/figures/bodyhist.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
hist(residuals(model1), main="", xlab="Unstandardized residual",
     breaks=13)
par(oldpar)
dev.off()

postscript("manuscript/figures/bodyqq.eps",
           width=2.5, height=2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
qqnorm(residuals(model1), main="")
qqline(residuals(model1))
par(oldpar)
dev.off()

postscript("manuscript/figures/bodyfit.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Arm, Height, xlab="Arm = Upper Arm Length (in cm)",
     ylab="Height = Standing Height (in cm)")
lines(Arm,fitted(model1))
par(oldpar)
dev.off()

predict(model1, newdata=data.frame(Arm=38), interval="confidence")
#       fit      lwr     upr
#1 169.4661 168.0182 170.914

predict(model1, newdata=data.frame(Arm=38), interval="prediction")
#       fit     lwr      upr
#1 169.4661 156.928 182.0042

detach(body)