# Chapter 2: Simple Linear Regression
# Odd-numbered problems

setwd("~/Teaching/arm3e/")

# 2.1 internet

internet <- read.csv("data/internet.csv")
attach(internet)

model <- lm(Int ~ Gdp)
summary(model)
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 12.36278    1.71827   7.195 1.09e-11 ***
#Gdp          1.36093    0.07975  17.065  < 2e-16 ***

predict(model, data.frame(Gdp=20))
# 39.58131

postscript("insman/internetplot1.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gdp,Int,xlab="GDP per capita (in thousands of US dollars)",
     ylab="Percentage of Internet users")
lines(sort(Gdp),fitted(model)[order(Gdp)])
par(oldpar)
dev.off()

detach(internet)

# 2.3 exams

midterm <- c(95, 90, 85, 85, 80, 75)
final <- c(91, 94, 88, 70, 82, 67)
model <- lm(final ~ midterm)
summary(model)
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -20.0000    44.2945  -0.452   0.6750  
# midterm       1.2000     0.5196   2.309   0.0821 .
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 8.216 on 4 degrees of freedom
# Multiple R-squared:  0.5714,	Adjusted R-squared:  0.4643 
# F-statistic: 5.333 on 1 and 4 DF,  p-value: 0.08209

predict(model)
#  1  2  3  4  5  6 
# 94 88 82 82 76 70 

resid(model)
#  1   2   3   4   5   6 
# -3   6   6 -12   6  -3

rss <- sum(resid(model)^2)
rss # 270

sqrt(rss/(6-2)) # 8.215838

mean(final) # 82
final-mean(final)
# [1]   9  12   6 -12   0 -15
tss <- sum((final-mean(final))^2)
tss # 630

1-rss/tss # 0.5714286

# 2.5 psychology

# n <- 10

# pscore <- round(runif(n, 10, 20), 0)
# pscore
# 16 13 12 16 15 16 19 12 11 20

pscore <- c(16, 13, 12, 16, 15, 16, 19, 12, 11, 20)

# ascore <- round(5 + 0.8*pscore + rnorm(n, 0, 2), 0)
# ascore - 2
# 12 15 10 18 14 19 20 15 12 16

ascore <- c(12, 15, 10, 18, 14, 19, 20, 15, 12, 16)

model <- lm(ascore ~ pscore)

postscript("insman/psychology.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(pscore,ascore,xlab="Personality score",
     ylab="Aptitude test score")
lines(sort(pscore),fitted(model)[order(pscore)])
par(oldpar)
dev.off()

summary(model)
# Coefficients:
# Estimate Std. Error t value Pr(>|t|)  
# (Intercept)   4.8561     4.4878   1.082   0.3108  
# pscore        0.6829     0.2939   2.324   0.0486 *
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 2.661 on 8 degrees of freedom
# Multiple R-squared:  0.403,	Adjusted R-squared:  0.3284 
# F-statistic:   5.4 on 1 and 8 DF,  p-value: 0.04863

qt(0.975, 8) # 2.306004

predict(model, data.frame(pscore=18)) # 17.14878

4.856 + 0.683*18 # 17.15

# 2.7 electricity

electricity <- read.csv("data/electricity.csv")
attach(electricity)

model <- lm(Elec ~ Gdp)
summary(model)
#(Intercept) -82.26554   45.35351  -1.814   0.0804 .  
#Gdp           0.28249    0.01255  22.500   <2e-16 ***

postscript("insman/electricityplot1.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gdp,Elec,xlab="GDP (purchasing power parity, $ billions)",
     ylab="Electricity consumption (billion kWh)")
lines(sort(Gdp),fitted(model)[order(Gdp)])
text(11800, 3873, "United States")
text(8800, 3438, "China")
par(oldpar)
dev.off()

identify(Gdp,Elec)
Country[c(29,4)]
# United States China

detach(electricity)

electricity.x2 <- electricity[electricity$Country!="United States"&
                                electricity$Country!="China",]

attach(electricity.x2)

model <- lm(Elec ~ Gdp)
summary(model)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 14.27579   29.11331    0.49    0.628    
#Gdp          0.18596    0.01752   10.62 6.01e-11 ***

postscript("insman/electricityplot2.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gdp,Elec,xlab="GDP (purchasing power parity, $ billions)",
     ylab="Electricity consumption (billion kWh)")
lines(sort(Gdp),fitted(model)[order(Gdp)])
text(1850, 858, "Russia")
text(3750, 568, "India")
par(oldpar)
dev.off()

identify(Gdp,Elec)
Country[c(20,10)]
# Russia India

detach(electricity.x2)

# 2.9 cars2

cars2 <- read.csv("data/cars2.csv")
attach(cars2)

Cgphm <- 100/Cmpg
mean(Cgphm) # 4.613156

model1 <- lm(Cgphm ~ Eng)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   2.5894     0.1026   25.24   <2e-16 ***
#Eng           0.8183     0.0397   20.61   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.3351 on 125 degrees of freedom
#Multiple R-squared: 0.7726,	Adjusted R-squared: 0.7708 
#F-statistic: 424.8 on 1 and 125 DF,  p-value: < 2.2e-16 

postscript("insman/cars2plot1.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Eng,Cgphm,xlab="Eng = Engine Size (liters)",
     ylab="Cgphm = City Gallons per Hundred Miles")
lines(sort(Eng),fitted(model1)[order(Eng)])
par(oldpar)
dev.off()

model2 <- lm(Cgphm ~ Vol)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   1.8760     0.5337   3.515 0.000613 ***
#Vol           2.5010     0.4849   5.157 9.53e-07 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.6382 on 125 degrees of freedom
#Multiple R-squared: 0.1755,	Adjusted R-squared: 0.1689 
#F-statistic:  26.6 on 1 and 125 DF,  p-value: 9.527e-07 

postscript("insman/cars2plot2.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Vol, Cgphm,xlab="Vol = Passenger/Cargo Volume (cu ft)",
     ylab="Cgphm = City Gallons per Hundred Miles")
lines(sort(Vol),fitted(model2)[order(Vol)])
par(oldpar)
dev.off()

detach(cars2)

# 2.11 compare

compare <- read.csv("data/compare.csv")
attach(compare)

model1 <- lm (Y ~ X1)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.57049    0.37571    4.18 0.000123 ***
#X1           1.07647    0.07611   14.14  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 1.07 on 48 degrees of freedom
#Multiple R-squared: 0.8065,	Adjusted R-squared: 0.8024 
#F-statistic:   200 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/compare1.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(X1, Y)
lines(X1, fitted(model1))
par(oldpar)
dev.off()

model2 <- lm (Y ~ X2)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  2.42555    0.30323   7.999 2.21e-10 ***
#X2           0.88722    0.05906  15.023  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 1.019 on 48 degrees of freedom
#Multiple R-squared: 0.8246,	Adjusted R-squared: 0.821 
#F-statistic: 225.7 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/compare2.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(X2, Y)
lines(X2, fitted(model2))
par(oldpar)
dev.off()

model3 <- lm (Y ~ X3)
summary(model3)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  2.11793    0.32146   6.589 3.15e-08 ***
#X3           0.98766    0.06576  15.020  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.019 on 48 degrees of freedom
#Multiple R-squared: 0.8246,	Adjusted R-squared: 0.8209 
#F-statistic: 225.6 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/compare3.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(X3, Y)
lines(X3, fitted(model3))
par(oldpar)
dev.off()

model4 <- lm (Y ~ X4)
summary(model4)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  2.85659    0.27838   10.26 1.08e-13 ***
#X4           0.90016    0.05993   15.02  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.019 on 48 degrees of freedom
#Multiple R-squared: 0.8245,	Adjusted R-squared: 0.8209 
#F-statistic: 225.6 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/compare4.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(X4, Y)
lines(X4, fitted(model4))
par(oldpar)
dev.off()

detach(compare)

# 2.15 psychology

pscore <- c(16, 13, 12, 16, 15, 16, 19, 12, 11, 20)
ascore <- c(12, 15, 10, 18, 14, 19, 20, 15, 12, 16)

model <- lm(ascore ~ pscore)
summary(model)
# Coefficients:
# Estimate Std. Error t value Pr(>|t|)  
# (Intercept)   4.8561     4.4878   1.082   0.3108  
# pscore        0.6829     0.2939   2.324   0.0486 *
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 2.661 on 8 degrees of freedom
# Multiple R-squared:  0.403,	Adjusted R-squared:  0.3284 
# F-statistic:   5.4 on 1 and 8 DF,  p-value: 0.04863

4.856 + 0.683*18 # 17.15
qt(0.975, 8) # 2.306004
17.15 + c(-1, 1)*2.306*1.219 # 14.33899 19.96101
19.96101-14.33899 # 5.62202

predict(model, data.frame(pscore=18), se.fit=T, interval="confidence")
# $fit
# fit     lwr      upr
# 1 17.14878 14.3382 19.95936
# 
# $se.fit
# [1] 1.218809
# 
# $df
# [1] 8
# 
# $residual.scale
# [1] 2.661205

sqrt(1.219^2 + 2.661^2) # 2.926924
17.15 + c(-1, 1)*2.306*2.927 # 10.40034 23.89966
23.89966-10.40034 # 13.49932

predict(model, data.frame(pscore=18), interval="prediction")
#        fit      lwr      upr
# 1 17.14878 10.39904 23.89852

# 2.17 cars2

cars2 <- read.csv("data/cars2.csv")
attach(cars2)

Cgphm <- 100/Cmpg

model1 <- lm(Cgphm ~ Eng)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   2.5894     0.1026   25.24   <2e-16 ***
#Eng           0.8183     0.0397   20.61   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 0.3351 on 125 degrees of freedom
#Multiple R-squared: 0.7726,	Adjusted R-squared: 0.7708 
#F-statistic: 424.8 on 1 and 125 DF,  p-value: < 2.2e-16 

qt(0.975, 125) # 1.979124
0.8183 + c(-1,1)*1.979*0.0397 # 0.7397337 0.8968663

confint(model1)
#                2.5 %    97.5 %
#(Intercept) 2.3863697 2.7924758
#Eng         0.7396795 0.8968317

predict(model1, newdata=data.frame(Eng=3), interval="confidence")
#      fit      lwr      upr
#1 5.04419 4.972238 5.116142

predict(model1, newdata=data.frame(Eng=3), interval="prediction")
#      fit      lwr      upr
#1 5.04419 4.377044 5.711335

detach(cars2)