# Chapter 3: Multiple Linear Regression

setwd("~/Teaching/arm3e/")

# 3.1: Probability model for (X1, X2, ...) and Y

# mlrmodel

library(lattice)

g<-expand.grid(Party=seq(0,1,.1),Study=seq(0,1,.1))
g$Exam<-70-20*g$Party+20*g$Study
cexmult=.6
postscript("manuscript/figures/mlrmodel.eps",
           width = 5.0, height = 5.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(1,1,1,1)+0.1)
wireframe(Exam~Party*Study,data=g,drape=T,col.regions=gray(20:100 / 100),
  xlab = list(cex=cexmult),
  ylab = list(cex=cexmult),
  zlab = list(cex=cexmult),
  colorkey = list(labels=list(cex=cexmult)),
  panel=function(x,y,z,...){
  panel.wireframe(x,y,z,...)
  lpoints(.088,-.066,col="black",cex=cexmult)
  lpoints(.088,-.011,pch=19,col="black",cex=cexmult)
  larrows(.088,-.066,.088,-.011,length=0.08,code=3,lwd=0.5,angle=20)
  lpoints(-.066,.059,col="black",cex=cexmult)
  lpoints(-.066,.088,pch=19,col="black",cex=cexmult)
  larrows(-.066,.059,-.066,.088,length=0,lwd=0.5)
  lpoints(.018,.046,col="black",cex=cexmult)
  lpoints(.018,.066,pch=19,col="black",cex=cexmult)
  larrows(.018,.046,.018,.066,length=0,lwd=0.5)
  lpoints(.035,-.068,col="black",cex=cexmult)
  lpoints(.035,-.102,pch=19,col="black",cex=cexmult)
  larrows(.035,-.079,.035,-.102,length=0,lwd=0.5)
  larrows(.035,-.068,.035,-.079,length=0,lwd=0.5,lty=2)
  lpoints(-.033,-.002,col="black",cex=cexmult)
  lpoints(-.033,-.064,pch=19,col="black",cex=cexmult)
  larrows(-.033,-.048,-.033,-.064,length=0,lwd=0.5)
  larrows(-.033,-.002,-.033,-.048,length=0,lwd=0.5,lty=2)
  ltext(-.010,-0.185,"(0,0,50)",cex=cexmult)
  ltext(.090,0.012,"observed",cex=cexmult)
  ltext(.090,0.000,"response",cex=cexmult)
  ltext(.112,-0.038,"error",cex=cexmult)
  ltext(.088,-0.094,"fitted value",cex=cexmult)})
par(oldpar)
dev.off()

# 3.2: Least squares criterion

# splomcar

homes3 <- read.csv("data/homes3.csv")
attach(homes3)

model1 <- lm(Price ~ Floor + Lot)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  122.357     14.786   8.275  0.00370 **
#Floor         61.976      6.113  10.139  0.00204 **
#Lot            7.091      1.281   5.535  0.01162 * 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 2.475 on 3 degrees of freedom
#Multiple R-squared: 0.9717,	Adjusted R-squared: 0.9528 
#F-statistic: 51.43 on 2 and 3 DF,  p-value: 0.00477 

postscript("manuscript/figures/splomhomes3.eps",
           width = 4.0, height = 4.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
#oldpar <- par(mar=c(2,2,2,2)+0.1)
#splom(~cbind(Price, Floor, Lot))
pairs(cbind(Price, Floor, Lot), cex.labels=1.5)
#par(oldpar)
dev.off()

# 3.3: Model evaluation

model2 <- lm(Price ~ Floor)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)    184.0       28.2   6.526  0.00285 **
#Floor           42.8       14.6   2.931  0.04277 * 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 7.178 on 4 degrees of freedom
#Multiple R-squared: 0.6823,	Adjusted R-squared: 0.6029 
#F-statistic: 8.591 on 1 and 4 DF,  p-value: 0.04277 

detach(homes3)

# shipdept

shipdept <- read.csv("data/shipdept.csv")
attach(shipdept)

model1 <- lm(Lab ~ Tws + Pst + Asw + Num)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  95.4150    30.0358   3.177  0.00626 **
#Tws           6.0739     2.6625   2.281  0.03755 * 
#Pst           8.4347     8.8702   0.951  0.35673   
#Asw          -1.7460     0.7602  -2.297  0.03645 * 
#Num          -0.1245     0.3799  -0.328  0.74768   
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 9.103 on 15 degrees of freedom
#Multiple R-squared: 0.8196,	Adjusted R-squared: 0.7715 
#F-statistic: 17.03 on 4 and 15 DF,  p-value: 1.889e-05 

model2 <- lm(Lab ~ Tws + Asw)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 110.4311    24.8556   4.443 0.000357 ***
#Tws           5.0007     2.2607   2.212 0.040948 *  
#Asw          -2.0122     0.6675  -3.014 0.007810 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 8.815 on 17 degrees of freedom
#Multiple R-squared: 0.8082,	Adjusted R-squared: 0.7857 
#F-statistic: 35.83 on 2 and 17 DF,  p-value: 8.008e-07 

detach(shipdept)

# sales2

sales2 <- read.csv("data/sales2.csv")
attach(sales2)

postscript("manuscript/figures/sales1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Advert, Sales, xlab="Advert = annual advertising (in $m)",
     ylab="Sales = annual sales (in $m)")
par(oldpar)
dev.off()

cor(Sales,Advert) # 0.1651257

detach(sales2)

# sales3

sales3 <- read.csv("data/sales3.csv") 
attach(sales3)

postscript("manuscript/figures/sales4.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Trad, Sales, xlab="Trad = annual traditional advertising (in $m)",
     ylab="Sales = annual sales (in $m)")
par(oldpar)
dev.off()

cor(Sales,Trad) # 0.9857635

detach(sales3)

# 3.3.3: Regression parameters - global usefulness test

# Fcurvereject

postscript("manuscript/figures/Fcurvereject.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(1,1,1,1)+0.1)
x <- seq(0,3.5,len=100)
plot(x,df(x,df1=5,df2=30),type="l",xlab="",ylab="",
     ylim=c(.0,.75),
     yaxt="n",xaxt="n",bty="n",
     main="F-test: reject null", cex.main=1)
lines(c(0,3.5),c(0,0))
lines(c(0,0),c(0,.75))
text(0,-0.03,"0",xpd=NA)
x <- seq(2.5,3.5,len=20)
y <- df(x,df1=5,df2=30)
x <- c(x,3.5,2.5,2.5)
y <- c(y,0,0,df(2.5,df1=5,df2=30))
polygon(x,y,density=15)
x <- seq(3.0,3.5,len=20)
y <- df(x,df1=5,df2=30)
x <- c(x,3.5,3.0,3.0)
y <- c(y,0,0,df(3.0,df1=5,df2=30))
polygon(x,y,density=15,angle=-45)
lines(c(3.5,3.5),c(0,df(3.5,df1=5,df2=30)),col="white")
text(2.9,0.2,"significance")
text(2.9,0.18,"level")
arrows(2.9,0.16,2.7,0.03,0,lwd=.5)
text(3.2,0.14,"p-value")
arrows(3.2,0.12,3.3,0.01,0,lwd=.5)
text(2.35,-0.03,"critical value",xpd=NA)
text(3.15,-0.03,"test statistic",xpd=NA)
par(oldpar)
dev.off()

# homes3

homes3 <- read.csv("data/homes3.csv")
attach(homes3)

model1 <- lm(Price ~ Floor + Lot)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  122.357     14.786   8.275  0.00370 **
#Floor         61.976      6.113  10.139  0.00204 **
#Lot            7.091      1.281   5.535  0.01162 * 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 2.475 on 3 degrees of freedom
#Multiple R-squared: 0.9717,	Adjusted R-squared: 0.9528 
#F-statistic: 51.43 on 2 and 3 DF,  p-value: 0.00477 

model0 <- lm(Price ~ 1)
anova(model0,model1)
#  Res.Df    RSS Df Sum of Sq      F  Pr(>F)   
#1      5 648.64                               
#2      3  18.38  2    630.26 51.434 0.00477 **

tss <- sum((Price-mean(Price))^2)
tss # 648.64
rss <- sum((Price-fitted(model1))^2)
rss # 18.3807
tss-rss # 630.2593
(tss-rss)/2 # 315.1296
rss/3 # 6.126901
((tss-rss)/2)/(rss/3) # 51.43378
pf(((tss-rss)/2)/(rss/3),2,3, lower.tail=F) # 0.004770211
qf(.95,2,3) # 9.552094

detach(homes3)

# shipdept

shipdept <- read.csv("data/shipdept.csv")
attach(shipdept)

model1 <- lm(Lab ~ Tws + Pst + Asw + Num)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  95.4150    30.0358   3.177  0.00626 **
#Tws           6.0739     2.6625   2.281  0.03755 * 
#Pst           8.4347     8.8702   0.951  0.35673   
#Asw          -1.7460     0.7602  -2.297  0.03645 * 
#Num          -0.1245     0.3799  -0.328  0.74768   
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 9.103 on 15 degrees of freedom
#Multiple R-squared: 0.8196,	Adjusted R-squared: 0.7715 
#F-statistic: 17.03 on 4 and 15 DF,  p-value: 1.889e-05 

model0 <- lm(Lab ~ 1)
anova(model0,model1)
#   Res.Df    RSS Df Sum of Sq      F    Pr(>F)    
# 1     19 6888.9                                  
# 2     15 1242.9  4    5646.1 17.035 1.889e-05 ***
  
tss <- sum((Lab-mean(Lab))^2)
tss # 6888.95
rss <- sum((Lab-fitted(model1))^2)
rss # 1242.898
tss-rss # 5646.052
(tss-rss)/4 # 1411.513
rss/15 # 82.85986
((tss-rss)/4)/(rss/15) # 17.03494
pf(((tss-rss)/4)/(rss/15),4,15, lower.tail=F) # 1.889006e-05
qf(.95,4,15) # 3.055568

# 3.3.4: Regression parameters - nested model test

model2 <- lm(Lab ~ Tws + Asw)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 110.4311    24.8556   4.443 0.000357 ***
#Tws           5.0007     2.2607   2.212 0.040948 *  
#Asw          -2.0122     0.6675  -3.014 0.007810 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 8.815 on 17 degrees of freedom
#Multiple R-squared: 0.8082,	Adjusted R-squared: 0.7857 
#F-statistic: 35.83 on 2 and 17 DF,  p-value: 8.008e-07 

sum((Lab-mean(Lab))^2)-sum((Lab-fitted(model2))^2) # 5567.889
sum((Lab-fitted(model2))^2) # 1321.061
sum((Lab-mean(Lab))^2) # 6888.95
(sum((Lab-mean(Lab))^2)-sum((Lab-fitted(model2))^2))/2 # 2783.945
sum((Lab-fitted(model2))^2)/17 # 77.70945
((sum((Lab-mean(Lab))^2)-sum((Lab-fitted(model2))^2))/2)/
  (sum((Lab-fitted(model2))^2)/17) # 35.82505
pf(((sum((Lab-mean(Lab))^2)-sum((Lab-fitted(model2))^2))/2)/
     (sum((Lab-fitted(model2))^2)/17),2,17, lower.tail=F) # 8.008345e-07

qf(.95,2,15) # 3.68232

anova(model2, model1)
#  Res.Df    RSS Df Sum of Sq      F Pr(>F)
#1     17 1321.1                           
#2     15 1242.9  2    78.163 0.4717 0.6329

1321.061-1242.898 # 78.163
((1321.061-1242.898)/(4-2)) / (1242.898/15) # 0.4716578

# Sequential sums of squares

model1r <- lm(Lab ~ Tws + Asw + Pst + Num)
print(anova(model1r), digits=7)
# Analysis of Variance Table
# 
# Response: Lab
# Df   Sum Sq  Mean Sq  F value     Pr(>F)    
# Tws        1 4861.741 4861.741 58.67426 1.4641e-06 ***
# Asw        1  706.148  706.148  8.52219   0.010573 *  
# Pst        1   69.266   69.266  0.83594   0.375024    
# Num        1    8.897    8.897  0.10737   0.747682    
# Residuals 15 1242.898   82.860                        
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

69.266+8.897 # 78.163

# 3.3.5: Regression parameters - individual tests

summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  95.4150    30.0358   3.177  0.00626 **
#Tws           6.0739     2.6625   2.281  0.03755 * 
#Pst           8.4347     8.8702   0.951  0.35673   
#Asw          -1.7460     0.7602  -2.297  0.03645 * 
#Num          -0.1245     0.3799  -0.328  0.74768   
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 9.103 on 15 degrees of freedom
#Multiple R-squared: 0.8196,	Adjusted R-squared: 0.7715 
#F-statistic: 17.03 on 4 and 15 DF,  p-value: 1.889e-05 

6.074/2.662 # 2.281743
qt(0.975, 15) # 2.13145
2*pt(2.28, 15, lower.tail=F) # 0.03765023

model3 <- lm(Lab ~ Pst + Asw + Num)
anova(model3, model1)
#  Res.Df    RSS Df Sum of Sq      F  Pr(>F)  
#1     16 1674.1                              
#2     15 1242.9  1    431.24 5.2044 0.03755 *

# Regression parameter confidence intervals

qt(0.975,15) # 2.13145
2.131*2.662 # 5.672722
6.074 + c(-1,1)*5.673 # 0.401 11.747

confint(model1)
#                  2.5 %      97.5 %
#(Intercept)  31.3952143 159.4346889
#Tws           0.3990298  11.7487955
#Pst         -10.4716924  27.3410063
#Asw          -3.3662966  -0.1257046
#Num          -0.9343077   0.6853138

11.7487955-0.3990298 # 11.34977
-0.1257046--3.3662966 # 3.240592

confint(model2)
#                2.5 %      97.5 %
#(Intercept) 57.990304 162.8719430
#Tws          0.230959   9.7704540
#Asw         -3.420478  -0.6038597

9.7704540-0.230959 # 9.539495
-0.6038597--3.420478 # 2.816618

qt(0.95,15) # 1.75305
1.753*2.662 # 4.666486
6.074 + c(-1,1)*4.666 # 1.408 10.740

confint(model1, level=0.9)
#                   5 %       95 %
#(Intercept) 42.7607269 148.069176
#Tws          1.4064996  10.741326
#Pst         -7.1152220  23.984536
#Asw         -3.0786432  -0.413358
#Num         -0.7905409   0.541547

qt(0.95,17) # 1.739607
1.740*2.261 # 3.93414
5.001 + c(-1,1)*3.934 # 1.067 8.935

confint(model2, level=0.9)
#                  5 %        95 %
#(Intercept) 67.192082 153.6701645
#Tws          1.067906   8.9335075
#Asw         -3.173363  -0.8509754

detach(shipdept)

# Correlation revisited

# sales2

sales2 <- read.csv("data/sales2.csv")
attach(sales2)

cor(Sales,Advert) # 0.1651257

summary(lm(Sales ~ Advert + Stores))
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  -4.7694     0.8198  -5.818 0.000254 ***
#Advert        1.0530     0.1142   9.221 7.00e-06 ***
#Stores        5.6452     0.2151  26.242 8.18e-10 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.8186 on 9 degrees of freedom
#Multiple R-squared: 0.9875,	Adjusted R-squared: 0.9847 
#F-statistic: 354.1 on 2 and 9 DF,  p-value: 2.778e-09 

postscript("manuscript/figures/sales1a.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Advert, Sales, xlab="Advert = annual advertising (in $m)",
     ylab="Sales = annual sales (in $m)", type="n")
for (i in 1:12)
  points(Advert[i], Sales[i], pch=as.character(Stores[i]))
legend("bottomright", legend="Points marked by Stores = # of stores",
       inset = .02, x.intersp = 0, cex = .8)
par(oldpar)
dev.off()

# partial correlation
cor(resid(lm(Sales ~ Stores)), resid(lm(Advert ~ Stores)))
# 0.9509368

detach(sales2)

# sales3

sales3 <- read.csv("data/sales3.csv") 
attach(sales3)

cor(Sales,Trad) # 0.9857635

summary(lm(Sales ~ Trad + Int))
#            Estimate Std. Error t value Pr(>|t|)  
#(Intercept)   1.9921     0.9016   2.210   0.0545 .
#Trad          1.2748     0.7367   1.730   0.1176  
#Int           0.7672     0.8683   0.884   0.3999  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.8916 on 9 degrees of freedom
#Multiple R-squared: 0.974,	Adjusted R-squared: 0.9682 
#F-statistic: 168.5 on 2 and 9 DF,  p-value: 7.386e-08 

postscript("manuscript/figures/sales4a.eps",
           width = 4.0, height = 4.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Sales, Trad, Int), cex.labels=1.5)
dev.off()

summary(lm(Sales ~ Trad))
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   2.6245     0.5422   4.841 0.000681 ***
# Trad          1.9190     0.1035  18.540  4.5e-09 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

# Residual standard error: 0.8817 on 10 degrees of freedom
# Multiple R-squared:  0.9717,	Adjusted R-squared:  0.9689 
# F-statistic: 343.7 on 1 and 10 DF,  p-value: 4.497e-09

# partial correlation
cor(resid(lm(Sales ~ Int)), resid(lm(Trad ~ Int))) # 0.4996549

detach(sales3)

# 3.4: Model assumptions

# mlra

#X1 <- runif(50)
#X2 <- runif(50)
#X3 <- runif(50)
#Y <- .5*X1-.5*X2+1*X3+.5*rnorm(50)
#write.table(data.frame(Y,X1,X2,X3), file = "mlra.csv", sep = ",",
#            col.names = NA)

mlra <- read.csv("data/mlra.csv")
attach(mlra)

model1 <- lm(Y ~ X1+X2)
postscript("manuscript/figures/res1.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(X3, residuals(model1), span=0.75,
               xlab="X3",ylab="Model 1 residuals")
par(oldpar)
dev.off()

model2 <- lm(Y ~ X1+X2+X3)
postscript("manuscript/figures/res2.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(X3, residuals(model2), span=0.75,
               xlab="X3",ylab="Model 2 residuals")
par(oldpar)
dev.off()

postscript("manuscript/figures/res12.eps",
           width = 3.1, height = 5.1, pointsize = 10,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:8,4,2,byrow=T))
scatter.smooth(fitted(model2), residuals(model2), span=0.75,
xlab="Model 2 fitted values",ylab="Model 2 residuals",xaxt="n",
yaxt="n",mgp=c(1,1,0))
plot(fitted(model2), residuals(model2),
xlab="Model 2 fitted values",ylab="Model 2 residuals",xaxt="n",
yaxt="n",mgp=c(1,1,0))
scatter.smooth(X1, residuals(model2), span=0.75,
xlab="X1",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
plot(X1, residuals(model2),
xlab="X1",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
scatter.smooth(X2, residuals(model2), span=0.75,
xlab="X2",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
plot(X2, residuals(model2),
xlab="X2",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
scatter.smooth(X3, residuals(model2), span=0.75,
xlab="X3",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
plot(X3, residuals(model2),
xlab="X3",ylab="Model 2 residuals",xaxt="n",yaxt="n",mgp=c(1,1,0))
par(oldpar)
dev.off()

postscript("manuscript/figures/histqq1.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(residuals(model2),main="",
     xlab="Model 2 residuals",
     breaks=seq(min(residuals(model2)),max(residuals(model2)),
       length=10),
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

postscript("manuscript/figures/histqq2.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
qqnorm(residuals(model2),main="",
       xlab="Normal quantiles",
       ylab="Model 2 residual quantiles",mgp=c(2,1,0))
qqline(residuals(model2))
par(oldpar)
dev.off()

# 3.4.2: Testing the model assumptions

summary(lm(residuals(model1)~X3))
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  -0.4700     0.1121  -4.191 0.000118 ***
# X3            1.1143     0.2254   4.943 9.79e-06 ***

summary(lm(residuals(model2)~X3))
#               Estimate Std. Error t value Pr(>|t|)
# (Intercept)  8.791e-17  1.095e-01       0        1
# X3          -2.084e-16  2.201e-01       0        1

X3sq <- X3^2
summary(lm(residuals(model2)~X3+X3sq))
#              Estimate Std. Error t value Pr(>|t|)
# (Intercept) -0.002372   0.163923  -0.014    0.989
# X3           0.015606   0.826114   0.019    0.985
# X3sq        -0.017016   0.867485  -0.020    0.984

detach(mlra)

# 3.5: Model interpretation

# shipdept

shipdept <- read.csv("data/shipdept.csv")
attach(shipdept)

model1 <- lm(Lab ~ Tws + Pst + Asw + Num)
model2 <- lm(Lab ~ Tws + Asw)
anova(model2, model1)
#   Res.Df    RSS Df Sum of Sq      F Pr(>F)
# 1     17 1321.1                           
# 2     15 1242.9  2    78.163 0.4717 0.6329

summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 110.4311    24.8556   4.443 0.000357 ***
#Tws           5.0007     2.2607   2.212 0.040948 *  
#Asw          -2.0122     0.6675  -3.014 0.007810 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 8.815 on 17 degrees of freedom
#Multiple R-squared: 0.8082,	Adjusted R-squared: 0.7857 
#F-statistic: 35.83 on 2 and 17 DF,  p-value: 8.008e-07 

# 3.6: Estimation and prediction

# 3.6.1: Confidence interval for the population mean, E(Y)

predict(model2, newdata=data.frame(Tws=6, Asw=20), interval="confidence")
#       fit      lwr      upr
# 1 100.192 95.35329 105.0307

predict(model2, newdata=data.frame(Tws=6, Asw=20),
        interval="confidence", se.fit=T)$se.fit
# 2.293418

110.431+5.001*6-2.012*20 # 100.197
qt(0.975,17) # 2.109816
2.110*2.293 # 4.83823
100.2 + c(-1,1)*4.838 # 95.362 105.038

predict(model2, newdata=data.frame(Tws=6, Asw=20), interval="confidence", level=0.9)
#       fit      lwr      upr
# 1 100.192 96.20234 104.1816

qt(0.95,17) # 1.739607
1.740*2.293 # 3.98982
100.2 + c(-1,1)*3.990 # 96.21 104.19

# 3.6.2: Prediction interval for an individual Y-value

predict(model2, newdata=data.frame(Tws=6, Asw=20), interval="prediction")
#       fit      lwr      upr
# 1 100.192 80.97421 119.4098

sqrt(summary(model2)$sigma^2 + 
       predict(model2, newdata=data.frame(Tws=6, Asw=20), 
               interval="prediction", se.fit=T)$se.fit^2)
# 9.108744

2.110*9.109 # 19.21999
100.2 + c(-1,1)*19.220 # 80.98 119.42

predict(model2, newdata=data.frame(Tws=6, Asw=20), interval="prediction", level=0.9)
#       fit      lwr      upr
# 1 100.192 84.34635 116.0376

1.740*9.109 # 15.84966
100.2 + c(-1,1)*15.850 # 84.35 116.05

detach(shipdept)