# Chapter 4: Regression Model Building I

setwd("~/Teaching/arm3e/")

# 4.1.1: Natural logarithm transformation for predictors

# tvads

tvads <- read.csv("data/tvads.csv")
attach(tvads)

model1 <- lm(Impress ~ Spend)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept) 22.16269    7.08948   3.126  0.00556 **
#Spend        0.36317    0.09712   3.739  0.00139 **
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 23.5 on 19 degrees of freedom
#Multiple R-squared: 0.424,	Adjusted R-squared: 0.3936 
#F-statistic: 13.98 on 1 and 19 DF,  p-value: 0.001389 

postscript("manuscript/figures/tvads1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Spend, Impress, xlab="Spend = spending (in $m)",
     ylab="Impress = retained impressions (in millions)")
lines(Spend,fitted(model1))
par(oldpar)
dev.off()

logSpend <- log(Spend)

model2 <- lm(Impress ~ logSpend)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  -28.050     15.441  -1.817 0.085093 .  
#logSpend      20.180      4.339   4.650 0.000174 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 21.18 on 19 degrees of freedom
#Multiple R-squared: 0.5323,	Adjusted R-squared: 0.5077 
#F-statistic: 21.63 on 1 and 19 DF,  p-value: 0.0001744 

postscript("manuscript/figures/tvads2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(logSpend, Impress, xlab="logSpend = natural logarithm of spending",
     ylab="Impress = retained impressions")
lines(logSpend,fitted(model2))
par(oldpar)
dev.off()

Spendeffect <- fitted(model2)

postscript("manuscript/figures/tvads3.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Spend), Spendeffect[order(Spend)], xlab="Spend = spending (in $m)",
     ylab=expression(paste("Spend effect = ", -28.1 + 20.2, " logSpend")), type="l")
par(oldpar)
dev.off()

postscript("manuscript/figures/tvads4a.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(Spend,main="",
     xlab="Spend = spending (in $m)",
     breaks=10,
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

postscript("manuscript/figures/tvads4b.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(logSpend,main="",
     xlab="logSpend = natural logarithm of spending",
#     breaks=10,
     seq(1.6,5.3,length=11),
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

detach(tvads)

logX <- rnorm(21, 0, .9)
X <- 2 - exp(logX)

round(range(X),1)
round(range(logX),1)

postscript("manuscript/figures/tvads5a.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(X,main="",
     xlab="X",
#     breaks=10,
     seq(min(X),max(X),length=11),
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

postscript("manuscript/figures/tvads5b.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(logX,main="",
     xlab="log(2-X)",
#     breaks=10,
     seq(min(logX),max(logX),length=11),
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

rm(X, logX)

# 4.1.2: Polynomial transformation for predictors

# homes4

homes4 <- read.csv("data/homes4.csv")
attach(homes4)

model1 <- lm(Price ~ Age)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 299.8856    12.5545  23.887   <2e-16 ***
#Age          -0.3959     0.2950  -1.342    0.184    
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 60.01 on 74 degrees of freedom
#Multiple R-squared: 0.02376,	Adjusted R-squared: 0.01057 
#F-statistic: 1.801 on 1 and 74 DF,  p-value: 0.1837 

round(summary(model1)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)  299.886     12.555  23.887    0.000
#Age           -0.396      0.295  -1.342    0.184

Agesq <- Age^2

model2 <- lm(Price ~ Age + Agesq)
summary(model2)
#              Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 330.410440  15.103397  21.877  < 2e-16 ***
#Age          -2.652629   0.748807  -3.542 0.000695 ***
#Agesq         0.027491   0.008472   3.245 0.001773 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 56.49 on 73 degrees of freedom
#Multiple R-squared: 0.1468,	Adjusted R-squared: 0.1235 
#F-statistic: 6.282 on 2 and 73 DF,  p-value: 0.003039 

round(summary(model2)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)  330.410     15.103  21.877    0.000
#Age           -2.653      0.749  -3.542    0.001
#Agesq          0.027      0.008   3.245    0.002

newAge <- seq(min(Age), max(Age), length=100)
newAgesq <- newAge^2

postscript("manuscript/figures/homes4.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Age, Price, xlab="Age = age (years)",
     ylab="Price = sale price ($ thousands)")
lines(Age,fitted(model1))
lines(newAge, predict(model2, newdata=data.frame(Age = newAge, Agesq = newAgesq)))
par(oldpar)
dev.off()

Agez <- (Age-mean(Age))/sd(Age)
Agezsq <- Agez^2

model2z <- lm(Price ~ Agez + Agezsq)
summary(model2z)
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  270.823      7.954  34.047  < 2e-16 ***
# Agez         -16.344      6.874  -2.378  0.02005 *  
# Agezsq        15.172      4.675   3.245  0.00177 ** 
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 56.49 on 73 degrees of freedom
# Multiple R-squared:  0.1468,	Adjusted R-squared:  0.1235 
# F-statistic: 6.282 on 2 and 73 DF,  p-value: 0.003039

detach(homes4)

# 4.1.3: Reciprocal transformation for predictors

# cars3

cars3 <- read.csv("data/cars3.csv")
attach(cars3)

model1 <- lm(Cmpg ~ Eng)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 27.79944    0.29824   93.21   <2e-16 ***
#Eng         -2.67175    0.08227  -32.47   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.929 on 349 degrees of freedom
#Multiple R-squared: 0.7513,	Adjusted R-squared: 0.7506 
#F-statistic:  1055 on 1 and 349 DF,  p-value: < 2.2e-16 

round(summary(model1)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   27.799      0.298  93.210        0
#Eng           -2.672      0.082 -32.474        0

postscript("manuscript/figures/carguide1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Eng, Cmpg, xlab="Eng = engine size (liters)",
     ylab="Cmpg = city miles per gallon")
lines(Eng,fitted(model1))
par(oldpar)
dev.off()

recEng <- 1/Eng

model2 <- lm(Cmpg ~ recEng)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   9.7028     0.2601   37.30   <2e-16 ***
#recEng       26.7067     0.7204   37.07   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.741 on 349 degrees of freedom
#Multiple R-squared: 0.7975,	Adjusted R-squared: 0.7969 
#F-statistic:  1374 on 1 and 349 DF,  p-value: < 2.2e-16 

round(summary(model2)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    9.703       0.26  37.302        0
#recEng        26.707       0.72  37.071        0

postscript("manuscript/figures/carguide2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(recEng, Cmpg, xlab="recEng = 1/Eng (reciprocal of engine size)",
     ylab="Cmpg = city miles per gallon")
lines(recEng,fitted(model2))
par(oldpar)
dev.off()

Engeffect <- fitted(model2)

postscript("manuscript/figures/carguide3.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Eng), Engeffect[order(Eng)], xlab="Eng = engine size (liters)",
     ylab=expression(paste("Eng effect = 9.70", + 26.71, "(1/Eng)")), type="l")
par(oldpar)
dev.off()

detach(cars3)

# 4.1.4: Natural logarithm transformation for response

# workexp

workexp <- read.csv("data/workexp.csv")
attach(workexp)

model1 <- lm(Sal ~ Exp)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  10.3226     2.7058   3.815 0.000389 ***
#Exp           3.0937     0.1766  17.515  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 8.357 on 48 degrees of freedom
#Multiple R-squared: 0.8647,	Adjusted R-squared: 0.8619 
#F-statistic: 306.8 on 1 and 48 DF,  p-value: < 2.2e-16 

round(summary(model1)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   10.323      2.706   3.815        0
#Exp            3.094      0.177  17.515        0

postscript("manuscript/figures/workexp1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Exp, Sal, xlab="Exp = experience (years)",
     ylab="Sal = salary ($ thousands)", ylim=c(10, 130))
lines(Exp,fitted(model1))
par(oldpar)
dev.off()

logSal <- log(Sal)

model2 <- lm(logSal ~ Exp)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 3.074347   0.040405   76.09   <2e-16 ***
#Exp         0.058824   0.002638   22.30   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1248 on 48 degrees of freedom
#Multiple R-squared: 0.912,	Adjusted R-squared: 0.9102 
#F-statistic: 497.4 on 1 and 48 DF,  p-value: < 2.2e-16 

round(summary(model2)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    3.074      0.040  76.089        0
#Exp            0.059      0.003  22.302        0

postscript("manuscript/figures/workexp2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Exp, logSal, xlab="Exp = experience (years)",
     ylab="logSal = natural logarithm of salary")
lines(Exp,fitted(model2))
par(oldpar)
dev.off()

3.074 + 10*0.059 # 3.664
qt(0.975, 48, lower.tail=T) # 2.010635
3.664 + c(-1,1)*2*0.1248 # 3.4144 3.9136
exp(c(3.4144, 3.9136)) # 30.39870 50.07891

predict(model2, interval="prediction")[Exp==10,][1,]
#      fit      lwr      upr 
# 3.662591 3.408385 3.916797 

exp(predict(model2, interval="prediction")[Exp==10,])[1,]
#        fit      lwr      upr
#28 38.96216 30.21641 50.23925

# incorrect
exp(3.664) + c(-1,1)*2*exp(0.1248) # 36.75126 41.28294

# multiplicative change
exp(0.059)-1 # 0.06077524
exp(coef(model2)[2])-1 # 0.06058901

detach(workexp)

# 4.1.5: Transformations for the response and predictors

# hometax

hometax <- read.csv("data/hometax.csv")
attach(hometax)

model1 <- lm(Tax ~ Price)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  61.2716    41.9781    1.46    0.147    
#Price         6.8763     0.3645   18.87   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 141.9 on 102 degrees of freedom
#Multiple R-squared: 0.7773,	Adjusted R-squared: 0.7751 
#F-statistic: 355.9 on 1 and 102 DF,  p-value: < 2.2e-16 

postscript("manuscript/figures/hometax1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Price, Tax, xlab="Price = sale price ($ thousands)",
     ylab="Tax = annual tax ($)")
lines(Price,fitted(model1))
par(oldpar)
dev.off()

logPrice <- log(Price)
logTax <- log(Tax)

model2 <- lm(logTax ~ logPrice)
summary(model2)
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)    2.076      0.237   8.762 4.42e-14 ***
#logPrice       0.983      0.051  19.276  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1616 on 102 degrees of freedom
#Multiple R-squared: 0.7846,	Adjusted R-squared: 0.7825 
#F-statistic: 371.6 on 1 and 102 DF,  p-value: < 2.2e-16 

postscript("manuscript/figures/hometax2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(logPrice, logTax, xlab="logPrice = natural logarithm of sale price",
     ylab="logTax = natural logarithm of annual tax")
lines(logPrice,fitted(model2))
par(oldpar)
dev.off()

exp(2.076 + 0.983*log(100)) # 737.217
exp(predict(model2, newdata=data.frame(logPrice=log(100)))) # 737.6208
                                           
predict(model1, newdata=data.frame(Price=c(100,150,200)),
        interval="prediction")[,2:3]
#        lwr      upr
#1  466.0192 1031.792
#2  808.3306 1377.114
#3 1146.1154 1726.963

exp(predict(model2, newdata=data.frame(logPrice=c(log(100),log(150),log(200))),
            interval="prediction")[,2:3])
#        lwr      upr
#1  534.4600 1018.008
#2  794.4401 1519.884
#3 1049.1839 2026.080

detach(hometax)

# 4.2: Interactions

# sales1

sales1 <- read.csv("data/sales1.csv")
attach(sales1)

AdvInt <- Advert*Interest

model1 <- lm(Sales ~ Advert + Interest + AdvInt)
summary(model1)
#Coefficients:
#               Estimate Std. Error t value Pr(>|t|)    
#(Intercept)     5.94148    0.66169   8.979 1.88e-05 ***
#Advert          1.83632    0.13492  13.611 8.17e-07 ***
#Interest       -1.31187    0.19670  -6.669 0.000158 ***
#AdvInt         -0.12601    0.03864  -3.261 0.011507 *  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.3075 on 8 degrees of freedom
#Multiple R-squared: 0.9944,	Adjusted R-squared: 0.9923 
#F-statistic: 472.1 on 3 and 8 DF,  p-value: 2.445e-09 

round(summary(model1)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    5.941      0.662   8.979    0.000
#Advert         1.836      0.135  13.611    0.000
#Interest      -1.312      0.197  -6.669    0.000
#AdvInt        -0.126      0.039  -3.261    0.012

1.836-0.126*c(2,3,4,5) # 1.584 1.458 1.332 1.206

postscript("manuscript/figures/salesinter.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Advert, Sales, xlab="Advert = advertising (in $m)",
     ylab="Sales = sales (in $m)", type="n")
for (i in 1:12)
  points(Advert[i], Sales[i], pch=as.character(Interest[i]))
legend("bottomright", legend="Points marked by Interest = interest rate",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 2:5)
  lines(Advert[Interest==i],fitted(model1)[Interest==i])
par(oldpar)
dev.off()

-0.12601/0.03864 # -3.261128
qt(0.975,8) # 2.306004
2*pt(-3.26,8) # 0.01152729

-1.312-0.126*c(1,4,7) # -1.438 -1.816 -2.194

# rough plot - needs refining as values of Advert are not all whole numbers
plot(Interest, Sales, xlab="Interest = interest rate (%)",
     ylab="Sales = sales (in $m)", type="n")
for (i in 1:12)
  points(Interest[i], Sales[i], pch=as.character(Advert[i]))
legend("topright", legend="Points marked by Advert = advertising (in $m)",
       inset = .02, x.intersp = 0, cex = .8)
lines(c(2,4),
      c(predict(model1, newdata=data.frame(Advert=1, Interest=2, AdvInt=2)),
        predict(model1, newdata=data.frame(Advert=1, Interest=4, AdvInt=4))))
lines(c(2,5),
      c(predict(model1, newdata=data.frame(Advert=4, Interest=2, AdvInt=8)),
        predict(model1, newdata=data.frame(Advert=4, Interest=5, AdvInt=20))))
lines(c(2,5),
      c(predict(model1, newdata=data.frame(Advert=7, Interest=2, AdvInt=14)),
        predict(model1, newdata=data.frame(Advert=7, Interest=5, AdvInt=35))))

detach(sales1)

# sales2

sales2 <- read.csv("data/sales2.csv")
attach(sales2)

AdvSto <- Advert*Stores

model1 <- lm(Sales ~ Advert + Stores + AdvSto)
summary(model1)
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  -6.1824     1.5402  -4.014  0.00387 ** 
#Advert        1.3490     0.2966   4.549  0.00188 ** 
#Stores        6.1561     0.5189  11.864 2.34e-06 ***
#AdvSto       -0.1101     0.1019  -1.080  0.31171    
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.8112 on 8 degrees of freedom
#Multiple R-squared: 0.989,	Adjusted R-squared: 0.9849 
#F-statistic: 240.8 on 3 and 8 DF,  p-value: 3.526e-08 

round(summary(model1)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   -6.182      1.540  -4.014    0.004
#Advert         1.349      0.297   4.549    0.002
#Stores         6.156      0.519  11.864    0.000
#AdvSto        -0.110      0.102  -1.080    0.312

postscript("manuscript/figures/salesnoint.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Advert, Sales, xlab="Advert = advertising (in $m)",
     ylab="Sales = sales (in $m)", type="n", xlim=c(1,7.7))
for (i in 1:12)
  points(Advert[i], Sales[i], pch=as.character(Stores[i]))
legend("bottomright", legend="Points marked by Stores = # of stores",
       inset = .02, x.intersp = 0, cex = .7)
for (i in 1:4)
  lines(Advert[Stores==i],fitted(model1)[Stores==i])
par(oldpar)
dev.off()

-0.1101/0.1019 # -1.080471
qt(0.975,8) # 2.306004
2*pt(-1.08,8) # 0.3116229

model2 <- lm(Sales ~ Advert + Stores)
summary(model2)
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  -4.7694     0.8198  -5.818 0.000254 ***
#Advert        1.0530     0.1142   9.221 7.00e-06 ***
#Stores        5.6452     0.2151  26.242 8.18e-10 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.8186 on 9 degrees of freedom
#Multiple R-squared: 0.9875,	Adjusted R-squared: 0.9847 
#F-statistic: 354.1 on 2 and 9 DF,  p-value: 2.778e-09 

round(summary(model2)$coef, 3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   -4.769      0.820  -5.818        0
#Advert         1.053      0.114   9.221        0
#Stores         5.645      0.215  26.242        0

detach(sales2)

# 4.3.1: Qualitative predictors with two levels

# salgpa1

salgpa1 <- read.csv("data/salgpa1.csv")
attach(salgpa1)

DFGpa <- DF*Gpa

model1 <- lm(Salary ~ DF + Gpa + DFGpa)
summary(model1)
#Coefficients:
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)    2.600      5.288   0.492 0.640386    
#DF            35.614      6.456   5.516 0.001492 ** 
#Gpa           17.680      2.035   8.687 0.000128 ***
#DFGpa         -7.159      2.559  -2.797 0.031276 *  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 3.218 on 6 degrees of freedom
#Multiple R-squared: 0.9664,	Adjusted R-squared: 0.9496 
#F-statistic: 57.54 on 3 and 6 DF,  p-value: 8.187e-05 

postscript("manuscript/figures/salgpa1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gpa, Salary, xlab="Gpa = grade point average",
     ylab="Salary = salary ($ thousands)", type="n")
for (i in 1:10)
  points(Gpa[i], Salary[i], pch=as.character(Gender[i]))
legend("bottomright", legend="Points marked by gender",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(Gpa[DF==i],fitted(model1)[DF==i])
par(oldpar)
dev.off()

DM <- 1-DF
DMGpa <- DM*Gpa

model2 <- lm(Salary ~ DM + Gpa + DMGpa)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   38.214      3.705  10.314 4.85e-05 ***
#DM           -35.614      6.456  -5.516 0.001492 ** 
#Gpa           10.521      1.552   6.780 0.000503 ***
#DMGpa          7.159      2.559   2.797 0.031276 *  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 3.218 on 6 degrees of freedom
#Multiple R-squared: 0.9664,	Adjusted R-squared: 0.9496 
#F-statistic: 57.54 on 3 and 6 DF,  p-value: 8.187e-05 

-7.159/2.559 # -2.797577
qt(0.975,6) # 2.446912
2*pt(-2.80,6, lower.tail=T) # 0.03116395

salgpa1a <- salgpa1[Gender=="M",]
detach(salgpa1)
attach(salgpa1a)

model1a <- lm(Salary ~ Gpa)
summary(model1a)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)    2.600      5.174   0.503  0.64987   
#Gpa           17.680      1.991   8.878  0.00301 **
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 3.149 on 3 degrees of freedom
#Multiple R-squared: 0.9633,	Adjusted R-squared: 0.9511 
#F-statistic: 78.82 on 1 and 3 DF,  p-value: 0.003013 

detach(salgpa1a)
attach(salgpa1)
salgpa1b <- salgpa1[Gender=="F",]
detach(salgpa1)
attach(salgpa1b)

model1b <- lm(Salary ~ Gpa)
summary(model1b)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)   38.214      3.783   10.10  0.00207 **
#Gpa           10.521      1.584    6.64  0.00696 **
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 3.286 on 3 degrees of freedom
#Multiple R-squared: 0.9363,	Adjusted R-squared: 0.9151 
#F-statistic: 44.09 on 1 and 3 DF,  p-value: 0.006959 

detach(salgpa1b)

# salgpa2

salgpa2 <- read.csv("data/salgpa2.csv")
attach(salgpa2)

DFGpa <- DF*Gpa

model1 <- lm(Salary ~ DF + Gpa + DFGpa)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   7.2800     2.9510   2.467  0.04866 *  
#DF           20.2921     3.6034   5.631  0.00134 ** 
#Gpa          13.5200     1.1359  11.903 2.13e-05 ***
#DFGpa        -0.7619     1.4284  -0.533  0.61294    
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.796 on 6 degrees of freedom
#Multiple R-squared: 0.9887,	Adjusted R-squared: 0.983 
#F-statistic: 174.3 on 3 and 6 DF,  p-value: 3.178e-06 

round(summary(model1)$coef,3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    7.280      2.951   2.467    0.049
#DF            20.292      3.603   5.631    0.001
#Gpa           13.520      1.136  11.903    0.000
#DFGpa         -0.762      1.428  -0.533    0.613

postscript("manuscript/figures/salgpa2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gpa, Salary, xlab="Gpa = grade point average",
     ylab="Salary = salary ($ thousands)", type="n")
for (i in 1:10)
  points(Gpa[i], Salary[i], pch=as.character(Gender[i]))
legend("bottomright", legend="Points marked by gender",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(Gpa[DF==i],fitted(model1)[DF==i])
par(oldpar)
dev.off()

-0.7619/1.4284 # -0.533394
2*pt(-0.533,6) # 0.6131879

model2 <- lm(Salary ~ DF + Gpa)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   8.4844     1.8002   4.713  0.00218 ** 
#DF           18.4715     1.0939  16.886 6.26e-07 ***
#Gpa          13.0382     0.6526  19.980 1.97e-07 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.702 on 7 degrees of freedom
#Multiple R-squared: 0.9881,	Adjusted R-squared: 0.9847 
#F-statistic: 291.1 on 2 and 7 DF,  p-value: 1.828e-07 

round(summary(model2)$coef,3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    8.484      1.800   4.713    0.002
#DF            18.471      1.094  16.886    0.000
#Gpa           13.038      0.653  19.980    0.000

detach(salgpa2)

# salaries - used in slides 4b

salary <- c(21, 31, 46.1, 60.7, 34.1, 49.1, 24, 39)
experience <- c(5, 15, 15, 30, 5, 20, 10, 25)
job <- c(rep("clerical",2), rep("manager",4), rep("clerical",2))
D <- c(0, 0, 1, 1, 1, 1, 0, 0)

model1 <- lm(salary ~ experience + D)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) 15.00000    0.93543   16.04 1.72e-05 ***
# experience   1.00000    0.05189   19.27 6.94e-06 ***
# D           15.00000    0.87742   17.10 1.25e-05 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 1.21 on 5 degrees of freedom
# Multiple R-squared:  0.9942,	Adjusted R-squared:  0.9918 
# F-statistic: 425.8 on 2 and 5 DF,  p-value: 2.602e-06

postscript("manuscript/figures/discrim2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(experience, salary, xlab="experience (years)",
     ylab="salary ($ thousands)", type="n")
for (i in 1:10)
  points(experience[i], salary[i], pch=as.character(job[i]))
legend("bottomright", legend="Points marked by job type",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(experience[D==i],fitted(model1)[D==i])
par(oldpar)
dev.off()

Dstar <- 1-D
model2 <- lm(salary ~ experience + Dstar)
summary(model2)
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  30.00000    1.09112   27.50 1.19e-06 ***
# experience    1.00000    0.05189   19.27 6.94e-06 ***
# Dstar       -15.00000    0.87742  -17.10 1.25e-05 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 1.21 on 5 degrees of freedom
# Multiple R-squared:  0.9942,	Adjusted R-squared:  0.9918 
# F-statistic: 425.8 on 2 and 5 DF,  p-value: 2.602e-06

salary <- c(25.5, 26.5, 26, 27, 27, 28, 28, 29, 28.5, 29.5)
experience <- c(1, 1, 2, 2, 3, 3, 4, 4, 5, 5)
gender <- c("f", "f", "m", "f", "m", "f", "m", "f", "m", "m")
D <- c(0, 0, 1, 0, 1, 0, 1, 0, 1, 1)

model1 <- lm(salary ~ experience + D)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  25.0000     0.2818  88.715 6.09e-12 ***
# experience    1.0000     0.1025   9.757 2.52e-05 ***
# D            -1.0000     0.2899  -3.450   0.0107 *  
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.378 on 7 degrees of freedom
# Multiple R-squared:  0.9355,	Adjusted R-squared:  0.9171 
# F-statistic: 50.75 on 2 and 7 DF,  p-value: 6.821e-05

postscript("manuscript/figures/discrim3.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(experience, salary, xlab="experience (years)",
     ylab="salary ($ thousands)", type="n")
for (i in 1:10)
  points(experience[i], salary[i], pch=as.character(gender[i]))
legend("bottomright", legend="Points marked by gender",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(experience[D==i],fitted(model1)[D==i])
par(oldpar)
dev.off()

salary <- c(25.455, 25.956, 25.923, 26.434, 27.023, 27.535,
            28.123, 28.621, 28.617, 28.819)
experience <- c(1, 0.5, 2, 1.5, 3, 2.5, 4, 3.5, 5, 4.5)
gender <- c("f", "f", "m", "f", "m", "f", "m", "f", "m", "m")
D <- c(0, 0, 1, 0, 1, 0, 1, 0, 1, 1)

model1 <- lm(salary ~ experience + D)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) 24.99986    0.23335 107.136 1.63e-12 ***
# experience   1.00019    0.09896  10.107 1.99e-05 ***
# D           -0.99956    0.28424  -3.517  0.00977 ** 
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.337 on 7 degrees of freedom
# Multiple R-squared:  0.9449,	Adjusted R-squared:  0.9291 
# F-statistic:    60 on 2 and 7 DF,  p-value: 3.931e-05

postscript("manuscript/figures/discrim4.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(experience, salary, xlab="experience (years)",
     ylab="salary ($ thousands)", type="n")
for (i in 1:10)
  points(experience[i], salary[i], pch=as.character(gender[i]))
legend("bottomright", legend="Points marked by gender",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(experience[D==i],fitted(model1)[D==i])
par(oldpar)
dev.off()

salary <- c(25.5, 26, 25.9, 26.5, 26.9, 27.5, 27.9, 28.5, 28.4, 28.9)
experience <- c(0.5, 1, 2, 2, 2.5, 3, 3.5, 4.5, 3.5, 4)
gender <- c("f", "f", "m", "f", "m", "f", "m", "f", "m", "m")
D <- c(0, 0, 1, 0, 1, 0, 1, 0, 1, 1)

Dexp <- D*experience
model1 <- lm(salary ~ experience + D + Dexp)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) 25.15534    0.15325 164.143 3.45e-12 ***
# experience   0.74757    0.05834  12.814 1.39e-05 ***
# D           -2.03312    0.39406  -5.159   0.0021 ** 
# Dexp         0.69687    0.12802   5.444   0.0016 ** 
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1872 on 6 degrees of freedom
# Multiple R-squared:  0.9841,	Adjusted R-squared:  0.9761 
# F-statistic: 123.5 on 3 and 6 DF,  p-value: 8.8e-06

postscript("manuscript/figures/discrim5.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(experience, salary, xlab="experience (years)",
     ylab="salary ($ thousands)", type="n")
for (i in 1:10)
  points(experience[i], salary[i], pch=as.character(gender[i]))
legend("bottomright", legend="Points marked by gender",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:1)
  lines(experience[D==i],fitted(model1)[D==i])
par(oldpar)
dev.off()

# 4.3.2: Qualitative predictors with three or more levels

# cars4

cars4 <- read.csv("data/cars4.csv")
attach(cars4)

Cgphm <- 100/Cmpg

DScEng <- DSc*Eng
DCoEng <- DCo*Eng
DSwEng <- DSw*Eng

model1 <- lm(Cgphm ~ DCo + DSw + Eng + DCoEng + DSwEng)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.99414    0.23917   8.338 6.12e-08 ***
#DCo          1.06994    0.31878   3.356  0.00314 ** 
#DSw         -0.06245    0.62425  -0.100  0.92131    
#Eng          1.00805    0.10767   9.362 9.47e-09 ***
#DCoEng      -0.42496    0.14028  -3.029  0.00662 ** 
#DSwEng       0.16994    0.28535   0.596  0.55815    
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.2177 on 20 degrees of freedom
#Multiple R-squared: 0.8899,	Adjusted R-squared: 0.8623 
#F-statistic: 32.32 on 5 and 20 DF,  p-value: 6.352e-09 

round(summary(model1)$coef,3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    1.994      0.239   8.338    0.000
#DCo            1.070      0.319   3.356    0.003
#DSw           -0.062      0.624  -0.100    0.921
#Eng            1.008      0.108   9.362    0.000
#DCoEng        -0.425      0.140  -3.029    0.007
#DSwEng         0.170      0.285   0.596    0.558

newEng <- c(seq(min(Eng[DSc==1]), max(Eng[DSc==1]), length=100),
          seq(min(Eng[DCo==1]), max(Eng[DCo==1]), length=100),
          seq(min(Eng[DSw==1]), max(Eng[DSw==1]), length=100))
newDCo <- rep(c(0,1,0),rep(100,3))
newDSw <- rep(c(0,0,1),rep(100,3))
newDCoEng <- newEng*newDCo
newDSwEng <- newEng*newDSw
gp <- newDCo+2*newDSw

Class1 <- c(rep("S",7),rep("C",11),rep("W",8))

postscript("manuscript/figures/cars4.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Eng, Cgphm, xlab="Eng = engine size (liters)",
     ylab="Cgphm = city gallons per hundred miles", type="n")
for (i in 1:26)
  points(Eng[i], Cgphm[i], pch=as.character(Class1[i]))
legend("bottomright", legend="Points marked by Class",
       inset = .02, x.intersp = 0, cex = .9)
for (i in 0:2)
  lines(newEng[gp==i],
        predict(model1, newdata=data.frame(Eng = newEng[gp==i],
                          DCo = newDCo[gp==i], DSw = newDSw[gp==i],
                          DCoEng = newDCoEng[gp==i],
                          DSwEng = newDSwEng[gp==i])))
par(oldpar)
dev.off()

cars4a <- cars4[Class=="SC",]
detach(cars4)
attach(cars4a)

Cgphm <- 100/Cmpg

model1a <- lm(Cgphm ~ Eng)
summary(model1a)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.99414    0.19920   10.01  0.00017 ***
#Eng          1.00805    0.08968   11.24 9.73e-05 ***

detach(cars4a)
attach(cars4)
cars4b <- cars4[Class=="CO",]
detach(cars4)
attach(cars4b)

Cgphm <- 100/Cmpg

model1b <- lm(Cgphm ~ Eng)
summary(model1b)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   3.0641     0.2435  12.585 5.13e-07 ***
#Eng           0.5831     0.1039   5.613 0.000329 ***

detach(cars4b)
attach(cars4)
cars4c <- cars4[Class=="SW",]
detach(cars4)
attach(cars4c)

Cgphm <- 100/Cmpg

model1c <- lm(Cgphm ~ Eng)
summary(model1c)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)   1.9317     0.5005   3.859  0.00837 **
#Eng           1.1780     0.2294   5.135  0.00215 **

detach(cars4c)
attach(cars4)

0.16994/0.28535 # 0.5955493
qt(0.975,20) # 2.085963
2*pt(0.596,20,lower.tail=F) # 0.5578609

Cgphm <- 100/Cmpg
DCoEng <- DCo*Eng

model2 <- lm(Cgphm ~ DCo + DSw + Eng + DCoEng)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.94368    0.22019   8.827 1.64e-08 ***
#DCo          1.12041    0.30256   3.703  0.00132 ** 
#DSw          0.30320    0.11119   2.727  0.01263 *  
#Eng          1.03225    0.09817  10.515 7.98e-10 ***
#DCoEng      -0.44916    0.13219  -3.398  0.00271 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1

#Residual standard error: 0.2143 on 21 degrees of freedom
#Multiple R-squared: 0.8879,	Adjusted R-squared: 0.8666 
#F-statistic: 41.59 on 4 and 21 DF,  p-value: 1.081e-09 

round(summary(model2)$coef,3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    1.944      0.220   8.827    0.000
#DCo            1.120      0.303   3.703    0.001
#DSw            0.303      0.111   2.727    0.013
#Eng            1.032      0.098  10.515    0.000
#DCoEng        -0.449      0.132  -3.398    0.003

# DSw ref
DScEng <- DSc*Eng
model1 <- lm(Cgphm ~ DSc + DCo + Eng + DScEng + DCoEng)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  1.93169    0.57661   3.350 0.003188 ** 
# DSc          0.06245    0.62425   0.100 0.921313    
# DCo          1.13239    0.61392   1.845 0.079974 .  
# Eng          1.17800    0.26426   4.458 0.000241 ***
# DScEng      -0.16994    0.28535  -0.596 0.558147    
# DCoEng      -0.59490    0.27914  -2.131 0.045665 *  

model2 <- lm(Cgphm ~ DSc + DCo + Eng + DCoEng)
summary(model2)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  2.24687    0.22541   9.968 2.05e-09 ***
# DSc         -0.30320    0.11119  -2.727  0.01263 *  
# DCo          0.81721    0.30637   2.667  0.01441 *  
# Eng          1.03225    0.09817  10.515 7.98e-10 ***
# DCoEng      -0.44916    0.13219  -3.398  0.00271 ** 

# DCo ref
DSwEng <- DSw*Eng
model1 <- lm(Cgphm ~ DSc + DSw + Eng + DScEng + DSwEng)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  3.06408    0.21076  14.538 4.28e-12 ***
# DSc         -1.06994    0.31878  -3.356  0.00314 ** 
# DSw         -1.13239    0.61392  -1.845  0.07997 .  
# Eng          0.58309    0.08992   6.484 2.54e-06 ***
# DScEng       0.42496    0.14028   3.029  0.00662 ** 
# DSwEng       0.59490    0.27914   2.131  0.04566 *

DScSwEng <- DScEng + DSwEng
model1a <- lm(Cgphm ~ DSc + DSw + Eng + DScSwEng)
summary(model1a)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  3.06408    0.20750  14.767 1.46e-12 ***
# DSc         -1.12041    0.30256  -3.703  0.00132 ** 
# DSw         -0.81721    0.30637  -2.667  0.01441 *  
# Eng          0.58309    0.08853   6.586 1.60e-06 ***
# DScSwEng     0.44916    0.13219   3.398  0.00271 **

anova(model1a, model1)
#  Res.DF     RSS DF Sum of Sq      F Pr(>F)
#1     21 0.96477                           
#2     20 0.94795  1  0.016812 0.3547 0.5581

detach(cars4)

# states - used in slides 4b

rev <- c(25.5, 26, 25.9, 26.5, 27.3, 27.5, 27.9, 28.5, 28.4, 28.9, 26.6, 27.4)
cost <- c(0.1, 0.05, 0.2, 0.15, 0.3, 0.25, 0.4, 0.35, 0.5, 0.45, 0.35, 0.45)
state <- c("CA", "WA", "CA", "OR", "OR", "WA", "OR", "WA", "OR", "WA", "CA", "CA")
D1 <- c(1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1)
D2 <- c(0, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 0)

D1cost <- D1*cost
D2cost <- D2*cost

model1 <- lm(rev ~ cost + D1 + D2 + D1cost+ D2cost)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) 25.67664    0.19269 133.252 1.20e-11 ***
# cost         5.47664    0.53315  10.272 4.97e-05 ***
# D1          -0.78698    0.24842  -3.168   0.0194 *  
# D2          -0.01806    0.24148  -0.075   0.9428    
# D1cost      -0.16629    0.73922  -0.225   0.8295    
# D2cost       2.03765    0.70817   2.877   0.0282 *  
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1379 on 6 degrees of freedom
# Multiple R-squared:  0.9916,	Adjusted R-squared:  0.9845 
# F-statistic:   141 on 5 and 6 DF,  p-value: 3.903e-06

gp <- D1+2*D2

postscript("manuscript/figures/states.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(cost, rev, xlab="annual cost ($m)",
     ylab="annual revenue ($m)", type="n")
for (i in 1:12)
  points(cost[i], rev[i], pch=as.character(state[i]))
legend("bottomright", legend="Points marked by state",
       inset = .02, x.intersp = 0, cex = .8)
for (i in 0:2)
  lines(cost[gp==i],fitted(model1)[gp==i])
par(oldpar)
dev.off()

model2 <- lm(rev ~ cost + D1 + D2cost)
summary(model2)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) 25.68271    0.08892 288.819  < 2e-16 ***
# cost         5.44259    0.25512  21.334 2.45e-08 ***
# D1          -0.82942    0.08117 -10.219 7.22e-06 ***
# D2cost       2.00361    0.25294   7.921 4.69e-05 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1204 on 8 degrees of freedom
# Multiple R-squared:  0.9914,	Adjusted R-squared:  0.9882 
# F-statistic:   308 on 3 and 8 DF,  p-value: 1.331e-08

anova(model2, model1)
#   Res.Df     RSS Df Sum of Sq      F Pr(>F)
# 1      8 0.11604                           
# 2      6 0.11406  2 0.0019857 0.0522 0.9495