# Chapter 4: Regression Model Building I
# Odd-numbered problems

setwd("~/Teaching/arm3e/")

# 4.1 nyjuice

nyjuice <- read.csv("data/nyjuice.csv")
attach(nyjuice)

Daysq <- Day^2
model2 <- lm(Cases ~ Day + Daysq)
newDay <- seq(min(Day), max(Day), length=100)
newDaysq <- newDay^2

postscript("insman/nyjuice.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Day, Cases, xlab="Day = sale day",
     ylab="Cases = number of cases of orange juice")
lines(newDay,
      predict(model2, newdata=data.frame(Day = newDay, Daysq = newDaysq)))
par(oldpar)
dev.off()

model1 <- lm(Cases ~ Day)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)   2802.4      604.7   4.634 4.13e-05 ***
#Day            123.0       25.7   4.783 2.61e-05 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1877 on 38 degrees of freedom
#Multiple R-squared: 0.3758,	Adjusted R-squared: 0.3594 
#F-statistic: 22.88 on 1 and 38 DF,  p-value: 2.606e-05 

summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 4944.221    829.601   5.960 7.12e-07 ***
#Day         -183.029     93.319  -1.961  0.05740 .  
#Daysq          7.463      2.207   3.381  0.00172 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1662 on 37 degrees of freedom
#Multiple R-squared: 0.5232,	Adjusted R-squared: 0.4974 
#F-statistic:  20.3 on 2 and 37 DF,  p-value: 1.122e-06 

7.463/2.207 # 3.381513
2*pt(3.381, 37, lower.tail=F) # 0.001716259
qt(0.975, 37) # 2.026192

detach(nyjuice)

# 4.3 transformations

transformations <- read.csv("data/transformations.csv")
attach(transformations)

logX4 <- log(X4)

model1 <- lm(Y4 ~ logX4)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  2.48146    0.06287   39.47   <2e-16 ***
# logX4        0.91053    0.07047   12.92   <2e-16 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.4415 on 48 degrees of freedom
# Multiple R-squared:  0.7767,	Adjusted R-squared:  0.772 
# F-statistic: 166.9 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/transformationsa.eps",
           width = 5, height = 3.75, pointsize = 10,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:4,2,2,byrow=T))
plot(X4,Y4,xlab="X4",
     ylab="Y4",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
plot(logX4,Y4,xlab="Natural logarithm of X4",
     ylab="Y4",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(sort(logX4),fitted(model1)[order(logX4)])
plot(fitted(model1), residuals(model1),
     xlab="Fitted values",ylab="Residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
qqnorm(residuals(model1),main="",
       xlab="Normal quantiles",
       ylab="Residual quantiles",xaxt="n",
       yaxt="n",mgp=c(1,1,0))
qqline(residuals(model1))
par(oldpar)
dev.off()

logY3 <- log(Y3)

model2 <- lm(logY3 ~ X3)
summary(model2)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.86439    0.15706  -5.504 1.42e-06 ***
# X3           0.93303    0.07091  13.158  < 2e-16 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.4513 on 48 degrees of freedom
# Multiple R-squared:  0.7829,	Adjusted R-squared:  0.7784 
# F-statistic: 173.1 on 1 and 48 DF,  p-value: < 2.2e-16 

postscript("insman/transformationsb.eps",
           width = 5, height = 3.75, pointsize = 10,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:4,2,2,byrow=T))
plot(X3,Y3,xlab="X3",
     ylab="Y3",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
plot(X3,logY3,xlab="X3",
     ylab="Natural logarithm of Y3",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(sort(X3),fitted(model2)[order(X3)])
plot(fitted(model2), residuals(model2),
     xlab="Fitted values",ylab="Residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
qqnorm(residuals(model2),main="",
       xlab="Normal quantiles",
       ylab="Residual quantiles",xaxt="n",
       yaxt="n",mgp=c(1,1,0))
qqline(residuals(model2))
par(oldpar)
dev.off()

logX1 <- log(X1)
logY1 <- log(Y1)

model3 <- lm(logY1 ~ logX1)
summary(model3)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  0.84491    0.07309   11.56 1.79e-15 ***
# logX1        0.91384    0.08749   10.45 5.96e-14 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.5167 on 48 degrees of freedom
# Multiple R-squared:  0.6945,	Adjusted R-squared:  0.6881 
# F-statistic: 109.1 on 1 and 48 DF,  p-value: 5.963e-14

summary(model3)$r.squared # 0.694479

postscript("insman/transformationsc.eps",
           width = 5, height = 3.75, pointsize = 10,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:4,2,2,byrow=T))
plot(X1,Y1,xlab="X1",
     ylab="Y1",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
plot(logX1,logY1,xlab="Natural logarithm of X1",
     ylab="Natural logarithm of Y1",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(sort(logX1),fitted(model3)[order(logX1)])
plot(fitted(model3), residuals(model3),
     xlab="Fitted values",ylab="Residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
qqnorm(residuals(model3),main="",
       xlab="Normal quantiles",
       ylab="Residual quantiles",xaxt="n",
       yaxt="n",mgp=c(1,1,0))
qqline(residuals(model3))
par(oldpar)
dev.off()

X2sq <- X2^2

model4 <- lm(Y2 ~ X2 + X2sq)
summary(model4)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   1.5615     1.0115   1.544    0.129    
# X2           -0.1655     1.0277  -0.161    0.873    
# X2sq          1.3003     0.2296   5.663 8.69e-07 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 1.833 on 47 degrees of freedom
# Multiple R-squared:  0.915,	Adjusted R-squared:  0.9113 
# F-statistic: 252.8 on 2 and 47 DF,  p-value: < 2.2e-16 

round(summary(model4)$coefficients, 3)
#             Estimate Std. Error t value Pr(>|t|)
# (Intercept)    1.562      1.012   1.544    0.129
# X2            -0.166      1.028  -0.161    0.873
# X2sq           1.300      0.230   5.663    0.000

postscript("insman/transformationsd.eps",
           width = 5, height = 3.75, pointsize = 10,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(2,2,1,1)+0.1)
layout(matrix(1:4,2,2,byrow=T))
plot(X2,Y2,xlab="X2",
     ylab="Y2",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
plot(X2,Y2,xlab="X2",
     ylab="Y2",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
lines(sort(X2),fitted(model4)[order(X2)])
plot(fitted(model4), residuals(model4),
     xlab="Fitted values",ylab="Residuals",xaxt="n",
     yaxt="n",mgp=c(1,1,0))
qqnorm(residuals(model4),main="",
       xlab="Normal quantiles",
       ylab="Residual quantiles",xaxt="n",
       yaxt="n",mgp=c(1,1,0))
qqline(residuals(model4))
par(oldpar)
dev.off()

detach(transformations)

# 4.5 internet

internet <- read.csv("data/internet.csv")
attach(internet)

model1 <- lm(Int ~ Gdp)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 12.36278    1.71827   7.195 1.09e-11 ***
#Gdp          1.36093    0.07975  17.065  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 18.14 on 210 degrees of freedom
#Multiple R-squared: 0.581,	Adjusted R-squared: 0.579 
#F-statistic: 291.2 on 1 and 210 DF,  p-value: < 2.2e-16 

plot(Gdp,Int,xlab="GDP per capita (in thousands of US dollars)",
     ylab="Percentage of Internet users")
lines(sort(Gdp),fitted(model1)[order(Gdp)])

logInt <- log(Int)
logGdp <- log(Gdp)

model2 <- lm(logInt ~ logGdp)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.03583    0.11529   8.984   <2e-16 ***
#logGdp       0.88067    0.04799  18.350   <2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.9046 on 210 degrees of freedom
#Multiple R-squared: 0.6159,	Adjusted R-squared: 0.6141 
#F-statistic: 336.7 on 1 and 210 DF,  p-value: < 2.2e-16 

postscript("insman/internetplot2.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(logGdp,logInt,
     xlab="Natural logarithm of GDP per capita",
     ylab="Natural logarithm of Internet user percentage")
lines(sort(logGdp),fitted(model2)[order(logGdp)])
par(oldpar)
dev.off()

sqrtInt <- sqrt(Int)
sqrtGdp <- sqrt(Gdp)

model3 <- lm(sqrtInt ~ sqrtGdp)
summary(model3)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  1.35970    0.22284   6.102 4.99e-09 ***
#sqrtGdp      1.10369    0.05784  19.081  < 2e-16 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 1.633 on 210 degrees of freedom
#Multiple R-squared: 0.6342,	Adjusted R-squared: 0.6325 
#F-statistic: 364.1 on 1 and 210 DF,  p-value: < 2.2e-16 

postscript("insman/internetplot3.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sqrtGdp,sqrtInt,
     xlab="Square root of GDP per capita",
     ylab="Square root of Internet user percentage")
lines(sort(sqrtGdp),fitted(model3)[order(sqrtGdp)])
par(oldpar)
dev.off()

detach(internet)

# 4.7 homes6

homes6 <- read.csv("data/homes6.csv")
attach(homes6)

round(coef(summary(lm(Price ~ Floor + Lot + Bath + Bed + I(Bath*Bed) + Age + I(Age^2) + Gar + DAc + DEd + DHa))),2)
#              Estimate Std. Error t value Pr(>|t|)
#(Intercept)     332.47     106.60    3.12     0.00
#Floor            56.72      27.97    2.03     0.05
#Lot               9.92       3.44    2.88     0.01
#Bath            -98.15      42.67   -2.30     0.02
#Bed             -78.91      27.75   -2.84     0.01
#I(Bath * Bed)    30.39      11.88    2.56     0.01
#Age               3.30       3.17    1.04     0.30
#I(Age^2)          1.64       0.73    2.24     0.03
#Gar              13.12       8.28    1.58     0.12
#DAc              27.43      10.99    2.50     0.02
#DEd              67.06      16.82    3.99     0.00
#DHa              47.27      14.84    3.18     0.00

-98.15+30.39*2 # -37.37
-98.15+30.39*3 # -6.98
-98.15+30.39*4 # 23.41

detach(homes6)

# 4.11 homes5

homes5 <- read.csv("data/homes5.csv")
attach(homes5)

DHaFloor <- DHa*Floor

model1 <- lm(Price ~ DHa + Floor + DHaFloor)

postscript("insman/homes5.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Floor, Price, xlab="Floor = floor size (thousands of square feet)",
     ylab="Price = sale price ($ thousands)", type="n")
for (i in 1:40)
  points(Floor[i], Price[i], pch=as.character(School[i]))
legend("topleft", legend="Points marked by neighborhood",
       inset = .02, x.intersp = 0, cex = 1)
for (i in 0:1)
  lines(Floor[DHa==i],fitted(model1)[DHa==i])
text(1.64,295,"Harris")
text(1.7,220,"Redwood")
par(oldpar)
dev.off()

summary(model1)
#            Estimate Std. Error t value Pr(>|t|)  
#(Intercept)    35.90     122.17   0.294   0.7705  
#DHa            73.30     216.10   0.339   0.7364  
#Floor         118.63      61.77   1.921   0.0627 .
#DHaFloor      -13.05     108.66  -0.120   0.9051  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 50.57 on 36 degrees of freedom
#Multiple R-squared: 0.2763,	Adjusted R-squared: 0.216 
#F-statistic: 4.583 on 3 and 36 DF,  p-value: 0.008102 

model2 <- lm(Price ~ DHa + Floor)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)    44.21      99.32   0.445  0.65878   
#DHa            47.42      16.56   2.863  0.00687 **
#Floor         114.41      50.14   2.282  0.02833 * 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 49.9 on 37 degrees of freedom
#Multiple R-squared: 0.2761,	Adjusted R-squared: 0.2369 
#F-statistic: 7.055 on 2 and 37 DF,  p-value: 0.002538 

44.21+47.42 # 91.63

detach(homes5)

# 4.15 drop indicator variable

Y <- c(3.4,3.8,3.5,3.9,3.5,3.9)
X <- c(2.3,3.0,2.9,3.8,2.3,3.2)
Manufacturer <- c("A", "A", "B", "B", "C", "C")
DA <- c(1,1,0,0,0,0)
DB <- c(0,0,1,1,0,0)

model1 <- lm(Y ~ DA + DB + X)
round(summary(model1)$coefficients, 3)
#             Estimate Std. Error t value Pr(>|t|)
# (Intercept)    2.397      0.108  22.224    0.002
# DA            -0.053      0.039  -1.344    0.311
# DB            -0.284      0.045  -6.305    0.024
# X              0.474      0.038  12.500    0.006

2.397-0.053 # 2.344
2.397-0.284 # 2.113

plot(X, Y, type="n")
for (i in 1:6)
  points(X[i], Y[i], pch=as.character(Manufacturer[i]))
legend("topleft", legend="Points marked by neighborhood",
       inset = .02, x.intersp = 0, cex = 1)
lines(X[Manufacturer=="A"],fitted(model1)[Manufacturer=="A"])
lines(X[Manufacturer=="B"],fitted(model1)[Manufacturer=="B"])
lines(X[Manufacturer=="C"],fitted(model1)[Manufacturer=="C"])

model2 <- lm(Y ~ DB + X)
round(summary(model2)$coefficients, 3)
#             Estimate Std. Error t value Pr(>|t|)
# (Intercept)    2.357      0.117  20.169    0.000
# DB            -0.261      0.047  -5.561    0.011
# X              0.479      0.043  11.264    0.002

2.357-0.261 # 2.096
