# Chapter 5: Regression Model Building II
# Odd-numbered problems

setwd("~/Teaching/arm3e/")

# 5.1 collgpa - influential points

collgpa <- read.csv("data/collgpa.csv")
attach(collgpa)

model1 <- lm(Gpa ~ Verb + Math)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept) -0.905450   0.606037  -1.494 0.143642    
#Verb         0.027974   0.004939   5.664 1.79e-06 ***
#Math         0.026139   0.006048   4.322 0.000112 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.4938 on 37 degrees of freedom
#Multiple R-squared: 0.5545,	Adjusted R-squared: 0.5304 
#F-statistic: 23.03 on 2 and 37 DF,  p-value: 3.189e-07 

rstu1 <- rstudent(model1)

postscript("insman/collgpa1.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(Verb, rstu1, span=0.75,
               xlab="Verb = verbal score",
               ylab="Model 1 studentized residual")
par(oldpar)
dev.off()

postscript("insman/collgpa2.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(Math, rstu1, span=0.75,
               xlab="Math = math score",
               ylab="Model 1 studentized residual")
par(oldpar)
dev.off()

VerbMath <- Verb*Math
Verbsq <- Verb^2
Mathsq <- Math^2

model2 <- lm(Gpa ~ Verb + Math + VerbMath + Verbsq + Mathsq)
summary(model2)
#              Estimate Std. Error t value Pr(>|t|)    
#(Intercept) -7.2229715  1.4720009  -4.907 2.27e-05 ***
#Verb         0.1262617  0.0230892   5.468 4.23e-06 ***
#Math         0.1170340  0.0290549   4.028 0.000299 ***
#VerbMath     0.0008780  0.0001565   5.611 2.76e-06 ***
#Verbsq      -0.0011301  0.0001275  -8.866 2.32e-10 ***
#Mathsq      -0.0010630  0.0001733  -6.135 5.76e-07 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.2034 on 34 degrees of freedom
#Multiple R-squared: 0.9305,	Adjusted R-squared: 0.9203 
#F-statistic:  91.1 on 5 and 34 DF,  p-value: < 2.2e-16 

rstu2 <- rstudent(model2)
zpred2 <- fitted(model2)
zpred2 <- (zpred2-mean(zpred2))/sd(zpred2)

postscript("insman/collgpa3.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(zpred2, rstu2, span=0.75,
               xlab="Model 2 standardized predicted value",
               ylab="Model 2 studentized residual")
par(oldpar)
dev.off()

#scatter.smooth(Verb, rstu2)
#scatter.smooth(Math, rstu2)

postscript("insman/collgpa4.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
hist(rstu2,main="",
     xlab="Model 2 studentized residual",
     breaks=9,
     mgp=c(2,1,0),ylab="")
par(oldpar)
dev.off()

postscript("insman/collgpa5.eps",
           width = 2.5, height = 2.5, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1)
qqnorm(rstu2,main="",
       xlab="Normal quantile",
       ylab="Model 2 studentized residual quantile",mgp=c(2,1,0))
qqline(rstu2)
par(oldpar)
dev.off()

range(rstu2) # -3.030458  1.946457
which.min(rstu2) # 28

lev2 <- hatvalues(model2)
coo2 <- cooks.distance(model2)

postscript("insman/collgpa6.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(ID, lev2, xlab="ID number", ylab="Model 2 leverage")
text(ID[4]+2, lev2[4], ID[4])
par(oldpar)
dev.off()

lev2[4] # 0.5630702
3*(5+1)/40 # 0.45
c(Verb[4],Math[4]) # 100  49

postscript("insman/collgpa7.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(ID, coo2, xlab="ID number",
     ylab="Model 2 Cook's distance")
text(ID[9]+2, coo2[9], ID[9])
par(oldpar)
dev.off()

coo2[9] # 0.3089189
c(rstu2[9],lev2[9]) # -2.7519524  0.2260432

detach(collgpa)
collgpax <- collgpa[-4,]
attach(collgpax)

VerbMath <- Verb*Math
Verbsq <- Verb^2
Mathsq <- Math^2

model3 <- lm(Gpa ~ Verb + Math + VerbMath + Verbsq + Mathsq)
summary(model3)
#              Estimate Std. Error t value Pr(>|t|)    
#(Intercept) -7.2007150  1.5045385  -4.786 3.46e-05 ***
#Verb         0.1265163  0.0235208   5.379 6.03e-06 ***
#Math         0.1161645  0.0303077   3.833 0.000539 ***
#VerbMath     0.0008661  0.0001856   4.667 4.90e-05 ***
#Verbsq      -0.0011252  0.0001353  -8.319 1.31e-09 ***
#Mathsq      -0.0010521  0.0001964  -5.357 6.44e-06 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.2064 on 33 degrees of freedom
#Multiple R-squared: 0.922,	Adjusted R-squared: 0.9101 
#F-statistic: 77.97 on 5 and 33 DF,  p-value: < 2.2e-16 

detach(collgpax)
collgpaxx <- collgpa[-9,]
attach(collgpaxx)

VerbMath <- Verb*Math
Verbsq <- Verb^2
Mathsq <- Math^2

model4 <- lm(Gpa ~ Verb + Math + VerbMath + Verbsq + Mathsq)
summary(model4)
#               Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -5.8148494  1.4413759  -4.034 0.000305 ***
# Verb         0.1163427  0.0214414   5.426 5.24e-06 ***
# Math         0.0912155  0.0282036   3.234 0.002771 ** 
# VerbMath     0.0009937  0.0001493   6.657 1.42e-07 ***
# Verbsq      -0.0011268  0.0001167  -9.656 3.86e-11 ***
# Mathsq      -0.0009568  0.0001632  -5.861 1.45e-06 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1862 on 33 degrees of freedom
# Multiple R-squared:  0.9376,	Adjusted R-squared:  0.9282 
# F-statistic: 99.18 on 5 and 33 DF,  p-value: < 2.2e-16 

detach(collgpaxx)

# 5.3 inflammation - weighted least squares

inflammation <- read.csv("data/inflammation.csv")
attach(inflammation)

postscript("~/Teaching/arm3e/insman/inflammation1.eps",
           width = 4, height = 3, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Dose, Inflammation,
     xlab="Dose",
     ylab="Inflammation")
par(oldpar)
dev.off()

model1 <- lm(Inflammation ~ Dose + DoseSq)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  9.37782    0.55276  16.966  < 2e-16 ***
# Dose        -1.04691    0.22551  -4.642 4.23e-05 ***
# DoseSq       0.05063    0.01985   2.551    0.015 *  
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 1.155 on 37 degrees of freedom
# Multiple R-squared:   0.67,	Adjusted R-squared:  0.6521 
# F-statistic: 37.56 on 2 and 37 DF,  p-value: 1.239e-09

postscript("~/Teaching/arm3e/insman/inflammation2.eps",
           width = 4, height = 3, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(fitted(model1), rstandard(model1),
     xlab="Fitted values for unweighted model",
     ylab="Standardized residuals for unweighted model")
par(oldpar)
dev.off()

absres <- abs(residuals(model1))
fv <- fitted(lm(absres ~ fitted(model1)))
wts <- 1/fv^2

model2 <- lm(Inflammation ~ Dose + DoseSq, weights = wts)
summary(model2)
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  9.55738    0.77826  12.280 1.28e-14 ***
# Dose        -1.11893    0.23828  -4.696 3.60e-05 ***
# DoseSq       0.05629    0.01729   3.255  0.00243 ** 
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 1.286 on 37 degrees of freedom
# Multiple R-squared:  0.6219,	Adjusted R-squared:  0.6015 
# F-statistic: 30.43 on 2 and 37 DF,  p-value: 1.534e-08

postscript("~/Teaching/arm3e/insman/inflammation3.eps",
           width = 4, height = 3, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(fitted(model2), rstandard(model2),
     xlab="Fitted values for weighted model",
     ylab="Standardized residuals for weighted model")
par(oldpar)
dev.off()

detach(inflammation)

# 5.5 adsales - autocorrelation

adsales <- read.csv("data/adsales.csv")
attach(adsales)

postscript("~/Teaching/arm3e/insman/adsales1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Ads,Sales,xlab="Ads", ylab="Sales")
par(oldpar)
dev.off()

model1 <- lm(Sales ~ Ads)
summary(model1)
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  21.8041     5.9915   3.639  0.00081 ***
# Ads           1.6066     0.3375   4.760 2.81e-05 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 8.525 on 38 degrees of freedom
# Multiple R-squared:  0.3735,	Adjusted R-squared:  0.357 
# F-statistic: 22.65 on 1 and 38 DF,  p-value: 2.806e-05

resid1 <- residuals(model1)

postscript("~/Teaching/arm3e/insman/adsales2.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Time,resid1,xlab="Time", ylab="Residuals from SLR model")
lines(Time, resid1)
par(oldpar)
dev.off()

n <- nrow(adsales)
rhohat <- c(resid1[-n]%*%resid1[-1]/resid1%*%resid1) # 0.6659815 autocorrelation

lagr1x <- c(resid1[-1],0)
model1a <- lm(lagr1x ~ resid1 - 1)
coef(model1a) # 0.6659815 autocorrelation (alternative calculation)

# Cochrane-Orcutt procedure

coSales <- Sales[-1]-rhohat*lagSales
coAds <- Ads[-1]-rhohat*lagAds

model2 <- lm(coSales ~ coAds)
summary(model2)
# Coefficients:
#             Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   5.6665     1.5428   3.673 0.000754 ***
# coAds         1.9076     0.2056   9.277 3.41e-11 ***
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 6.243 on 37 degrees of freedom
# Multiple R-squared:  0.6993,	Adjusted R-squared:  0.6912 
# F-statistic: 86.06 on 1 and 37 DF,  p-value: 3.409e-11

coef(model2)
# (Intercept)       coAds 
#    5.666452    1.907629 

coef(model2)/c(1-rhohat,1)
# (Intercept)       coAds 
#   16.964484    1.907629

resid2 <- residuals(model2)

postscript("~/Teaching/arm3e/insman/adsales3.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Time[-1],resid2,xlab="Time", ylab="Residuals from Cochrane-Orcutt model")
lines(Time[-1],resid2)
par(oldpar)
dev.off()

resid2[-(n-1)]%*%resid2[-1]/resid2%*%resid2 # -0.02564619 autocorrelation

detach(adsales)

# 5.7 rescale - rescaling predictor

rescale <- read.csv("data/rescale.csv")
attach(rescale)

Xsq <- X**2
model1 <- lm(Y ~ X + Xsq)
summary(model1)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept)  8.17922    5.90567   1.385   0.1692   
#X           -0.43553    1.15460  -0.377   0.7068   
#Xsq          0.16296    0.05603   2.908   0.0045 **
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.9425 on 97 degrees of freedom
#Multiple R-squared: 0.9246,	Adjusted R-squared: 0.923 
#F-statistic: 594.4 on 2 and 97 DF,  p-value: < 2.2e-16 

vif(model1)
#       X      Xsq 
#185.3544 185.3544 

Z <- (X-mean(X))/sd(X)
Zsq <- Z**2

model2 <- lm(Y ~ Z + Zsq)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 20.19101    0.11693 172.673   <2e-16 ***
#Z            3.16317    0.09979  31.700   <2e-16 ***
#Zsq          0.20332    0.06991   2.908   0.0045 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.9425 on 97 degrees of freedom
#Multiple R-squared: 0.9246,	Adjusted R-squared: 0.923 
#F-statistic: 594.4 on 2 and 97 DF,  p-value: < 2.2e-16 

vif(model2)
#       Z      Zsq 
#1.109634 1.109634 

plot(fitted(model1),fitted(model2))
round(fitted(model1)-fitted(model2), 10) # 0s

detach(rescale)

# 5.9 model selection

n <- 50
tss <- 884.8

rss3 <- 279.5
rss23 <- 262.5
rss123 <- 261.6
rss1234 <- 261.6

k3 <- 1
k23 <- 2
k123 <- 3
k1234 <- 4

s3 <- sqrt(rss3/(n-k3-1))                      # 2.413072 
s23 <- sqrt(rss23/(n-k23-1))                   # 2.363283 *
s123 <- sqrt(rss123/(n-k123-1))                # 2.384734 
s1234 <- sqrt(rss1234/(n-k1234-1))             # 2.411086 

ar3 <- 1 - ((n-1)/(n-k3-1))*rss3/tss           # 0.6775283
ar23 <- 1 - ((n-1)/(n-k23-1))*rss23/tss        # 0.6906982 *
ar123 <- 1 - ((n-1)/(n-k123-1))*rss123/tss     # 0.6850578
ar1234 <- 1 - ((n-1)/(n-k1234-1))*rss1234/tss  # 0.6780591

aic3 <- n*log(rss3/n) + 2*(k3+1)               # 90.04896
aic23 <- n*log(rss23/n) + 2*(k23+1)            # 88.91140 *
aic123 <- n*log(rss123/n) + 2*(k123+1)         # 90.73968
aic1234 <- n*log(rss1234/n) + 2*(k1234+1)      # 92.73968

bic3 <- n*log(rss3/n) + log(n)*(k3+1)          # 93.87301 *
bic23 <- n*log(rss23/n) + log(n)*(k23+1)       # 94.64747
bic123 <- n*log(rss123/n) + log(n)*(k123+1)    # 98.38777
bic1234 <- n*log(rss1234/n) + log(n)*(k1234+1) # 102.2998

cp3 <- rss3/s1234^2 + 2*(k3+1) - n             # 2.079128
cp23 <- rss23/s1234^2 + 2*(k23+1) - n          # 1.154817 *
cp123 <- rss123/s1234^2 + 2*(k123+1) - n       # 3
cp1234 <- rss1234/s1234^2 + 2*(k1234+1) - n    # 5

# 5.11 ubs - model building and predictor effect plots

ubs <- read.csv("data/ubs.csv")
attach(ubs)

postscript("insman/ubs1.eps",
           width = 5.0, height = 5.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Wage, Bread, Rice, Vac, Bigmac), cex.labels=1.5,
      labels=c("Wage", "Bread", "Rice", "Vac", "Bigmac"),
      pch=as.character(Region))
dev.off()

boxplot(Bigmac ~ Region)

DNw <- 1 - DAs - DEm - DSa
c(sum(DNw),sum(DAs),sum(DEm),sum(DSa)) # 32 14 17 10

model1 <- lm(Bigmac ~ DAs + DEm + DSa + Wage + Bread + Rice + Vac)
summary(model1)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  3.929449   0.631421   6.223 3.99e-08 ***
#DAs         -0.207525   0.114411  -1.814   0.0743 .  
#DEm         -0.104153   0.094352  -1.104   0.2737    
#DSa          0.181246   0.118389   1.531   0.1306    
#Wage        -0.576032   0.084254  -6.837 3.37e-09 ***
#Bread        0.309707   0.074294   4.169 9.25e-05 ***
#Rice         0.102046   0.088928   1.148   0.2554    
#Vac          0.015415   0.005814   2.651   0.0101 *  
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.2331 on 65 degrees of freedom
#Multiple R-squared: 0.8807,	Adjusted R-squared: 0.8678 
#F-statistic: 68.54 on 7 and 65 DF,  p-value: < 2.2e-16 

rstu1 <- rstudent(model1)

postscript("insman/ubs2.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(Bread, rstu1, span=0.75,
               xlab="Bread",
               ylab="Model 1 studentized residual")
par(oldpar)
dev.off()

DAsWage <- DAs*Wage
DAsBread <- DAs*Bread
DAsRice <- DAs*Rice
DAsVac <- DAs*Vac
DEmWage <- DEm*Wage
DEmBread <- DEm*Bread
DEmRice <- DEm*Rice
DEmVac <- DEm*Vac
DSaWage <- DSa*Wage
DSaBread <- DSa*Bread
DSaRice <- DSa*Rice
DSaVac <- DSa*Vac

model2 <- lm(Bigmac ~ DAs + DEm + DSa + Wage + Bread + Rice + Vac
             + DAsWage + DAsBread + DAsRice + DAsVac
             + DEmWage + DEmBread + DEmRice + DEmVac
             + DSaWage + DSaBread + DSaRice + DSaVac)
summary(model2)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  3.683085   0.996793   3.695 0.000522 ***
#DAs         -0.738972   1.459567  -0.506 0.614749    
#DEm          0.555744   1.383537   0.402 0.689532    
#DSa         -0.984978   2.907659  -0.339 0.736134    
#Wage        -0.478023   0.154255  -3.099 0.003106 ** 
#Bread        0.082348   0.107430   0.767 0.446765    
#Rice         0.221956   0.122558   1.811 0.075804 .  
#Vac          0.022065   0.007127   3.096 0.003131 ** 
#DAsWage     -0.103942   0.188635  -0.551 0.583933    
#DAsBread     0.567501   0.183594   3.091 0.003176 ** 
#DAsRice     -0.463639   0.202251  -2.292 0.025882 *  
#DAsVac       0.054241   0.021818   2.486 0.016104 *  
#DEmWage     -0.051375   0.214087  -0.240 0.811278 !   
#DEmBread     0.208266   0.175752   1.185 0.241303    
#DEmRice     -0.011267   0.203540  -0.055 0.956064 !   
#DEmVac      -0.045066   0.015387  -2.929 0.005005 ** 
#DSaWage     -0.130008   0.460941  -0.282 0.779005 !   
#DSaBread     0.690651   0.189595   3.643 0.000614 ***
#DSaRice     -0.160711   0.384538  -0.418 0.677684    
#DSaVac      -0.007723   0.013443  -0.575 0.568045    
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1903 on 53 degrees of freedom
#Multiple R-squared: 0.9351,	Adjusted R-squared: 0.9119 
#F-statistic: 40.21 on 19 and 53 DF,  p-value: < 2.2e-16 

round(coef(summary(model2)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    3.683      0.997   3.695    0.001
#DAs           -0.739      1.460  -0.506    0.615
#DEm            0.556      1.384   0.402    0.690
#DSa           -0.985      2.908  -0.339    0.736
#Wage          -0.478      0.154  -3.099    0.003
#Bread          0.082      0.107   0.767    0.447
#Rice           0.222      0.123   1.811    0.076
#Vac            0.022      0.007   3.096    0.003
#DAsWage       -0.104      0.189  -0.551    0.584
#DAsBread       0.568      0.184   3.091    0.003
#DAsRice       -0.464      0.202  -2.292    0.026
#DAsVac         0.054      0.022   2.486    0.016
#DEmWage       -0.051      0.214  -0.240    0.811
#DEmBread       0.208      0.176   1.185    0.241
#DEmRice       -0.011      0.204  -0.055    0.956
#DEmVac        -0.045      0.015  -2.929    0.005
#DSaWage       -0.130      0.461  -0.282    0.779
#DSaBread       0.691      0.190   3.643    0.001
#DSaRice       -0.161      0.385  -0.418    0.678
#DSaVac        -0.008      0.013  -0.575    0.568

model3 <- lm(Bigmac ~ DAs + DEm + DSa + Wage + Bread + Rice + Vac
             + DAsWage + DAsBread + DAsRice + DAsVac
             + DEmBread + DEmVac
             + DSaBread + DSaRice + DSaVac)
anova(model3, model2)
#  Res.Df    RSS Df Sum of Sq      F Pr(>F)
#1     56 1.9243                           
#2     53 1.9198  3 0.0045205 0.0416 0.9886

(sum(residuals(model3)^2)-sum(residuals(model2)^2))/3 /
  (sum(residuals(model2)^2)/53) # F = 0.04160049
qf(0.95,3,53) # 2.779114
pf(0.0416,3,53,lower.tail=F) # 0.9885684

summary(model3)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  3.873477   0.707313   5.476 1.06e-06 ***
#DAs         -0.929363   1.256451  -0.740  0.46259    
#DEm          0.282447   0.565201   0.500  0.61922    
#DSa         -1.752632   0.898657  -1.950  0.05615 .  
#Wage        -0.511492   0.100893  -5.070 4.66e-06 ***
#Bread        0.075781   0.102562   0.739  0.46306    
#Rice         0.209768   0.092579   2.266  0.02735 *  
#Vac          0.022123   0.006832   3.238  0.00203 ** 
#DAsWage     -0.070473   0.146160  -0.482  0.63157 !   
#DAsBread     0.574068   0.177613   3.232  0.00206 ** 
#DAsRice     -0.451451   0.182008  -2.480  0.01616 *  
#DAsVac       0.054183   0.021215   2.554  0.01340 *  
#DEmBread     0.224488   0.158454   1.417  0.16210    
#DEmVac      -0.045118   0.013701  -3.293  0.00172 ** 
#DSaBread     0.714585   0.166165   4.300 6.89e-05 ***
#DSaRice     -0.076633   0.179529  -0.427  0.67112 !   
#DSaVac      -0.007269   0.012880  -0.564  0.57475 !   
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1854 on 56 degrees of freedom
#Multiple R-squared: 0.935,	Adjusted R-squared: 0.9164 
#F-statistic: 50.33 on 16 and 56 DF,  p-value: < 2.2e-16 

model4 <- lm(Bigmac ~ DAs + DEm + DSa + Wage + Bread + Rice + Vac
             + DAsBread + DAsRice + DAsVac
             + DEmBread + DEmVac
             + DSaBread)
anova(model4, model3)
#  Res.Df    RSS Df Sum of Sq      F Pr(>F)
#1     59 1.9464                           
#2     56 1.9243  3  0.022104 0.2144  0.886

(sum(residuals(model4)^2)-sum(residuals(model3)^2))/3 /
  (sum(residuals(model3)^2)/56) # F = 0.2144228
qf(0.95,3,56) # 2.769431
pf(0.2144,3,56,lower.tail=F) # 0.886012

summary(model4)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  4.110961   0.553962   7.421 5.23e-10 ***
#DAs         -1.512860   0.632105  -2.393 0.019894 *  
#DEm          0.212223   0.542260   0.391 0.696935    
#DSa         -2.219990   0.508840  -4.363 5.23e-05 ***
#Wage        -0.541401   0.071295  -7.594 2.67e-10 ***
#Bread        0.065805   0.098576   0.668 0.507019    
#Rice         0.189425   0.073788   2.567 0.012809 *  
#Vac          0.020716   0.005185   3.995 0.000182 ***
#DAsBread     0.608153   0.163987   3.709 0.000463 ***
#DAsRice     -0.394569   0.137903  -2.861 0.005830 ** 
#DAsVac       0.057814   0.019994   2.892 0.005358 ** 
#DEmBread     0.226347   0.154589   1.464 0.148451    
#DEmVac      -0.042906   0.012967  -3.309 0.001600 ** 
#DSaBread     0.729123   0.153530   4.749 1.35e-05 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1816 on 59 degrees of freedom
#Multiple R-squared: 0.9342,	Adjusted R-squared: 0.9197 
#F-statistic: 64.47 on 13 and 59 DF,  p-value: < 2.2e-16 

round(coef(summary(model4)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    4.111      0.554   7.421    0.000
#DAs           -1.513      0.632  -2.393    0.020
#DEm            0.212      0.542   0.391    0.697
#DSa           -2.220      0.509  -4.363    0.000
#Wage          -0.541      0.071  -7.594    0.000
#Bread          0.066      0.099   0.668    0.507
#Rice           0.189      0.074   2.567    0.013
#Vac            0.021      0.005   3.995    0.000
#DAsBread       0.608      0.164   3.709    0.000
#DAsRice       -0.395      0.138  -2.861    0.006
#DAsVac         0.058      0.020   2.892    0.005
#DEmBread       0.226      0.155   1.464    0.148
#DEmVac        -0.043      0.013  -3.309    0.002
#DSaBread       0.729      0.154   4.749    0.000

qt(0.975,59) # 2.000995

model5 <- lm(Bigmac ~ DAs + DEm + DSa + Wage + Bread + Rice + Vac
             + DAsBread + DAsRice + DAsVac
             + DEmVac
             + DSaBread)
summary(model5)
#             Estimate Std. Error t value Pr(>|t|)    
#(Intercept)  3.861757   0.532170   7.257 9.12e-10 ***
#DAs         -1.207924   0.602473  -2.005 0.049487 *  
#DEm          0.876811   0.299504   2.928 0.004821 ** 
#DSa         -1.991641   0.488946  -4.073 0.000138 ***
#Wage        -0.547934   0.071831  -7.628 2.11e-10 ***
#Bread        0.154348   0.078586   1.964 0.054162 .  
#Rice         0.195452   0.074372   2.628 0.010889 *  
#Vac          0.021595   0.005199   4.153 0.000105 ***
#DAsBread     0.515727   0.152786   3.375 0.001297 ** 
#DAsRice     -0.406481   0.138969  -2.925 0.004856 ** 
#DAsVac       0.056577   0.020165   2.806 0.006759 ** 
#DEmVac      -0.043681   0.013079  -3.340 0.001446 ** 
#DSaBread     0.641239   0.142652   4.495 3.24e-05 ***
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.1834 on 60 degrees of freedom
#Multiple R-squared: 0.9318,	Adjusted R-squared: 0.9182 
#F-statistic: 68.36 on 12 and 60 DF,  p-value: < 2.2e-16 

round(coef(summary(model5)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    3.862      0.532   7.257    0.000
#DAs           -1.208      0.602  -2.005    0.049
#DEm            0.877      0.300   2.928    0.005
#DSa           -1.992      0.489  -4.073    0.000
#Wage          -0.548      0.072  -7.628    0.000
#Bread          0.154      0.079   1.964    0.054
#Rice           0.195      0.074   2.628    0.011
#Vac            0.022      0.005   4.153    0.000
#DAsBread       0.516      0.153   3.375    0.001
#DAsRice       -0.406      0.139  -2.925    0.005
#DAsVac         0.057      0.020   2.806    0.007
#DEmVac        -0.044      0.013  -3.340    0.001
#DSaBread       0.641      0.143   4.495    0.000

round(coef(summary(model5)),4)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   3.8618     0.5322  7.2566   0.0000
#DAs          -1.2079     0.6025 -2.0049   0.0495
#DEm           0.8768     0.2995  2.9275   0.0048
#DSa          -1.9916     0.4889 -4.0733   0.0001
#Wage         -0.5479     0.0718 -7.6281   0.0000
#Bread         0.1543     0.0786  1.9640   0.0542
#Rice          0.1955     0.0744  2.6280   0.0109
#Vac           0.0216     0.0052  4.1533   0.0001
#DAsBread      0.5157     0.1528  3.3755   0.0013
#DAsRice      -0.4065     0.1390 -2.9250   0.0049
#DAsVac        0.0566     0.0202  2.8057   0.0068
#DEmVac       -0.0437     0.0131 -3.3397   0.0014
#DSaBread      0.6412     0.1427  4.4951   0.0000

rstu5 <- rstudent(model5)

postscript("insman/ubs3.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
scatter.smooth(Bread, rstu5, span=0.75,
               xlab="Bread",
               ylab="Model 5 studentized residual")
par(oldpar)
dev.off()

mWage <- mean(Wage)
mBread <- mean(Bread)
mRice <- mean(Rice)
mVac <- mean(Vac)

c(mWage, mBread, mRice, mVac)
#  3.568836  3.040534  2.916767 20.041096

# Wage effect

round(coef(model5)[5],3) # -0.548 

# Bread effect

# North America, Western Europe, and Oceania
3.8618 - 0.5479*3.5688 + 0.1955*2.9168 + 0.0216*20.0411 # 2.909577
# 0.1543

round(c(cbind(1, 0, 0, 0, 
              mWage, 0, mRice, mVac, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 1, 0, 0, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.909 0.154

# Asia
3.8618 - 1.2079 - 0.5479*3.5688 + 0.1955*2.9168 + 0.0216*20.0411 -
  0.4065*2.9168 + 0.0566*20.0411 # 1.650324
0.1543 + 0.5157 # 0.67

round(c(cbind(1, 1, 0, 0, 
              mWage, 0, mRice, mVac, 
              0, mRice, mVac, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 1, 0, 0, 
              1, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 1.649 0.670

# Eastern Europe and the Middle East
3.8618 + 0.8768 - 0.5479*3.5688 + 0.1955*2.9168 + 0.0216*20.0411 -
  0.0437*20.0411 # 2.910581
# 0.1543

round(c(cbind(1, 0, 1, 0, 
              mWage, 0, mRice, mVac, 
              0, 0, 0, 
              mVac, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 1, 0, 0, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.911 0.154

# South America and Africa
3.8618 - 1.9916 - 0.5479*3.5688 + 0.1955*2.9168 + 0.0216*20.0411 # 0.9179766
0.1543 + 0.6412 # 0.7955

round(c(cbind(1, 0, 0, 1, 
              mWage, 0, mRice, mVac, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 1, 0, 0, 
              0, 0, 0, 
              0, 
              1) %*% coef(model5)), 3)
# 0.917 0.796

Breadeffect <- cbind(1, DAs, DEm, DSa, mWage, Bread, mRice, mVac, DAsBread,
                     DAs*mRice, DAs*mVac, DEm*mVac, DSaBread) %*% coef(model5)

Breadeffect1 <- Breadeffect[DNw==1]
Breadeffect2 <- Breadeffect[DAs==1]
Breadeffect3 <- Breadeffect[DEm==1]
Breadeffect4 <- Breadeffect[DSa==1]

postscript("insman/ubs4.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Bread, Breadeffect, type="n",
     xlab="Bread",
     ylab="Bread effect on Bigmac")
lines(sort(Bread[DNw==1]), Breadeffect1[order(Bread[DNw==1])], col="red")
lines(sort(Bread[DAs==1]), Breadeffect2[order(Bread[DAs==1])], col="blue")
lines(sort(Bread[DEm==1]), Breadeffect3[order(Bread[DEm==1])], col="green")
lines(sort(Bread[DSa==1]), Breadeffect4[order(Bread[DSa==1])], col="orange")
text(2.7,3.15,"N.America, W.Europe, Oceania", col="red")
text(2.6,3.55,"Asia", col="blue")
text(3.8,3.35,"E.Europe, Middle East", col="green")
text(3.0,2.9,"S.America, Africa", col="orange")
par(oldpar)
dev.off()

# Rice effect

# North America, Western Europe, and Oceania
3.8618 - 0.5479*3.5688 + 0.1543*3.0405 + 0.0216*20.0411 # 2.808491
# 0.1955

round(c(cbind(1, 0, 0, 0,
              mWage, mBread, 0, mVac,
              0, 0, 0,
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 1, 0, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.808 0.195

# Asia
3.8618 - 1.2079 - 0.5479*3.5688 + 0.1543*3.0405 + 0.0216*20.0411 +
  0.5157*3.0405 + 0.0566*20.0411 # 4.302904
0.1955 - 0.4065 # -0.211

round(c(cbind(1, 1, 0, 0, 
              mWage, mBread, 0, mVac, 
              mBread, 0, mVac, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 1, 0, 
              0, 1, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 4.302 -0.211

# Eastern Europe and the Middle East
3.8618 + 0.8768 - 0.5479*3.5688 + 0.1543*3.0405 + 0.0216*20.0411 -
  0.0437*20.0411 # 2.809495
# 0.1955

round(c(cbind(1, 0, 1, 0, 
              mWage, mBread, 0, mVac, 
              0, 0, 0, 
              mVac, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 1, 0, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.810 0.195

# South America and Africa
3.8618 - 1.9916 - 0.5479*3.5688 + 0.1543*3.0405 + 0.0216*20.0411 +
  0.6412*3.0405 # 2.76646
# 0.1955

round(c(cbind(1, 0, 0, 1, 
              mWage, mBread, 0, mVac, 
              0, 0, 0, 
              0, 
              mBread) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 1, 0, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.766 0.195

Riceeffect <- cbind(1, DAs, DEm, DSa, mWage, mBread, Rice, mVac, DAs*mBread, DAsRice, DAs*mVac, DEm*mVac, DSa*mBread) %*% coef(model5)

Riceeffect1 <- Riceeffect[DNw==1]
Riceeffect2 <- Riceeffect[DAs==1]
Riceeffect3 <- Riceeffect[DEm==1]
Riceeffect4 <- Riceeffect[DSa==1]

postscript("insman/ubs5.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Rice, Riceeffect, type="n",
     xlab="Rice",
     ylab="Rice effect on log(Bigmac)")
lines(sort(Rice[DNw==1]), Riceeffect1[order(Rice[DNw==1])], col="red")
lines(sort(Rice[DAs==1]), Riceeffect2[order(Rice[DAs==1])], col="blue")
lines(sort(Rice[DEm==1]), Riceeffect3[order(Rice[DEm==1])], col="green")
lines(sort(Rice[DSa==1]), Riceeffect4[order(Rice[DSa==1])], col="orange")
text(2.8,3.21,"N.America, W.Europe, Oceania", col="red")
text(3.1,3.60,"Asia", col="blue")
text(3.8,3.65,"E.Europe, Middle East", col="green")
text(2.9,3.25,"S.America, Africa", col="orange")
par(oldpar)
dev.off()

# Vac affect

# North America, Western Europe, and Oceania
3.8618 - 0.5479*3.5688 + 0.1543*3.0405 + 0.1955*2.9168 # 2.945838
# 0.0216

round(c(cbind(1, 0, 0, 0,
              mWage, mBread, mRice, 0,
              0, 0, 0,
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 0, 1, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.946 0.022

# Asia
3.8618 - 1.2079 - 0.5479*3.5688 + 0.1543*3.0405 + 0.1955*2.9168 +
  0.5157*3.0405 - 0.4065*2.9168 # 2.120245
0.0216 + 0.0566 # 0.0782

round(c(cbind(1, 1, 0, 0, 
              mWage, mBread, mRice, 0,
              mBread, mRice, 0, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 0, 1,
              0, 0, 1, 
              0, 
              0) %*% coef(model5)), 3)
# 2.120 0.078

# Eastern Europe and the Middle East
3.8618 + 0.8768 - 0.5479*3.5688 + 0.1543*3.0405 + 0.1955*2.9168 # 3.822638
0.0216 - 0.0437 # -0.0221

round(c(cbind(1, 0, 1, 0, 
              mWage, mBread, mRice, 0,
              0, 0, 0, 
              0, 
              0) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 0, 1, 
              0, 0, 0, 
              1,
              0) %*% coef(model5)), 3)
# 3.822 -0.022

# South America and Africa
3.8618 - 1.9916 - 0.5479*3.5688 + 0.1543*3.0405 + 0.1955*2.9168 +
  0.6412*3.0405 # 2.903807
# 0.0216

round(c(cbind(1, 0, 0, 1, 
              mWage, mBread, mRice, 0,
              0, 0, 0, 
              0, 
              mBread) %*% coef(model5),
        cbind(0, 0, 0, 0, 
              0, 0, 0, 1, 
              0, 0, 0, 
              0, 
              0) %*% coef(model5)), 3)
# 2.904 0.022

Vaceffect <- cbind(1, DAs, DEm, DSa, mWage, mBread, mRice, Vac, DAs*mBread, DAs*mRice, DAsVac, DEmVac, DSa*mBread) %*% coef(model5)

Vaceffect1 <- Vaceffect[DNw==1]
Vaceffect2 <- Vaceffect[DAs==1]
Vaceffect3 <- Vaceffect[DEm==1]
Vaceffect4 <- Vaceffect[DSa==1]

postscript("insman/ubs6.eps",
           width = 3.5, height = 2.625, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Vac, Vaceffect, type="n",
     xlab="Vac",
     ylab="Vac effect on log(Bigmac)")
lines(sort(Vac[DNw==1]), Vaceffect1[order(Vac[DNw==1])], col="red")
lines(sort(Vac[DAs==1]), Vaceffect2[order(Vac[DAs==1])], col="blue")
lines(sort(Vac[DEm==1]), Vaceffect3[order(Vac[DEm==1])], col="green")
lines(sort(Vac[DSa==1]), Vaceffect4[order(Vac[DSa==1])], col="orange")
text(20,3.56,"N.America, W.Europe, Oceania", col="red")
text(11,2.82,"Asia", col="blue")
text(23,3.15,"E.Europe, Middle East", col="green")
text(10,3.00,"S.America, Africa", col="orange")
par(oldpar)
dev.off()

detach(ubs)
rm(list = ls())

# 5.13 restaurant - model building

restaurant <- read.csv("data/restaurant.csv")
attach(restaurant)

pairs(cbind(Profit, Cov, Fco, Oco, Lco), pch=as.character(Region))

model1 <- lm(Profit ~ Cov + Fco + Oco + Lco + DSw + DNw)
summary(model1)
#Residual standard error: 11.85 on 113 degrees of freedom
#Multiple R-squared: 0.9078,	Adjusted R-squared: 0.9029 

scatter.smooth(Lco, residuals(model1), span=0.75)

DSwCov <- DSw*Cov
DSwFco <- DSw*Fco
DSwOco <- DSw*Oco
DSwLco <- DSw*Lco
DNwCov <- DNw*Cov
DNwFco <- DNw*Fco
DNwOco <- DNw*Oco
DNwLco <- DNw*Lco

model2 <- lm(Profit ~ Cov + Fco + Oco + Lco + DSw + DNw +
               DSwCov + DSwFco + DSwOco + DSwLco + DNwCov +
               DNwFco + DNwOco + DNwLco)
summary(model2)
#Residual standard error: 10.89 on 105 degrees of freedom
#Multiple R-squared: 0.9277,	Adjusted R-squared: 0.918 

scatter.smooth(Lco, residuals(model2), span=0.75)

Cov2 <- Cov^2
Fco2 <- Fco^2
Oco2 <- Oco^2
Lco2 <- Lco^2

model3 <- lm(Profit ~ Cov + Fco + Oco + Lco + DSw + DNw +
               DSwCov + DSwFco + DSwOco + DSwLco + DNwCov +
               DNwFco + DNwOco + DNwLco + Cov2 + Fco2 + Oco2 + Lco2)
summary(model3)
#Residual standard error: 10.13 on 101 degrees of freedom
#Multiple R-squared: 0.9398,	Adjusted R-squared: 0.929 

scatter.smooth(Lco, residuals(model3), span=0.75)

model4 <- lm(Profit ~ Cov + Fco + Oco + Lco + DSw + DNw +
               DSwOco + DSwLco + DNwCov + DNwOco + DNwLco +
               Cov2 + Oco2 + Lco2)
anova(model4, model3)
#  Res.Df   RSS Df Sum of Sq      F Pr(>F)
#1    105 10578                           
#2    101 10373  4    204.87 0.4987 0.7367

summary(model4)
#Residual standard error: 10.04 on 105 degrees of freedom
#Multiple R-squared: 0.9386,	Adjusted R-squared: 0.9304 

model5 <- lm(Profit ~ Cov + Fco + Oco + Lco + DSw + DNw +
               DSwOco + DSwLco + DNwCov + DNwOco + Oco2 + Lco2)
anova(model5, model4)
#  Res.Df   RSS Df Sum of Sq      F Pr(>F)
#1    107 10845                           
#2    105 10578  2    267.07 1.3255 0.2701

summary(model5)
#               Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  50.387177  27.010458   1.865 0.064855 .  
# Cov          26.822236   1.242767  21.583  < 2e-16 ***
# Fco          -0.910472   0.125682  -7.244 7.03e-11 ***
# Oco          -1.542986   0.483853  -3.189 0.001873 ** 
# Lco          -2.286140   0.578230  -3.954 0.000138 ***
# DSw         -11.526722  13.700418  -0.841 0.402033    
# DNw         -22.538830  16.052192  -1.404 0.163186    
# DSwOco       -0.419513   0.181716  -2.309 0.022886 *  
# DSwLco        0.602873   0.189933   3.174 0.001963 ** 
# DNwCov       -4.250797   1.350441  -3.148 0.002132 ** 
# DNwOco        0.355760   0.177879   2.000 0.048034 *  
# Oco2          0.005927   0.002653   2.234 0.027551 *  
# Lco2          0.007670   0.002852   2.690 0.008299 ** 
# ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 10.07 on 107 degrees of freedom
# Multiple R-squared:  0.937,	Adjusted R-squared:  0.9299 
# F-statistic: 132.6 on 12 and 107 DF,  p-value: < 2.2e-16

scatter.smooth(Lco, residuals(model5), span=0.75)

plot(model5)

max(cooks.distance(model5)) # 0.1381202

mean.Cov <- mean(Cov)
mean.Fco <- mean(Fco)
mean.Oco <- mean(Oco)
mean.Lco <- mean(Lco)

# Cov effect

round(c(cbind(1, 0, mean.Fco, mean.Oco, mean.Lco,
              0, 0, 0, 0, 0, 0, mean.Oco^2, mean.Lco^2) %*%
          coef(model5),
        cbind(0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5)), 2)
# -324.33   26.82

round(c(cbind(1, 0, mean.Fco, mean.Oco, mean.Lco, 
              1, 0, mean.Oco, mean.Lco, 0, 0, mean.Oco^2, 
              mean.Lco^2) %*%
          coef(model5),
        cbind(0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5)), 2)
# -312.85   26.82

round(c(cbind(1, 0, mean.Fco, mean.Oco, mean.Lco, 
              0, 1, 0, 0, 0, mean.Oco, mean.Oco^2, mean.Lco^2) 
        %*% coef(model5),
        cbind(0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0) %*% coef(model5)), 2)
# -316.99   22.57

Coveffect <- cbind(1, Cov, mean.Fco, mean.Oco, mean.Lco, 
                   DSw, DNw, DSw*mean.Oco, DSw*mean.Lco, 
                   DNw*Cov, DNw*mean.Oco, mean.Oco^2, mean.Lco^2) %*% coef(model5)

Coveffectmtn <- Coveffect[Region=="Mtn"]
Coveffectsw <- Coveffect[Region=="SW"]
Coveffectnw <- Coveffect[Region=="NW"]

postscript("insman/restaurant1.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Cov, Coveffect, type="n",
     xlab="Cov", 
     #     ylim=c(0, 11),
     ylab="Model 5: Cov effect on Profits")
lines(sort(Cov[Region=="Mtn"]), Coveffectmtn[order(Cov[Region=="Mtn"])], col="red")
#abline(-324.33,26.82)
lines(sort(Cov[Region=="SW"]), Coveffectsw[order(Cov[Region=="SW"])], col="blue")
#abline(-312.85,26.82)
lines(sort(Cov[Region=="NW"]), Coveffectnw[order(Cov[Region=="NW"])], col="green")
#abline(-316.99,22.57)
text(min(Cov[Region=="Mtn"]),Coveffectmtn[order(Cov[Region=="Mtn"])][1],"Mtn")
text(min(Cov[Region=="SW"]),Coveffectsw[order(Cov[Region=="SW"])][1],"SW")
text(min(Cov[Region=="NW"]),Coveffectnw[order(Cov[Region=="NW"])][1],"NW")
par(oldpar)
dev.off()

# Fco effect

round(c(cbind(1, mean.Cov, 0, mean.Oco, mean.Lco, 
              0, 0, 0, 0, 0, 0, mean.Oco^2, mean.Lco^2) %*%
          coef(model5),
        cbind(0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5)), 2)
# 215.55  -0.91

round(c(cbind(1, mean.Cov, 0, mean.Oco, mean.Lco, 
              1, 0, mean.Oco, mean.Lco, 0, 0, mean.Oco^2, 
              mean.Lco^2) %*%
          coef(model5),
        cbind(0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5)), 2)
# 227.03  -0.91

round(c(cbind(1, mean.Cov, 0, mean.Oco, mean.Lco, 
              0, 1, 0, 0, mean.Cov, mean.Oco, mean.Oco^2, 
              mean.Lco^2) 
        %*% coef(model5),
        cbind(0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5)), 2)
# 159.15  -0.91

Fcoeffect <- cbind(1, mean.Cov, Fco, mean.Oco, mean.Lco, 
                   DSw, DNw, DSw*mean.Oco, DSw*mean.Lco, 
                   DNw*mean.Cov, DNw*mean.Oco, mean.Oco^2, mean.Lco^2) %*% coef(model5)

Fcoeffectmtn <- Fcoeffect[Region=="Mtn"]
Fcoeffectsw <- Fcoeffect[Region=="SW"]
Fcoeffectnw <- Fcoeffect[Region=="NW"]

postscript("insman/restaurant2.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Fco, Fcoeffect, type="n",
     xlab="Fco", 
     #     ylim=c(0, 11),
     ylab="Model 5: Fco effect on Profits")
lines(sort(Fco[Region=="Mtn"]), Fcoeffectmtn[order(Fco[Region=="Mtn"])], col="red")
#abline(215.55,-0.91)
lines(sort(Fco[Region=="SW"]), Fcoeffectsw[order(Fco[Region=="SW"])], col="blue")
#abline(227.03,-0.91)
lines(sort(Fco[Region=="NW"]), Fcoeffectnw[order(Fco[Region=="NW"])], col="green")
#abline(159.15,-0.91)
text(min(Fco[Region=="Mtn"]),Fcoeffectmtn[order(Fco[Region=="Mtn"])][1],"Mtn")
text(min(Fco[Region=="SW"]),Fcoeffectsw[order(Fco[Region=="SW"])][1],"SW")
text(min(Fco[Region=="NW"]),Fcoeffectnw[order(Fco[Region=="NW"])][1],"NW")
par(oldpar)
dev.off()

# Oco effect

round(c(cbind(1, mean.Cov, mean.Fco, 0, mean.Lco, 
              0, 0, 0, 0, 0, 0, 0, mean.Lco^2) %*%
          coef(model5),
        cbind(0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0) %*% coef(model5)), 4)
# 165.6932  -1.5430   0.0059

round(c(cbind(1, mean.Cov, mean.Fco, 0, mean.Lco, 
              1, 0, 0, mean.Lco, 0, 0, 0, 
              mean.Lco^2) %*%
          coef(model5),
        cbind(0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0) %*% coef(model5)), 4)
# 212.4131  -1.9625   0.0059

round(c(cbind(1, mean.Cov, mean.Fco, 0, mean.Lco, 
              0, 1, 0, 0, mean.Cov, 0, 0, 
              mean.Lco^2) 
        %*% coef(model5),
        cbind(0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0) %*% coef(model5)), 4)
# 79.4079 -1.1872  0.0059

Ocoeffect <- cbind(1, mean.Cov, mean.Fco, Oco, mean.Lco, 
                   DSw, DNw, DSw*Oco, DSw*mean.Lco, 
                   DNw*mean.Cov, DNw*Oco, Oco^2, mean.Lco^2) %*% coef(model5)

Ocoeffectmtn <- Ocoeffect[Region=="Mtn"]
Ocoeffectsw <- Ocoeffect[Region=="SW"]
Ocoeffectnw <- Ocoeffect[Region=="NW"]

postscript("insman/restaurant1.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Oco, Ocoeffect, type="n",
     xlab="Oco", 
     #     ylim=c(0, 11),
     ylab="Model 5: Oco effect on Profits")
lines(sort(Oco[Region=="Mtn"]), Ocoeffectmtn[order(Oco[Region=="Mtn"])], col="red")
#plotOco <- seq(min(Oco),max(Oco),length.out=120)
#lines(plotOco, 165.6932-1.5430*plotOco+ 0.0059*plotOco^2)
lines(sort(Oco[Region=="SW"]), Ocoeffectsw[order(Oco[Region=="SW"])], col="blue")
#lines(plotOco, 212.4131-1.9625*plotOco+ 0.0059*plotOco^2)
lines(sort(Oco[Region=="NW"]), Ocoeffectnw[order(Oco[Region=="NW"])], col="green")
#lines(plotOco, 79.4079-1.1872*plotOco+ 0.0059*plotOco^2)
text(min(Oco[Region=="Mtn"]),Ocoeffectmtn[order(Oco[Region=="Mtn"])][1],"Mtn")
text(min(Oco[Region=="SW"]),Ocoeffectsw[order(Oco[Region=="SW"])][1],"SW")
text(min(Oco[Region=="NW"]),Ocoeffectnw[order(Oco[Region=="NW"])][1],"NW")
par(oldpar)
dev.off()

# Lco effect

round(c(cbind(1, mean.Cov, mean.Fco, mean.Oco, 
              0, 0, 0, 0, 0, 0, 0, mean.Oco^2, 0) %*%
          coef(model5),
        cbind(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1) %*% coef(model5)), 4)
# 227.1789  -2.2861   0.0077

round(c(cbind(1, mean.Cov, mean.Fco, mean.Oco, 
              0, 1, 0, mean.Oco, 0, 0, 0, mean.Oco^2, 0) %*%
          coef(model5),
        cbind(0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1) %*% coef(model5)), 4)
# 180.4125  -1.6833   0.0077

round(c(cbind(1, mean.Cov, mean.Fco, mean.Oco, 
              0, 0, 1, 0, 0, mean.Cov, mean.Oco, mean.Oco^2, 0) 
        %*% coef(model5),
        cbind(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0) %*% coef(model5),
        cbind(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1) %*% coef(model5)), 4)
# 170.7780  -2.2861   0.0077

Lcoeffect <- cbind(1, mean.Cov, mean.Fco, mean.Oco, 
                   Lco, DSw, DNw, DSw*mean.Oco, DSw*Lco, 
                   DNw*mean.Cov, DNw*mean.Oco, mean.Oco^2, Lco^2) %*% coef(model5)

Lcoeffectmtn <- Lcoeffect[Region=="Mtn"]
Lcoeffectsw <- Lcoeffect[Region=="SW"]
Lcoeffectnw <- Lcoeffect[Region=="NW"]

postscript("insman/restaurant1.eps",
           width = 2.5, height = 1.875, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Lco, Lcoeffect, type="n",
     xlab="Lco", 
     #     ylim=c(0, 11),
     ylab="Model 5: Lco effect on Profits")
lines(sort(Lco[Region=="Mtn"]), Lcoeffectmtn[order(Lco[Region=="Mtn"])], col="red")
#plotLco <- seq(min(Lco),max(Lco),length.out=120)
#lines(plotLco, 227.1789-2.2861*plotLco+ 0.0077*plotLco^2)
lines(sort(Lco[Region=="SW"]), Lcoeffectsw[order(Lco[Region=="SW"])], col="blue")
#lines(plotLco, 180.4125-1.6833*plotLco+ 0.0077*plotLco^2)
lines(sort(Lco[Region=="NW"]), Lcoeffectnw[order(Lco[Region=="NW"])], col="green")
#lines(plotLco, 170.7780-2.2861*plotLco+ 0.0077*plotLco^2)
text(min(Lco[Region=="Mtn"]),Lcoeffectmtn[order(Lco[Region=="Mtn"])][1],"Mtn")
text(min(Lco[Region=="SW"]),Lcoeffectsw[order(Lco[Region=="SW"])][1],"SW")
text(min(Lco[Region=="NW"]),Lcoeffectnw[order(Lco[Region=="NW"])][1],"NW")
par(oldpar)
dev.off()

detach(restaurant)
