# Chapter 6: Case Studies

setwd("~/Teaching/arm3e/")

# 6.1 Home prices

# homes6

homes6 <- read.csv("data/homes6.csv")
homes6x <- homes6[-77,] # remove observation missing Price
attach(homes6x)

postscript("manuscript/figures/splomhomes4.eps",
           width = 5.0, height = 5.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Price, Floor, Lot, Bath, Bed, Age, Gar), cex.labels=1.3,
      labels=c("Price", "Floor", "Lot", "Bath",
        "Bed", "Age", "Gar"))
dev.off()

postscript("manuscript/figures/boxhomes4a.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
boxplot(Price ~ DAc, boxwex=.4, cex.axis=.68,
        xlab = "DAc = indicator for active status",
        ylab = "Price = sale price in $ thousands")
par(oldpar)
dev.off()

postscript("manuscript/figures/boxhomes4b.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,0)+0.1, mgp=c(2,1,0))
School1 <- factor(School,
         levels=c("Redwood","Edison","Harris","Adams","Crest","Parker"))
boxplot(Price ~ School1, boxwex=.5, cex.axis=.68,
        xlab = "Nearest elementary school",
        ylab = "Price = sale price in $ thousands")
par(oldpar)
dev.off()

model1 <- lm(Price ~ Floor + Lot + Bath + Bed + Age + Gar +
               DAc + DEd + DHa + DAd + DCr + DPa)
summary(model1)
#Residual standard error: 45.11 on 63 degrees of freedom
#Multiple R-squared: 0.5305,	Adjusted R-squared: 0.4411 
#F-statistic: 5.932 on 12 and 63 DF,  p-value: 8.902e-07 

scatter.smooth(Age, residuals(model1), span=0.75,
               xlab="Age",ylab="Model 1 residuals")

model2 <- lm(Price ~ Floor + Lot + Bath + Bed + BathBed + Age + AgeSq + Gar +
               DAc + DEd + DHa + DAd + DCr + DPa)
summary(model2)
#            Estimate Std. Error t value Pr(>|t|)   
#(Intercept) 337.6528   124.9619   2.702  0.00891 **
#Floor        58.7715    29.2568   2.009  0.04899 * 
#Lot          10.3614     3.5731   2.900  0.00518 **
#Bath        -98.7324    47.9506  -2.059  0.04377 * 
#Bed         -77.4802    32.3251  -2.397  0.01961 * 
#BathBed      29.6564    13.6582   2.171  0.03381 * 
#Age           3.7773     3.2371   1.167  0.24781   
#AgeSq         1.8237     0.7571   2.409  0.01904 * 
#Gar          10.6769     8.7030   1.227  0.22461   
#DAc          30.3595    12.2685   2.475  0.01614 * 
#DEd          59.2151    18.2076   3.252  0.00187 **
#DHa          40.2357    16.3716   2.458  0.01684 * 
#DAd         -28.8884    28.2176  -1.024  0.30998   
#DCr          -8.8829    21.6213  -0.411  0.68263   
#DPa         -13.9343    16.0736  -0.867  0.38939   
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 42.37 on 61 degrees of freedom
#Multiple R-squared: 0.5989,	Adjusted R-squared: 0.5068 
#F-statistic: 6.506 on 14 and 61 DF,  p-value: 8.901e-08 

plot(model2)
scatter.smooth(Age, residuals(model2), span=0.75,
               xlab="Age",ylab="Model 2 residuals")

model3 <- lm(Price ~ Floor + Lot + Bath + Bed + BathBed + 
               Age + AgeSq + Gar + DAc + DEd + DHa)
anova(model3,model2)
#  Res.Df    RSS Df Sum of Sq      F Pr(>F)
#1     64 112395                           
#2     61 109505  3    2889.6 0.5366  0.659

summary(model3)
#            Estimate Std. Error t value Pr(>|t|)    
#(Intercept) 332.4707   106.5991   3.119 0.002721 ** 
#Floor        56.7212    27.9738   2.028 0.046763 *  
#Lot           9.9162     3.4379   2.884 0.005337 ** 
#Bath        -98.1533    42.6664  -2.300 0.024690 *  
#Bed         -78.9090    27.7518  -2.843 0.005985 ** 
#BathBed      30.3895    11.8780   2.558 0.012891 *  
#Age           3.3016     3.1695   1.042 0.301475    
#AgeSq         1.6414     0.7333   2.238 0.028676 *  
#Gar          13.1182     8.2845   1.583 0.118246    
#DAc          27.4256    10.9885   2.496 0.015153 *  
#DEd          67.0624    16.8220   3.987 0.000175 ***
#DHa          47.2747    14.8443   3.185 0.002239 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 41.91 on 64 degrees of freedom
#Multiple R-squared: 0.5883,	Adjusted R-squared: 0.5175 
#F-statistic: 8.314 on 11 and 64 DF,  p-value: 7.694e-09 

round(coef(summary(model3)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)  332.471    106.599   3.119    0.003
#Floor         56.721     27.974   2.028    0.047
#Lot            9.916      3.438   2.884    0.005
#Bath         -98.153     42.666  -2.300    0.025
#Bed          -78.909     27.752  -2.843    0.006
#BathBed       30.389     11.878   2.558    0.013
#Age            3.302      3.169   1.042    0.301
#AgeSq          1.641      0.733   2.238    0.029
#Gar           13.118      8.285   1.583    0.118
#DAc           27.426     10.988   2.496    0.015
#DEd           67.062     16.822   3.987    0.000
#DHa           47.275     14.844   3.185    0.002

round(coef(model3),2)
#(Intercept)       Floor         Lot        Bath         Bed     BathBed         Age       AgeSq 
#     332.47       56.72        9.92      -98.15      -78.91       30.39        3.30        1.64 
#        Gar         DAc         DEd         DHa 
#      13.12       27.43       67.06       47.27 

plot(model3)

sort(hatvalues(model3), decreasing=T)[1:2]
#        76        54 
# 0.4501893 0.4266328 

sort(cooks.distance(model3), decreasing=T)[1]
#        54 
# 0.3726125 

range(rstudent(model3))
#-2.55505  2.94432

range(Price) # 155.5 450.0

model0 <- lm(Price ~ 1)

predict(model0, interval="prediction")[1,]
#      fit      lwr      upr 
# 285.7961 164.8180 406.7741 

predict(model3, newdata=homes6[77,], interval="prediction")
#         fit     lwr      upr
# 77 283.0428 197.064 369.0216

k1 <- c(coef(model3) %*% c(1, 0, mean(Lot), mean(Bath), mean(Bed),
                           mean(Bath)*mean(Bed), mean(Age), mean(Age)^2,
                           mean(Gar), 0, 0, 0))
k1 # 134.9226
coef(model3)[2] # 56.72119
Flooreffect <- k1 + coef(model3)[2]*Floor

postscript("manuscript/figures/homesales4x1.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Floor), Flooreffect[order(Floor)],
     xlab="Floor = floor size", ylim=c(210,320),
     ylab="Floor effect on Price", type="l")
par(oldpar)
dev.off()

range(Floor) # 1.440 2.896
range(Flooreffect) # 216.6011 299.1872

k2 <- c(coef(model3) %*% c(1, mean(Floor), 0, mean(Bath), mean(Bed),
                           mean(Bath)*mean(Bed), mean(Age), mean(Age)^2,
                           mean(Gar), 0, 0, 0))
k2 # 207.1513 
coef(model3)[3] # 9.91624 
Loteffect <- k2 + coef(model3)[3]*Lot

postscript("manuscript/figures/homesales4x2.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Lot), Loteffect[order(Lot)],
     xlab="Lot = lot size category", ylim=c(210,320),
     ylab="Lot effect on Price", type="l")
par(oldpar)
dev.off()

range(Lot) # 1 11
range(Loteffect) # 217.0675 316.2299

k3 <- c(coef(model3) %*% c(1, mean(Floor), mean(Lot), 0, 0,
                           0, mean(Age), mean(Age)^2,
                           mean(Gar), 0, 0, 0))
k3 # 504.119 
coef(model3)[4] # -98.15332 
coef(model3)[5] # -78.90896
coef(model3)[6] # 30.38947 
BathBedeffect <- k3 + coef(model3)[4]*Bath + coef(model3)[5]*Bed + coef(model3)[6]*BathBed
Batheffect2 <- BathBedeffect[Bed==2]
Batheffect3 <- BathBedeffect[Bed==3]
Batheffect4 <- BathBedeffect[Bed==4]
Batheffect5 <- BathBedeffect[Bed==5]

k <- 0.05

postscript("manuscript/figures/homesales4x3.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Bath, BathBedeffect, xlim=c(.9,3.2),
     xlab="Bath = # bathrooms", ylim=c(210,320),
     ylab="BathBed effect on Price", type="n", axes=FALSE)
axis(1, 1:3, 1:3)
axis(2)
box()
lines(sort(Bath[Bed==2]), Batheffect2[order(Bath[Bed==2])])
lines(sort(Bath[Bed==3]), Batheffect3[order(Bath[Bed==3])])
lines(sort(Bath[Bed==4]), Batheffect4[order(Bath[Bed==4])])
lines(sort(Bath[Bed==5]), Batheffect5[order(Bath[Bed==5])])
text(min(Bath[Bed==2])-k, Batheffect2[order(Bath[Bed==2])][1],"2", cex=.8)
text(max(Bath[Bed==2])+k, Batheffect2[order(-Bath[Bed==2])][1],"2", cex=.8)
text(min(Bath[Bed==3])-k, Batheffect3[order(Bath[Bed==3])][1],"3", cex=.8)
text(max(Bath[Bed==3])+k, Batheffect3[order(-Bath[Bed==3])][1],"3", cex=.8)
text(min(Bath[Bed==4])-k, Batheffect4[order(Bath[Bed==4])][1],"4", cex=.8)
text(max(Bath[Bed==4])+k, Batheffect4[order(-Bath[Bed==4])][1],"4", cex=.8)
text(min(Bath[Bed==5])-k, Batheffect5[order(Bath[Bed==5])][1],"5", cex=.8)
text(max(Bath[Bed==5])+k, Batheffect5[order(-Bath[Bed==5])][1],"5", cex=.8)
legend("topright", legend="Lines marked by # beds",
       inset = .02, x.intersp = 0, cex = .8)
par(oldpar)
dev.off()

Bedeffect1 <- BathBedeffect[Bath==1]
Bedeffect2 <- BathBedeffect[Bath==2]
Bedeffect3 <- BathBedeffect[Bath==3]
Bedeffect11 <- BathBedeffect[Bath==1.1]
Bedeffect21 <- BathBedeffect[Bath==2.1]
Bedeffect31 <- BathBedeffect[Bath==3.1]

k <- 0.05

postscript("manuscript/figures/homesales4x4.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Bed, BathBedeffect, xlim=c(1.9,5.1), ylim=c(210,320),
     xlab="Bed = # bedrooms",
     ylab="BathBed effect on Price", type="n", axes=FALSE)
axis(1, 2:5, 2:5)
axis(2)
box()
lines(sort(Bed[Bath==1]), Bedeffect1[order(Bed[Bath==1])])
lines(sort(Bed[Bath==2])[-33], Bedeffect2[order(Bed[Bath==2])][-33])
lines(sort(Bed[Bath==3]), Bedeffect3[order(Bed[Bath==3])])
lines(sort(Bed[Bath==1.1]), Bedeffect11[order(Bed[Bath==1.1])])
#lines(sort(Bed[Bath==2.1]), Bedeffect21[order(Bed[Bath==2.1])])
#lines(sort(Bed[Bath==3.1]), Bedeffect31[order(Bed[Bath==3.1])])
text(min(Bed[Bath==1])-k, Bedeffect1[order(Bed[Bath==1])][1],"1", cex=.8)
text(max(Bed[Bath==1.1])+k, Bedeffect11[order(-Bed[Bath==1.1])][1],"1",
     cex=.8)
text(min(Bed[Bath==2])-k, Bedeffect2[order(Bed[Bath==2])][1],"2", cex=.8)
text(5+k, Bedeffect2[order(-Bed[Bath==2])][2],"2", cex=.8)
text(min(Bed[Bath==3])-k, Bedeffect3[order(Bed[Bath==3])][1],"3", cex=.8)
text(max(Bed[Bath==3])+k, Bedeffect3[order(-Bed[Bath==3])][1],"3", cex=.8)
legend("topright", legend="Lines marked by # baths",
       inset = .02, x.intersp = 0, cex = .8)
par(oldpar)
dev.off()

k5 <- c(coef(model3) %*% c(1, mean(Floor), mean(Lot), mean(Bath), mean(Bed),
                           mean(Bath)*mean(Bed), 0, 0,
                           mean(Gar), 0, 0, 0))
k5 # 246.8755 
coef(model3)[7] # 3.301627 
coef(model3)[8] # 1.641359 
Ageeffect <- k5 + coef(model3)[7]*Age + coef(model3)[8]*AgeSq

postscript("manuscript/figures/homesales4x5.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Year), Ageeffect[order(Year)],
     xlab="Year", ylim=c(210,320),
     ylab="Age effect on Price", type="l")
par(oldpar)
dev.off()

range(Year) # 1905 2005
range(Ageeffect) # 245.2152 294.7623
Ageeffect[order(Year)][76] # 278.5378

k6 <- c(coef(model3) %*% c(1, mean(Floor), mean(Lot), mean(Bath), mean(Bed),
                           mean(Bath)*mean(Bed), mean(Age), mean(Age)^2,
                           0, 0, 0, 0))
k6 # 226.1454 
coef(model3)[9] # 13.11824 
Gareffect <- k6 + coef(model3)[9]*Gar

postscript("manuscript/figures/homesales4x6.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(sort(Gar), Gareffect[order(Gar)], lab=c(4,5,7),
     xlab="Gar = garage size", ylim=c(210,320),
     ylab="Garage effect on Price", type="l")
par(oldpar)
dev.off()

range(Gar) # 0 3
range(Gareffect) # 226.1454 265.5001

detach(homes6x)

# 6.2 Vehicle fuel efficiency

# cars6

cars6 <- read.csv("data/cars6.csv")
attach(cars6)

postscript("manuscript/figures/splomcars.eps",
           width = 5.0, height = 5.0, pointsize = 9,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Cmpg, Eng, Cyl, 100*Vol), cex.labels=1.3,
      labels=c("City MPG", "Engine Size", "Cylinders", "Volume"))
dev.off()

Drive1 <- factor(Drive, levels = c("F", "R", "A", "4"), ordered=T,
                 labels = c("FWD","RWD","AWD","4WD"))

postscript("manuscript/figures/boxcarsa.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,0)+0.1, mgp=c(2,1,0))
boxplot(Cmpg ~ Drive1, boxwex=.5, cex.axis=.65,
        xlab = "Drive System",
        ylab = "City Miles per Gallon")
par(oldpar)
dev.off()

Air1 <- factor(Air, levels = c("N", "SC", "TC"), ordered=T,
               labels = c("Natural", "Supercharged", "Turbocharged"))

postscript("manuscript/figures/boxcarsb.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
boxplot(Cmpg ~ Air1, boxwex=.5, cex.axis=.65,
        xlab = "Air Aspiration Method",
        ylab = "City Miles per Gallon")
par(oldpar)
dev.off()

Class1 <- factor(Class, levels = c("MC", "SC", "CO", "MI", "LA", "SW", "SU"), 
                 ordered=T)

model <- lm(Cmpg ~ Eng + Cyl + Vol + DRw + DAw + D4w + DSt)
summary(model)
#Residual standard error: 1.621 on 343 degrees of freedom
#Multiple R-squared: 0.8274,	Adjusted R-squared: 0.8238 
#F-statistic: 234.8 on 7 and 343 DF,  p-value: < 2.2e-16 

rstu <- rstudent(model)
scatter.smooth(Eng, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Cyl, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Vol, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(fitted(model), rstu, span=0.75,
               ylab="Studentized residuals")

Cgphm <- 100/Cmpg

model <- lm(Cgphm ~ Eng + Cyl + Vol + DRw + DAw + D4w + DSt)
summary(model)
#Residual standard error: 0.4611 on 343 degrees of freedom
#Multiple R-squared: 0.8535,	Adjusted R-squared: 0.8505 
#F-statistic: 285.4 on 7 and 343 DF,  p-value: < 2.2e-16 

rstu <- rstudent(model)
scatter.smooth(Eng, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Cyl, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Vol, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(fitted(model), rstu, span=0.75,
               ylab="Studentized residuals")

DRwEng <- DRw*Eng
DAwEng <- DAw*Eng
D4wEng <- D4w*Eng
DStEng <- DSt*Eng
DRwCyl <- DRw*Cyl
DAwCyl <- DAw*Cyl
D4wCyl <- D4w*Cyl
DStCyl <- DSt*Cyl
DRwVol <- DRw*Vol
DAwVol <- DAw*Vol
D4wVol <- D4w*Vol
DStVol <- DSt*Vol

DRwDSt <- DRw*DSt
DAwDSt <- DAw*DSt
#DStD4w <- DSt*D4w - none

DRwDStEng <- DRwDSt*Eng
DAwDStEng <- DAwDSt*Eng
DRwDStCyl <- DRwDSt*Cyl
DAwDStCyl <- DAwDSt*Cyl
DRwDStVol <- DRwDSt*Vol
DAwDStVol <- DAwDSt*Vol

model1 <- lm(Cgphm ~ Eng + Cyl + Vol
             + DRw + DAw + D4w + DSt + DRwDSt + DAwDSt
             + DRwEng + DAwEng + D4wEng + DStEng + DRwDStEng + DAwDStEng
             + DRwCyl + DAwCyl + D4wCyl + DStCyl + DRwDStCyl + DAwDStCyl
             + DRwVol + DAwVol + D4wVol + DStVol + DRwDStVol + DAwDStVol)
summary(model1) # R2= 0.8851, s= 0.4207, adjR2= 0.8755
#             Estimate Std. Error t value Pr(>|t|)    
# D4wEng       0.02829    0.35089   0.081 0.935782    
# DAwDStEng   -0.12898    0.57617  -0.224 0.823014    
# DRwDStVol   -0.21164    1.10893  -0.191 0.848761    

# Remove D4wEng, DAwDStEng, DRwDStVol

model2 <- lm(Cgphm ~ Eng + Cyl + Vol
             + DRw + DAw + D4w + DSt + DRwDSt + DAwDSt
             + DRwEng + DAwEng + DStEng + DRwDStEng
             + DRwCyl + DAwCyl + D4wCyl + DStCyl + DRwDStCyl + DAwDStCyl
             + DRwVol + DAwVol + D4wVol + DStVol + DAwDStVol)
anova(model2,model1) # p-value= 0.991
summary(model2) # R2= 0.8851, s= 0.4189, adjR2= 0.8766
#             Estimate Std. Error t value Pr(>|t|)    
# DRwDStCyl   -0.19403    0.31516  -0.616 0.538549    
# DRwVol       0.29470    0.41304   0.713 0.476049    
# DAwDStVol   -0.74945    0.89693  -0.836 0.404008    

# Remove DRwDStCyl, DRwVol, DAwDStVol

model3 <- lm(Cgphm ~ Eng + Cyl + Vol
             + DRw + DAw + D4w + DSt + DRwDSt + DAwDSt
             + DRwEng + DAwEng + DStEng + DRwDStEng
             + DRwCyl + DAwCyl + D4wCyl + DStCyl + DAwDStCyl
             + DAwVol + D4wVol + DStVol)
anova(model3,model2) # p-value= 0.6583
summary(model3) # R2= 0.8845, s= 0.418, adjR2= 0.8771
#             Estimate Std. Error t value Pr(>|t|)    
# DRwDSt      -0.51944    0.53721  -0.967 0.334297    
# DRwDStEng    0.18734    0.23056   0.813 0.417082    
# DStVol      -0.18757    0.41236  -0.455 0.649501    

# Remove DRwDSt, DRwDStEng, DStVol

model4 <- lm(Cgphm ~ Eng + Cyl + Vol
             + DRw + DAw + D4w + DSt + DAwDSt
             + DRwEng + DAwEng + DStEng
             + DRwCyl + DAwCyl + D4wCyl + DStCyl + DAwDStCyl
             + DAwVol + D4wVol)
anova(model4,model3) # p-value= 0.7589
summary(model4) # R2= 0.8841, s= 0.4168, adjR2= 0.8778
#            Estimate Std. Error t value Pr(>|t|)    
#DRwEng      -0.67459    0.12999  -5.189 3.68e-07 ***
#DAwEng      -0.67840    0.17293  -3.923 0.000106 ***

# Combine DRwEng and DAwEng

DRwAw <- DRw+DAw
DRwAwEng <- DRwAw*Eng

model5 <- lm(Cgphm ~ Eng + Cyl + Vol
             + DRw + DAw + D4w + DSt + DAwDSt
             + DRwAwEng + DStEng
             + DRwCyl + DAwCyl + D4wCyl + DStCyl + DAwDStCyl
             + DAwVol + D4wVol)
anova(model5,model4) # p-value= 0.9792
summary(model5)
#            Estimate Std. Error t value Pr(>|t|)    
#1(Intercept)  1.89641    0.26224   7.231 3.30e-12 ***
#2Eng          0.87910    0.11320   7.766 1.01e-13 ***
#3Cyl         -0.04237    0.08610  -0.492 0.622997    
#4Vol          0.61868    0.17897   3.457 0.000617 ***

#5DRw         -0.14204    0.26215  -0.542 0.588292    
#6DAw          1.45930    0.57592   2.534 0.011739 *  
#7D4w          0.18210    0.76398   0.238 0.811751    
#8DSt          1.38359    0.23731   5.830 1.31e-08 ***
#9DAwDSt      -1.49942    0.42168  -3.556 0.000431 ***

#10DRwAwEng   -0.67532    0.12676  -5.327 1.84e-07 ***
#11DStEng      0.70952    0.11582   6.126 2.54e-09 ***

#12DRwCyl      0.45245    0.09611   4.708 3.68e-06 ***
#13DAwCyl      0.32514    0.10241   3.175 0.001638 ** 
#14D4wCyl     -0.18819    0.15570  -1.209 0.227656    
#15DStCyl     -0.56975    0.08590  -6.632 1.34e-10 ***
#16DAwDStCyl   0.27464    0.06664   4.121 4.76e-05 ***

#17DAwVol     -0.74549    0.41074  -1.815 0.070419 .  
#18D4wVol      1.35839    0.46801   2.902 0.003949 ** 
#---
#Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

#Residual standard error: 0.4162 on 333 degrees of freedom
#Multiple R-squared: 0.8841,	Adjusted R-squared: 0.8782 
#F-statistic: 149.4 on 17 and 333 DF,  p-value: < 2.2e-16 

round(coef(summary(model5)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)    1.896      0.262   7.231    0.000
#Eng            0.879      0.113   7.766    0.000
#Cyl           -0.042      0.086  -0.492    0.623
#Vol            0.619      0.179   3.457    0.001
#DRw           -0.142      0.262  -0.542    0.588
#DAw            1.459      0.576   2.534    0.012
#D4w            0.182      0.764   0.238    0.812
#DSt            1.384      0.237   5.830    0.000
#DAwDSt        -1.499      0.422  -3.556    0.000
#DRwAwEng      -0.675      0.127  -5.327    0.000
#DStEng         0.710      0.116   6.126    0.000
#DRwCyl         0.452      0.096   4.708    0.000
#DAwCyl         0.325      0.102   3.175    0.002
#D4wCyl        -0.188      0.156  -1.209    0.228
#DStCyl        -0.570      0.086  -6.632    0.000
#DAwDStCyl      0.275      0.067   4.121    0.000
#DAwVol        -0.745      0.411  -1.815    0.070
#D4wVol         1.358      0.468   2.902    0.004

plot(model5)

lev <- hatvalues(model5)
plot(fitted(model5),lev)
identify(fitted(model5),lev)
Name[c(63,29)]
# 63: BMW 760Li 6L; 
# 29: Bentley Mulsanne 6.8L
lev[c(63,29)]
#       63        29 
#0.3416653 0.3231724 
3*(17+1)/351
#0.1538462

cook <- cooks.distance(model5)
plot(fitted(model5),cook)
identify(fitted(model5),cook)
Name[c(28,224)]
# 28: Bentley Continental GTC FFV 6L; 224: Mercedes E 550 4matic 5.5L
cook[c(28,224)]
#        28        224 
#0.06115583 0.05996833 

rstu <- rstudent(model5)
scatter.smooth(Eng, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Cyl, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(Vol, rstu, span=0.75,
               ylab="Studentized residuals")
scatter.smooth(fitted(model5), rstu, span=0.75,
               ylab="Studentized residuals")

plot(fitted(model5),rstu)
identify(fitted(model5),rstu)
Name[c(202,203)]
# 202: Maserati Granturismo Convertible 4.7L
# 203: Maserati Quattroporte 4.2L
rstu[c(202,203)]
#     202      203
#4.445158 4.102596
rstu[abs(rstu)>3]
#     200      202      203      204      217 
#3.031667 4.445158 4.102596 3.823247 3.448877 
Name[abs(rstu)>3]
#[1] Maserati Granturismo 4.2L             Maserati Granturismo Convertible 4.7L
#[3] Maserati Quattroporte 4.2L            Maserati Quattroporte 4.7L           
#[5] Mercedes CLS 63 AMG 6.3L             

range(Cmpg) # 11 29
range(Eng) # 1.4 6.8
range(Cyl) # 4 12
range(Vol) # 0.56 1.73

Name[c(202,203,63,29,28,224)]
# Maserati Granturismo Convertible 4.7L
# Maserati Quattroporte 4.2L           
# BMW 760Li 6L
# Bentley Mulsanne 6.8L                
# Bentley Continental GTC FFV 6L
# Mercedes E 550 4matic 5.5L           
Cmpg[c(202,203,63,29,28,224)]
# 12 12 13 11 11 15
Eng[c(202,203,63,29,28,224)]
# 4.7 4.2 6.0 6.8 6.0 5.5
Cyl[c(202,203,63,29,28,224)]
# 8  8 12  8 12  8
Vol[c(202,203,63,29,28,224)]
# 0.90 1.29 1.29 1.12 0.93 1.11

Name[Cyl==8 & Eng>6.5]
# Bentley Mulsanne 6.8L
Name[Cyl==12 & Eng<=6]
# Aston Martin DB9 5.9L
# Aston Martin DBS 5.9L                      
# Aston Martin Rapide 5.9L
# Bentley Cont SuperSports Convertible FFV 6L
# Bentley Continental Flying Spur FFV 6L
# Bentley Continental GTC FFV 6L             
# BMW 760Li 6L                               

range(rstu[Class=="MC"])
# -1.813966  1.904227
range(rstu[Class=="SC"])
# -2.671554  4.445158
range(rstu[Class=="CO"])
# -1.726450  3.448877
range(rstu[Class=="MI"])
# -2.447012  2.126982
range(rstu[Class=="LA"])
# -2.105499  4.102596
range(rstu[Class=="SW"])
# -1.325137  2.499647
range(rstu[Class=="SU"])
# -0.7857363  2.0393074

cars6[71,]
#                  Name Cmpg Hmpg Eng Cyl  Vol Air DNa DSt Drive DFw DRw D4w DAw Class DMc DSc DCo
#71 Buick Lacrosse 2.4L   19   30 2.4   4 1.16   N   1   0     F   1   0   0   0    MI   0   0   0
#   DMi DLa DSw DSu
#71   1   0   0   0
cars6[170,]
#               Name Cmpg Hmpg Eng Cyl  Vol Air DNa DSt Drive DFw DRw D4w DAw Class DMc DSc DCo DMi
#170 Kia Optima 2.4L   24   34 2.4   4 1.17   N   1   0     F   1   0   0   0    MI   0   0   0   1
#    DLa DSw DSu
#170   0   0   0
100/fitted(model5)[71]
#      71 
#21.95658 
100/fitted(model5)[170]
#     170 
#21.92679 

Name[Cmpg>24&rstu>.6]
#[1] Chevrolet Aveo 5 1.6L Suzuki Swift + 1.6L  

Cmpg[Cmpg>24&rstu>.6]
#[1] 25 25

cars6[92,]
#                    Name Cmpg Hmpg Eng Cyl  Vol Air DNa DSt Drive DFw DRw D4w DAw Class DMc DSc DCo
#92 Chevrolet Aveo 5 1.6L   25   34 1.6   4 0.98   N   1   0     F   1   0   0   0    SC   0   1   0
#   DMi DLa DSw DSu
#92   0   0   0   0

fitted(model5)[92]
# 3.739805
100/fitted(model5)[92]
# 26.73936

paste(Name[rstu==min(rstu[Class=="MC"])], Cmpg[rstu==min(rstu[Class=="MC"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="MC"])],1))
#Aston Martin DB9 5.9L 13 11.9
paste(Name[rstu==min(rstu[Class=="SC"])], Cmpg[rstu==min(rstu[Class=="SC"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="SC"])],1))
#Ford Mustang 5L 18 15
paste(Name[rstu==min(rstu[Class=="CO"])], Cmpg[rstu==min(rstu[Class=="CO"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="CO"])],1))
#Chevrolet Camaro 6.2L 16 14.4
paste(Name[rstu==min(rstu[Class=="MI"])], Cmpg[rstu==min(rstu[Class=="MI"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="MI"])],1))
#BMW 528i 3L 22 18
paste(Name[rstu==min(rstu[Class=="LA"])], Cmpg[rstu==min(rstu[Class=="LA"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="LA"])],1))
#Hyundai Genesis 4.6L 17 14.8
paste(Name[rstu==min(rstu[Class=="SW"])], Cmpg[rstu==min(rstu[Class=="SW"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="SW"])],1))
#Nissan Juke Awd 1.6L 25 22.1
paste(Name[rstu==min(rstu[Class=="SU"])], Cmpg[rstu==min(rstu[Class=="SU"])], 
      round(100/fitted(model5)[rstu==min(rstu[Class=="SU"])],1))
#Mercedes ML 550 4matic 5.5L 13 12.5

sum(Air=="N"&Drive=="F")              # 106 Nat Front
sum(Air=="N"&Drive=="R")              #  92 Nat Rear
sum(Air=="N"&Drive=="A")              #  48 Nat All
sum(Air=="N"&Drive=="4")              #  20 Nat Four
sum((Air=="SC"|Air=="TC")&Drive=="F") #  21 Turbo Front
sum((Air=="SC"|Air=="TC")&Drive=="R") #  28 Turbo Rear
sum((Air=="SC"|Air=="TC")&Drive=="A") #  36 Turbo All

plot(fitted(model5), Cgphm, type="n")
points(fitted(model5)[Air=="N"&Drive=="F"], Cgphm[Air=="N"&Drive=="F"], col="black") # 106 Nat Front
points(fitted(model5)[Air=="N"&Drive=="R"], Cgphm[Air=="N"&Drive=="R"], col="blue") # 92 Nat Rear
points(fitted(model5)[Air=="N"&Drive=="A"], Cgphm[Air=="N"&Drive=="A"], col="red") # 48 Nat All
points(fitted(model5)[Air=="N"&Drive=="4"], Cgphm[Air=="N"&Drive=="4"], col="green") # 20 Nat Four
points(fitted(model5)[(Air=="SC"|Air=="TC")&Drive=="F"], Cgphm[(Air=="SC"|Air=="TC")&Drive=="F"], col="grey") # 21 Turbo Front
points(fitted(model5)[(Air=="SC"|Air=="TC")&Drive=="R"], Cgphm[(Air=="SC"|Air=="TC")&Drive=="R"], col="purple") # 28 Turbo Rear
points(fitted(model5)[(Air=="SC"|Air=="TC")&Drive=="A"], Cgphm[(Air=="SC"|Air=="TC")&Drive=="A"], col="orange") # 36 Turbo All

mEng <- mean(Eng) # 3.402279
#mCyl <- mean(Cyl) # 6.014245
mCyl <- 6
mVol <- mean(Vol) # 1.096439

# Eng effect

k1a <- c(coef(model5) %*% c(1, # Intercept
                         0, mCyl, mVol,
                         0, 0, 0, 0, 0,
                         0, 0,
                         0, 0, 0, 0, 0,
                         0, 0))
k1b <- c(coef(model5) %*% c(0, # Rear
                         0, 0, 0,
                         1, 0, 0, 0, 0,
                         0, 0,
                         mCyl, 0, 0, 0, 0,
                         0, 0))
k1c <- c(coef(model5) %*% c(0, # All
                         0, 0, 0,
                         0, 1, 0, 0, 0,
                         0, 0,
                         0, mCyl, 0, 0, 0,
                         mVol, 0))
k1d <- c(coef(model5) %*% c(0, # Four
                         0, 0, 0,
                         0, 0, 1, 0, 0,
                         0, 0,
                         0, 0, mCyl, 0, 0,
                         0, mVol))
k1e <- c(coef(model5) %*% c(0, # Turbo
                         0, 0, 0,
                         0, 0, 0, 1, 0,
                         0, 0,
                         0, 0, mCyl, 0, 0,
                         0, 0))
k1f <- c(coef(model5) %*% c(0, # TurboAll
                         0, 0, 0,
                         0, 0, 0, 0, 1,
                         0, 0,
                         0, 0, 0, 0, mCyl,
                         0, 0))
round(k1a, 2) #  2.32
round(k1b, 2) #  2.57
round(k1c, 2) #  2.59
round(k1d, 2) #  0.54
round(k1e, 2) #  0.25
round(k1f, 2) #  0.15
round(coef(model5)[2], 2)  #   0.88
round(coef(model5)[10], 2)  # -0.68
round(coef(model5)[11], 2)  #  0.71
Engeffect <- k1a + k1b*DRw + k1c*DAw + k1d*D4w + k1e*DSt + k1f*DAwDSt +
  coef(model5)[2]*Eng + coef(model5)[10]*DRwAwEng + coef(model5)[11]*DStEng

Engeffecta <- Engeffect[Air=="N"&Drive=="F"]              # 106 Nat Front
Engeffectb <- Engeffect[Air=="N"&Drive=="R"]              #  92 Nat Rear
Engeffectc <- Engeffect[Air=="N"&Drive=="A"]              #  48 Nat All
Engeffectd <- Engeffect[Air=="N"&Drive=="4"]              #  20 Nat Four
Engeffecte <- Engeffect[(Air=="SC"|Air=="TC")&Drive=="F"] #  21 Turbo Front
Engeffectf <- Engeffect[(Air=="SC"|Air=="TC")&Drive=="R"] #  28 Turbo Rear
Engeffectg <- Engeffect[(Air=="SC"|Air=="TC")&Drive=="A"] #  36 Turbo All

postscript("manuscript/figures/carsx1a.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Eng, 100/Engeffect,
     xlim=c(1,7), ylim=c(8,30),
     xlab="Eng = Engine Size (liters)",
     ylab="Engine Size Effect on City MPG", type="n")
lines(sort(Eng[Air=="N"&Drive=="F"]),
      100/Engeffecta[order(Eng[Air=="N"&Drive=="F"])])#, col="black")
lines(sort(Eng[Air=="N"&Drive=="R"]),
      100/Engeffectb[order(Eng[Air=="N"&Drive=="R"])])#, col="blue")
lines(sort(Eng[Air=="N"&Drive=="A"]),
      100/Engeffectc[order(Eng[Air=="N"&Drive=="A"])])#, col="red")
lines(sort(Eng[Air=="N"&Drive=="4"]),
      100/Engeffectd[order(Eng[Air=="N"&Drive=="4"])])#, col="green")
text(3.4, 100/4.5, "Nat Front", cex=.8)#, col="black")
text(6.2, 100/5.7, "Nat Rear", cex=.8)#, col="blue")
text(2.0, 100/5.8, "Nat All", cex=.8)#, col="red")
text(4.9, 100/8.0, "Nat Four", cex=.8)#, col="green")
par(oldpar)
dev.off()

postscript("manuscript/figures/carsx1b.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Eng, 100/Engeffect,
     xlim=c(1,7), ylim=c(8, 30),
     xlab="Eng = Engine Size (Liters)",
     ylab="Engine Size Effect on City MPG", type="n")
lines(sort(Eng[(Air=="SC"|Air=="TC")&Drive=="F"]),
      100/Engeffecte[order(Eng[(Air=="SC"|Air=="TC")&Drive=="F"])])#, col="orange")
lines(sort(Eng[(Air=="SC"|Air=="TC")&Drive=="R"]),
      100/Engeffectf[order(Eng[(Air=="SC"|Air=="TC")&Drive=="R"])])#, col="purple")
lines(sort(Eng[(Air=="SC"|Air=="TC")&Drive=="A"]),
      100/Engeffectg[order(Eng[(Air=="SC"|Air=="TC")&Drive=="A"])])#, col="grey")
text(2.6, 100/5.0, "Turbo Front", cex=.8)#, col="orange")
text(5.4, 100/9.0, "Turbo Rear", cex=.8)#, col="purple")
text(3.0, 100/9.0, "Turbo All", cex=.8)#, col="grey")
par(oldpar)
dev.off()

# Cyl effect

k1a <- c(coef(model5) %*% c(1, # Intercept
                         mEng, 0, mVol,
                         0, 0, 0, 0, 0,
                         0, 0,
                         0, 0, 0, 0, 0,
                         0, 0))
k1b <- c(coef(model5) %*% c(0, # Rear
                         0, 0, 0,
                         1, 0, 0, 0, 0,
                         mEng, 0,
                         0, 0, 0, 0, 0,
                         0, 0))
k1c <- c(coef(model5) %*% c(0, # All
                         0, 0, 0,
                         0, 1, 0, 0, 0,
                         mEng, 0,
                         0, 0, 0, 0, 0,
                         mVol, 0))
k1d <- c(coef(model5) %*% c(0, # Four
                         0, 0, 0,
                         0, 0, 1, 0, 0,
                         0, 0,
                         0, 0, 0, 0, 0,
                         0, mVol))
k1e <- c(coef(model5) %*% c(0, # Turbo
                         0, 0, 0,
                         0, 0, 0, 1, 0,
                         0, mEng,
                         0, 0, 0, 0, 0,
                         0, 0))
k1f <- c(coef(model5) %*% c(0, # TurboAll
                         0, 0, 0,
                         0, 0, 0, 0, 1,
                         0, 0,
                         0, 0, 0, 0, 0,
                         0, 0))
round(k1a, 2) #  5.57
round(k1b, 2) # -2.44
round(k1c, 2) # -1.66
round(k1d, 2) #  1.67
round(k1e, 2) #  3.80
round(k1f, 2) # -1.50
round(coef(model5)[3], 2)   # -0.04
round(coef(model5)[12], 2)  #  0.45
round(coef(model5)[13], 2)  #  0.33
round(coef(model5)[14], 2)  # -0.19
round(coef(model5)[15], 2)  # -0.57
round(coef(model5)[16], 2)  #  0.27
Cyleffect <- k1a + k1b*DRw + k1c*DAw + k1d*D4w + k1e*DSt + k1f*DAwDSt +
  coef(model5)[3]*Cyl + coef(model5)[12]*DRwCyl +
  coef(model5)[13]*DAwCyl + coef(model5)[14]*D4wCyl +
  coef(model5)[15]*DStCyl + coef(model5)[16]*DAwDStCyl

Cyleffecta <- Cyleffect[Air=="N"&Drive=="F"]              # 106 Nat Front
Cyleffectb <- Cyleffect[Air=="N"&Drive=="R"]              #  92 Nat Rear
Cyleffectc <- Cyleffect[Air=="N"&Drive=="A"]              #  48 Nat All
Cyleffectd <- Cyleffect[Air=="N"&Drive=="4"]              #  20 Nat Four
Cyleffecte <- Cyleffect[(Air=="SC"|Air=="TC")&Drive=="F"] #  21 Turbo Front
Cyleffectf <- Cyleffect[(Air=="SC"|Air=="TC")&Drive=="R"] #  28 Turbo Rear
Cyleffectg <- Cyleffect[(Air=="SC"|Air=="TC")&Drive=="A"] #  36 Turbo All

postscript("manuscript/figures/carsx2a.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Cyl, 100/Cyleffect,
     xlim=c(4,12), ylim=c(8,30),
     xlab="Cyl = Number of Cylinders",
     ylab="Cylinder Effect on City MPG", type="n")
lines(sort(Cyl[Air=="N"&Drive=="F"]),
      100/Cyleffecta[order(Cyl[Air=="N"&Drive=="F"])])#, col="black")
lines(sort(Cyl[Air=="N"&Drive=="R"]),
      100/Cyleffectb[order(Cyl[Air=="N"&Drive=="R"])])#, col="blue")
lines(sort(Cyl[Air=="N"&Drive=="A"]),
      100/Cyleffectc[order(Cyl[Air=="N"&Drive=="A"])])#, col="red")
lines(sort(Cyl[Air=="N"&Drive=="4"]),
      100/Cyleffectd[order(Cyl[Air=="N"&Drive=="4"])])#, col="green")
text(6.7, 100/4.8, "Nat Front", cex=.8)#, col="black")
text(10.0, 100/8.0, "Nat Rear", cex=.8)#, col="blue")
text(10.7, 100/6.7, "Nat All", cex=.8)#, col="red")
text(8.9, 100/5.6, "Nat Four", cex=.8)#, col="green")
par(oldpar)
dev.off()

postscript("manuscript/figures/carsx2b.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Cyl, 100/Cyleffect,
     xlim=c(4,12), ylim=c(8,30),
     xlab="Cyl = Number of Cylinders",
     ylab="Cylinder Effect on City MPG", type="n")
lines(sort(Cyl[(Air=="SC"|Air=="TC")&Drive=="F"]),
      100/Cyleffecte[order(Cyl[(Air=="SC"|Air=="TC")&Drive=="F"])])#, col="orange")
lines(sort(Cyl[(Air=="SC"|Air=="TC")&Drive=="R"]),
      100/Cyleffectf[order(Cyl[(Air=="SC"|Air=="TC")&Drive=="R"])])#, col="purple")
lines(sort(Cyl[(Air=="SC"|Air=="TC")&Drive=="A"]),
      100/Cyleffectg[order(Cyl[(Air=="SC"|Air=="TC")&Drive=="A"])])#, col="grey")
text(5.0, 100/7.2, "Turbo Front", cex=.8)#, col="orange")
text(8.0, 100/5.2, "Turbo Rear", cex=.8)#, col="purple")
text(8.0, 100/6.5, "Turbo All", cex=.8)#, col="grey")
par(oldpar)
dev.off()

# Vol effect

k1a <- c(coef(model5) %*% c(1, # Intercept
                         mEng, mCyl, 0,
                         0, 0, 0, 0, 0,
                         0, 0,
                         0, 0, 0, 0, 0,
                         0, 0))
k1b <- c(coef(model5) %*% c(0, # Rear
                         0, 0, 0,
                         1, 0, 0, 0, 0,
                         mEng, 0,
                         mCyl, 0, 0, 0, 0,
                         0, 0))
k1c <- c(coef(model5) %*% c(0, # All
                         0, 0, 0,
                         0, 1, 0, 0, 0,
                         mEng, 0,
                         0, mCyl, 0, 0, 0,
                         0, 0))
k1d <- c(coef(model5) %*% c(0, # Four
                         0, 0, 0,
                         0, 0, 1, 0, 0,
                         0, 0,
                         0, 0, mCyl, 0, 0,
                         0, 0))
k1e <- c(coef(model5) %*% c(0, # Turbo
                         0, 0, 0,
                         0, 0, 0, 1, 0,
                         0, mEng,
                         0, 0, 0, mCyl, 0,
                         0, 0))
k1f <- c(coef(model5) %*% c(0, # TurboAll
                         0, 0, 0,
                         0, 0, 0, 0, 1,
                         0, 0,
                         0, 0, 0, 0, mCyl,
                         0, 0))
round(k1a, 2) #  4.63
round(k1b, 2) #  0.28
round(k1c, 2) #  1.11
round(k1d, 2) # -0.95
round(k1e, 2) #  0.38
round(k1f, 2) #  0.15
round(coef(model5)[4], 2)  #   0.62
round(coef(model5)[17], 2) #  -0.75
round(coef(model5)[18], 2) #   1.36
Voleffect <- k1a + k1b*DRw + k1c*DAw + k1d*D4w + k1e*DSt + k1f*DAwDSt +
  coef(model5)[4]*Vol + coef(model5)[17]*DAwVol + coef(model5)[18]*D4wVol

Voleffecta <- Voleffect[Air=="N"&Drive=="F"]              # 106 Nat Front
Voleffectb <- Voleffect[Air=="N"&Drive=="R"]              #  92 Nat Rear
Voleffectc <- Voleffect[Air=="N"&Drive=="A"]              #  48 Nat All
Voleffectd <- Voleffect[Air=="N"&Drive=="4"]              #  20 Nat Four
Voleffecte <- Voleffect[(Air=="SC"|Air=="TC")&Drive=="F"] #  21 Turbo Front
Voleffectf <- Voleffect[(Air=="SC"|Air=="TC")&Drive=="R"] #  28 Turbo Rear
Voleffectg <- Voleffect[(Air=="SC"|Air=="TC")&Drive=="A"] #  36 Turbo All

postscript("manuscript/figures/carsx3a.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(100*Vol, 100/Voleffect,
     xlim=c(50,175), ylim=c(8,30),
     xlab="Vol = Passenger/Cargo Volume (cu ft)",
     ylab="Volume Effect", type="n")
lines(100*sort(Vol[Air=="N"&Drive=="F"]),
      100/Voleffecta[order(Vol[Air=="N"&Drive=="F"])])#, col="black")
lines(100*sort(Vol[Air=="N"&Drive=="R"]),
      100/Voleffectb[order(Vol[Air=="N"&Drive=="R"])])#, col="blue")
lines(100*sort(Vol[Air=="N"&Drive=="A"]),
      100/Voleffectc[order(Vol[Air=="N"&Drive=="A"])])#, col="red")
lines(100*sort(Vol[Air=="N"&Drive=="4"]),
      100/Voleffectd[order(Vol[Air=="N"&Drive=="4"])])#, col="green")
text(100, 100/4.8, "Nat Front", cex=.8)#, col="black")
text(65, 100/5.7, "Nat Rear", cex=.8)#, col="blue")
text(152, 100/5.5, "Nat All", cex=.8)#, col="red")
text(140, 100/7.0, "Nat Four", cex=.8)#, col="green")
par(oldpar)
dev.off()

postscript("manuscript/figures/carsx3b.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(100*Vol, 100/Voleffect,
     xlim=c(50,175), ylim=c(8,30),
     xlab="Vol = Passenger/Cargo Volume (cu ft)",
     ylab="Volume Effect", type="n")
lines(100*sort(Vol[(Air=="SC"|Air=="TC")&Drive=="F"]),
      100/Voleffecte[order(Vol[(Air=="SC"|Air=="TC")&Drive=="F"])])#, col="orange")
lines(100*sort(Vol[(Air=="SC"|Air=="TC")&Drive=="R"]),
      100/Voleffectf[order(Vol[(Air=="SC"|Air=="TC")&Drive=="R"])])#, col="purple")
lines(100*sort(Vol[(Air=="SC"|Air=="TC")&Drive=="A"]),
      100/Voleffectg[order(Vol[(Air=="SC"|Air=="TC")&Drive=="A"])])#, col="grey")
text(110, 100/5.2, "Turbo Front", cex=.8)#, col="orange")
text(65, 100/6.2+.5, "Turbo Rear", cex=.8)#, col="purple")
text(100, 100/6.6, "Turbo All", cex=.8)#, col="grey")
par(oldpar)
dev.off()

detach(cars6)

# patches

patches <- read.csv("data/patches.csv")
attach(patches)

postscript("manuscript/figures/splompatches.eps",
           width = 5.0, height = 5.0, pointsize = 9,
           horizontal = FALSE, onefile = FALSE, paper = "special")
pairs(cbind(Diff, Dos, Gap, Exp), cex.labels=1.3,
      labels=c("Diff", "Dos", "Gap", "Exp"))
dev.off()

model1 <- lm(Diff ~ Dos + Gap + Exp)
summary(model1)
#Residual standard error: 10.48 on 66 degrees of freedom
#Multiple R-squared: 0.6417,	Adjusted R-squared: 0.6254 
library(car)
vif(model1)
#     Dos      Gap      Exp 
#1.043788 1.125903 1.132466 

D50 <- ifelse(Dos==50, yes=1, no=0)
D75 <- ifelse(Dos==75, yes=1, no=0)
D100 <- ifelse(Dos==100, yes=1, no=0)
model2 <- lm(Diff ~ D50 + D75 + D100 + Gap + Exp)
summary(model2)
#Residual standard error: 9.26 on 64 degrees of freedom
#Multiple R-squared: 0.7289,	Adjusted R-squared: 0.7077 

rstu2 <- rstudent(model2)
scatter.smooth(Gap,rstu2,span=0.75)
scatter.smooth(Exp,rstu2,span=0.75)

Gap2 <- Gap^2
Exp2 <- Exp^2
model3 <- lm(Diff ~ D50 + D75 + D100 + Gap + Gap2 + Exp + Exp2)
summary(model3)
#Residual standard error: 7.37 on 62 degrees of freedom
#Multiple R-squared: 0.8336,	Adjusted R-squared: 0.8148 
round(coef(summary(model3)),1)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)   -746.1      172.9    -4.3        0
#D50            -20.3        2.4    -8.3        0
#D75            -18.8        2.4    -7.8        0
#D100           -20.1        2.6    -7.7        0
#Gap             38.9        8.5     4.6        0
#Gap2            -0.5        0.1    -5.0        0
#Exp              0.6        0.1     5.0        0
#Exp2             0.0        0.0    -2.6        0

D25 <- ifelse(Dos==25, yes=1, no=0)
model4 <- lm(Diff ~ D25 + Gap + Gap2 + Exp + Exp2)
summary(model4)
#Residual standard error: 7.275 on 64 degrees of freedom
#Multiple R-squared: 0.8326,	Adjusted R-squared: 0.8196 

D25Gap <- D25*Gap
D25Gap2 <- D25*Gap2
D25Exp <- D25*Exp
D25Exp2 <- D25*Exp2
model5 <- lm(Diff ~ D25 + Gap + Gap2 + Exp + Exp2 + D25Gap + D25Gap2 + D25Exp + D25Exp2)
summary(model5)
#Residual standard error: 6.833 on 60 degrees of freedom
#Multiple R-squared: 0.8616,	Adjusted R-squared: 0.8408 
round(coef(summary(model5)),2)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept)  -826.67     206.62   -4.00     0.00
#D25           201.14     328.82    0.61     0.54
#Gap            42.12      10.19    4.13     0.00
#Gap2           -0.56       0.12   -4.49     0.00
#Exp             0.49       0.15    3.20     0.00
#Exp2            0.00       0.00   -0.82     0.41
#D25Gap         -9.38      16.15   -0.58     0.56
#D25Gap2         0.12       0.20    0.60     0.55
#D25Exp          0.37       0.24    1.58     0.12
#D25Exp2         0.00       0.00   -2.17     0.03

model6 <- lm(Diff ~ D25 + Gap + Gap2 + Exp + Exp2 + D25Exp + D25Exp2)
anova(model6, model5)
#  Res.Df    RSS Df Sum of Sq      F Pr(>F)
#1     62 2830.4                           
#2     60 2801.3  2    29.097 0.3116 0.7334
summary(model6)
#Residual standard error: 6.757 on 62 degrees of freedom
#Multiple R-squared: 0.8601,	Adjusted R-squared: 0.8444 
#F-statistic: 54.47 on 7 and 62 DF,  p-value: < 2.2e-16 
round(coef(summary(model6)),3)
#            Estimate Std. Error t value Pr(>|t|)
#(Intercept) -750.499    158.518  -4.734    0.000
#D25           15.373      6.569   2.340    0.023
#Gap           38.257      7.813   4.897    0.000
#Gap2          -0.508      0.095  -5.352    0.000
#Exp            0.490      0.145   3.385    0.001
#Exp2          -0.001      0.001  -0.857    0.395
#D25Exp         0.384      0.214   1.790    0.078
#D25Exp2       -0.003      0.001  -2.374    0.021

rstu6 <- rstudent(model6)
scatter.smooth(Dos,rstu6,span=0.75)
scatter.smooth(Gap,rstu6,span=0.75)
scatter.smooth(Exp,rstu6,span=0.75)
scatter.smooth(fitted(model6),rstu6,span=0.75)

postscript("manuscript/figures/patchesres.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(fitted(model6),rstu6, xlab="Fitted value", ylab="Studentized residual")
par(oldpar)
dev.off()

hist(rstu6)
qqnorm(rstu6)
qqline(rstu6)

lev <- hatvalues(model6)
cook <- cooks.distance(model6)
plot(cook,lev)

lev[lev==max(lev)]
#       26 
#0.2924362 
patches[26,]
#   Dos   Gap Exp Diff
#26  25 36.45  10  -17
3*(7+1)/70
#0.3428571

cook[cook==max(cook)]
#       22 
#0.2330553 
lev[cook==max(cook)]
#       22 
#0.2732993 

cook[26]
#        26 
# 0.1332578

range(rstu6) # -2.302495  2.462384

range(Diff) # -25  32

sum(Dos==25)              # 29 low dose
sum(Dos!=25)              # 41 high dose

plot(fitted(model6), Diff, type="n")
points(fitted(model6)[Dos==25], Diff[Dos==25], col="blue")
points(fitted(model6)[Dos!=25], Diff[Dos!=25], col="red")

mGap <- mean(Gap) # 40.10671
mExp <- mean(Exp) # 75.28571

# Gap effect

k1a <- c(coef(model6) %*% c(1, # Intercept
                         0, 0, 0, mExp, mExp^2, 0, 0))
round(k1a,3) # -718.341
k1b <- c(coef(model6) %*% c(0, # High
                         1, 0, 0, 0, 0, mExp, mExp^2))
round(k1b,3) # 24.534
Gapeffect <- k1a + k1b*D25 + coef(model6)[3]*Gap + coef(model6)[4]*Gap2

plot(Gapeffect, -718.341+24.534*D25+38.257*Gap-0.508*Gap2)
cor(Gapeffect, -718.341+24.534*D25+38.257*Gap-0.508*Gap2)
# 0.9999832

Gapeffecta <- Gapeffect[Dos==25]              # 29 low dose
Gapeffectb <- Gapeffect[Dos!=25]              # 41 high dose

postscript("manuscript/figures/patchesgap.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Gap, Gapeffect,
     ylim=c(-35,30),
     xlab="Gap = gap height (mm)",
     ylab="Gap height effect on Diff", type="n")
lines(sort(Gap[Dos==25]),
      Gapeffecta[order(Gap[Dos==25])])#, col="blue")
lines(sort(Gap[Dos!=25]),
      Gapeffectb[order(Gap[Dos!=25])])#, col="red")
abline(0, 0, lty=5)
text(43, 19, "Low dose", cex=.8)#, col="blue")
text(43, -7, "High dose", cex=.8)#, col="red")
par(oldpar)
dev.off()

# Exp effect

k1a <- c(coef(model6) %*% c(1, # Intercept
                         0, mGap, mGap^2, 0, 0, 0, 0))
round(k1a,3) # -33.992
Expeffect <- k1a + coef(model6)[2]*D25 + coef(model6)[5]*Exp + coef(model6)[6]*Exp2 + coef(model6)[7]*D25Exp + coef(model6)[8]*D25Exp2

plot(Expeffect, -34+15.4*D25+0.49*Exp-0.000833*Exp2+0.384*D25Exp-0.00348*D25Exp2)
cor(Expeffect, -34+15.4*D25+0.49*Exp-0.000833*Exp2+0.384*D25Exp-0.00348*D25Exp2)
# 0.9999992

Expeffecta <- Expeffect[Dos==25]              # 29 low dose
Expeffectb <- Expeffect[Dos!=25]              # 41 high dose

postscript("manuscript/figures/patchesexp.eps",
           width = 2.5, height = 2.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(Exp, Expeffect,
     ylim=c(-35,30),
     xlab="Exp = exposure time (seconds)",
     ylab="Exposure time effect on Diff", type="n")
lines(sort(Exp[Dos==25]),
      Expeffecta[order(Exp[Dos==25])])#, col="blue")
lines(sort(Exp[Dos!=25]),
      Expeffectb[order(Exp[Dos!=25])])#, col="red")
abline(0, 0, lty=5)
text(30, 12, "Low dose", cex=.8)#, col="blue")
text(30, -13, "High dose", cex=.8)#, col="red")
par(oldpar)
dev.off()

detach(patches)
