# Chapter 7: Extensions

setwd("~/Teaching/arm3e/")

# 7.1 Generalized linear models

# 7.1.1 Logistic regression

# bcwis

bcwis <- read.csv("data/bcwis.csv")
attach(bcwis)

model1 <- glm(Y ~ X1 + X2 + X3 + X4 + X5 + X6 + X7 + X8 + X9, family="binomial")
round(coef(summary(model1)),3)
#            Estimate Std. Error z value Pr(>|z|)
#(Intercept)  -10.104      1.175  -8.600    0.000
#X1             0.535      0.142   3.767    0.000
#X2            -0.006      0.209  -0.030    0.976
#X3             0.323      0.231   1.399    0.162
#X4             0.331      0.123   2.678    0.007
#X5             0.097      0.157   0.617    0.537
#X6             0.383      0.094   4.082    0.000
#X7             0.447      0.171   2.609    0.009
#X8             0.213      0.113   1.887    0.059
#X9             0.535      0.329   1.627    0.104

summary(model1)
# Null deviance: 884.35  on 682  degrees of freedom
# Residual deviance: 102.89  on 673  degrees of freedom

summary(model1)$null.deviance-summary(model1)$deviance # 781.462
summary(model1)$df.null-summary(model1)$df.residual # 9

round(pchisq(summary(model1)$null.deviance-summary(model1)$deviance,
             summary(model1)$df.null-summary(model1)$df.residual,
             lower.tail=F), 3)
# 0

model2 <- glm(Y ~ X1 + X3 + X4 + X6 + X7 + X8 + X9, family="binomial")
round(coef(summary(model2)),3)
#            Estimate Std. Error z value Pr(>|z|)
#(Intercept)   -9.983      1.126  -8.865    0.000
#X1             0.534      0.141   3.793    0.000
#X3             0.345      0.172   2.012    0.044
#X4             0.342      0.119   2.873    0.004
#X6             0.388      0.094   4.150    0.000
#X7             0.462      0.168   2.746    0.006
#X8             0.226      0.111   2.037    0.042
#X9             0.531      0.324   1.637    0.102

summary(model2)
# Null deviance: 884.35  on 682  degrees of freedom
# Residual deviance: 103.27  on 675  degrees of freedom

summary(model2)$null.deviance-summary(model2)$deviance # 781.0834
summary(model2)$df.null-summary(model2)$df.residual # 7

anova(model2,model1, test="Chisq")
#  Resid. Df Resid. Dev Df Deviance P(>|Chi|)
#1       675     103.27                      
#2       673     102.89  2  0.37857    0.8276

summary(model2)$deviance-summary(model1)$deviance # 0.3785711

summary(model2)$df.residual-summary(model1)$df.residual # 2

pchisq(summary(model2)$deviance-summary(model1)$deviance,
       summary(model2)$df.residual-summary(model1)$df.residual,
       lower.tail=F)
# 0.8275502

exp(0.534) # 1.705742
exp(0.345) # 1.41199

postscript("manuscript/figures/bcwis1.eps",
           width = 4.0, height = 3.0, pointsize = 8,
           horizontal = FALSE, onefile = FALSE, paper = "special")
oldpar <- par(mar=c(3,3,1,1)+0.1, mgp=c(2,1,0))
plot(fitted(model2), jitter(Y, factor=.1),
     xlab="Fitted probabilities from the model",
     ylab="Y = 0 if benign, 1 if malignant")
par(oldpar)
dev.off()

table(Y, fitted(model2)>0.5)
# Y   FALSE TRUE
# 0   434   10
# 1    11  228

table(Y, fitted(model2)>0.2)
# Y   FALSE TRUE
# 0   431   13
# 1     3  236

detach(bcwis)

# 7.1.2 Poisson regression

# winewhite

winewhite <- read.csv("data/winewhite.csv")
attach(winewhite)

model1 <- glm(Y ~ X + D1 + D2 + D3 + D4 + D5 + D6 + D7 + D8 + D9 + D10 + 
                D11 + D12 + D13 + D14 + D15 + D16 + D17 + D18 + D19 + D20, 
              family="poisson")
round(coef(summary(model1)),3)
#            Estimate Std. Error z value Pr(>|z|)
#(Intercept)    2.726      0.691   3.946    0.000
#X             -0.105      0.029  -3.628    0.000
#D1            -1.146      0.373  -3.074    0.002
#D2             1.640      0.232   7.069    0.000
#D3            -1.385      0.166  -8.327    0.000
#D4            -0.839      0.128  -6.582    0.000
#D5            -1.044      0.177  -5.901    0.000
#D6            -1.021      0.191  -5.334    0.000
#D7            -1.864      0.532  -3.502    0.000
#D8            -0.711      0.383  -1.857    0.063
#D9            -0.185      0.520  -0.356    0.722!
#D10            1.016      0.385   2.640    0.008
#D11            0.452      0.360   1.254    0.210!
#D12           -0.111      0.328  -0.339    0.734!
#D13            0.253      0.421   0.600    0.548!
#D14            1.216      0.412   2.950    0.003
#D15            0.584      0.232   2.515    0.012
#D16            0.094      0.306   0.308    0.758!
#D17           -0.114      0.335  -0.340    0.734!
#D18           -0.828      0.362  -2.286    0.022
#D19            0.245      0.400   0.611    0.541!
#D20           -0.142      0.287  -0.492    0.622!

summary(model1)
# Null deviance: 2046.92  on 550  degrees of freedom
# Residual deviance:  492.17  on 529  degrees of freedom

summary(model1)$null.deviance-summary(model1)$deviance # 1554.74
summary(model1)$df.null-summary(model1)$df.residual # 21

round(pchisq(summary(model1)$null.deviance-summary(model1)$deviance,
             summary(model1)$df.null-summary(model1)$df.residual,
             lower.tail=F), 3)
# 0

model2 <- glm(Y ~ X + D1 + D2 + D3 + D4 + D5 + D6 + D7 + D8 + D10 + 
                D14 + D15 + D18, family="poisson")
round(coef(summary(model2)),3)
#            Estimate Std. Error z value Pr(>|z|)
#(Intercept)    2.204      0.431   5.117    0.000
#X             -0.084      0.015  -5.721    0.000
#D1            -0.912      0.258  -3.530    0.000
#D2             1.755      0.185   9.474    0.000
#D3            -1.309      0.139  -9.442    0.000
#D4            -0.844      0.126  -6.720    0.000
#D5            -0.958      0.135  -7.105    0.000
#D6            -0.910      0.149  -6.087    0.000
#D7            -1.791      0.440  -4.069    0.000
#D8            -0.767      0.242  -3.175    0.002
#D10            1.035      0.344   3.007    0.003
#D14            1.105      0.250   4.412    0.000
#D15            0.648      0.195   3.321    0.001
#D18           -0.858      0.272  -3.152    0.002

summary(model2)
# Null deviance: 2046.92  on 550  degrees of freedom
# Residual deviance:  495.23  on 537  degrees of freedom

summary(model2)$null.deviance-summary(model2)$deviance # 1551.69
summary(model2)$df.null-summary(model2)$df.residual # 13

anova(model2,model1, test="Chisq")
#  Resid. Df Resid. Dev Df Deviance P(>|Chi|)
#1       537     495.23                      
#2       529     492.17  8   3.0502    0.9312

summary(model2)$deviance-summary(model1)$deviance # 3.0502
summary(model2)$df.residual-summary(model1)$df.residual # 8

pchisq(summary(model2)$deviance-summary(model1)$deviance,
       summary(model2)$df.residual-summary(model1)$df.residual,
       lower.tail=F)
# 0.9311678

exp(-0.084) # 0.9194313
exp(coef(model2)[2]) # 0.9196207

exp(-0.912) # 0.40172
exp(coef(model2)[3]) # 0.4017139

detach(winewhite)

# oscars

oscars <- read.csv("data/oscars.csv")

library(mlogit)

oscars$Alt <- unlist(mapply(seq, to=table(-oscars$Year), from=1, by=1))

oscars1 <- mlogit.data(oscars, choice="Win", shape="long", alt.var="Alt", chid.var="Year")

model1 <- mlogit(Win ~ Nom + DOd + DGd + DGm + DPg | - 1, data=oscars1)

summary(model1)
#    Estimate Std. Error t-value  Pr(>|t|)    
#Nom  0.28462    0.08472  3.3595 0.0007807 ***
#DOd  2.06594    0.65369  3.1604 0.0015753 ** 
#DGd  0.70913    0.38801  1.8276 0.0676107 .  
#DGm  0.85255    0.59010  1.4448 0.1485271    
#DPg  1.79775    0.36696  4.8990  9.63e-07 ***

round((c(0.28462, 2.06594, 0.70913, 0.85255, 1.79775)/
         c(0.08472, 0.65369, 0.38801, 0.59010, 0.36696))^2,3)
# 11.286  9.988  3.340  2.087 24.001

round(pchisq((c(0.28462, 2.06594, 0.70913, 0.85255, 1.79775)/
                c(0.08472, 0.65369, 0.38801, 0.59010, 0.36696))^2,
             1,lower.tail=F),3)
# 0.001 0.002 0.068 0.149 0.000

exp(0.285) # 1.329762
exp(coef(model1)[1]) # 1.329255

exp(2.066) # 7.893187
exp(coef(model1)[2]) # 7.892676

exp(coef(model1))
#      Nom      DOd      DGd      DGm      DPg 
# 1.329255 7.892676 2.032221 2.345633 6.036071 

# mnradon

mnradon <- read.csv("data/mnradon.csv")
